@@ -1,7 +1,7 @@
 #ifndef GFANLIB_ADJUSTWEIGHTS_H
 #define GFANLIB_ADJUSTWEIGHTS_H
 
-#include <gfanlib/gfanlib_vector.h>
+#include "gfanlib/gfanlib_vector.h"
 
 gfan::ZVector nonvalued_adjustWeightForHomogeneity(const gfan::ZVector &w);
 gfan::ZVector valued_adjustWeightForHomogeneity(const gfan::ZVector &w);
