@@ -1,27 +1,26 @@
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 #if HAVE_GFANLIB
 
-#include <misc/intvec.h>
-#include <misc/sirandom.h>
+#include "misc/intvec.h"
+#include "misc/sirandom.h"
 
-#include <coeffs/bigintmat.h>
-#include <coeffs/longrat.h>
+#include "coeffs/bigintmat.h"
+#include "coeffs/longrat.h"
 
-#include <Singular/ipid.h>
-#include <Singular/ipshell.h>
-#include <Singular/blackbox.h>
+#include "Singular/ipid.h"
+#include "Singular/ipshell.h"
+#include "Singular/blackbox.h"
 
-#include <Singular/links/ssiLink.h>
+#include "Singular/links/ssiLink.h"
 
-#include <callgfanlib_conversion.h>
-#include <sstream>
+#include "callgfanlib_conversion.h"
 
-#include <gfanlib/gfanlib.h>
-#include <gfanlib/gfanlib_q.h>
+#include "gfanlib/gfanlib.h"
+#include "gfanlib/gfanlib_q.h"
 
-#include <bbfan.h>
-#include <bbpolytope.h>
+#include "bbfan.h"
+#include "bbpolytope.h"
 
 int coneID;
 
@@ -1236,6 +1235,62 @@ BOOLEAN intersectCones(leftv res, leftv args)
       return FALSE;
     }
   }
+  if ((u != NULL) && (u->Typ() == LIST_CMD))
+  {
+    if (u->next == NULL)
+    {
+      lists l = (lists) u->Data();
+
+      // find the total number of inequalities and equations
+      int r1=0; // total number of inequalities
+      int r2=0; // total number of equations
+      int c=0;  // ambient dimension
+      for (int i=0; i<=lSize(l); i++)
+      {
+        if (l->m[i].Typ() != coneID)
+        {
+          WerrorS("convexIntersection: entries of wrong type in list");
+          return TRUE;
+        }
+        gfan::ZCone* ll = (gfan::ZCone*) l->m[i].Data();
+        r1 = r1 + ll->getInequalities().getHeight();
+        r2 = r2 + ll->getEquations().getHeight();
+      }
+      if (lSize(l)>=0)
+      {
+        gfan::ZCone* ll = (gfan::ZCone*) l->m[0].Data();
+        c = ll->getInequalities().getWidth();
+      }
+      gfan::ZMatrix totalIneqs(r1,c);
+      gfan::ZMatrix totalEqs(r2,c);
+
+      // concat all inequalities and equations
+      r1=0; // counter for inequalities
+      r2=0; // counter for equations
+      for (int i=0; i<=lSize(l); i++)
+      {
+        gfan::ZCone* ll = (gfan::ZCone*) l->m[i].Data();
+        gfan::ZMatrix ineqs = ll->getInequalities();
+        for (int j=0; j<ineqs.getHeight(); j++)
+        {
+          totalIneqs[r1]=ineqs[j];
+          r1 = r1+1;
+        }
+        gfan::ZMatrix eqs = ll->getEquations();
+        for (int j=0; j<eqs.getHeight(); j++)
+        {
+          totalEqs[r2]=eqs[j];
+          r2 = r2+1;
+        }
+      }
+
+      gfan::ZCone* zc = new gfan::ZCone(totalIneqs,totalEqs);
+      zc->canonicalize();
+      res->rtyp = coneID;
+      res->data = (void *) zc;
+      return FALSE;
+    }
+  }
   if ((u != NULL) && (u->Typ() == polytopeID))
   {
     leftv v = u->next;
@@ -1444,7 +1499,7 @@ BOOLEAN coneLink(leftv res, leftv args)
       res->data = (void *) zd;
 
       delete zv;
-      if (v->Typ() == INTMAT_CMD)
+      if (v->Typ() == INTVEC_CMD)
         delete iv;
       gfan::deinitializeCddlibIfRequired();
       return FALSE;
@@ -1508,7 +1563,7 @@ BOOLEAN containsInSupport(leftv res, leftv args)
       res->data = (void*) (long) b;
 
       delete zv;
-      if (v->Typ() == INTMAT_CMD)
+      if (v->Typ() == INTVEC_CMD)
         delete iv;
       gfan::deinitializeCddlibIfRequired();
       return FALSE;
@@ -1518,6 +1573,96 @@ BOOLEAN containsInSupport(leftv res, leftv args)
   return TRUE;
 }
 
+BOOLEAN convexIntersectionOld(leftv res, leftv args)
+{
+  gfan::initializeCddlibIfRequired();
+  leftv u = args;
+  if ((u != NULL) && (u->Typ() == coneID))
+  {
+    leftv v = u->next;
+    if ((v != NULL) && (v->Typ() == coneID))
+    {
+      gfan::ZCone* zc1 = (gfan::ZCone*)u->Data();
+      gfan::ZCone* zc2 = (gfan::ZCone*)v->Data();
+      int d1 = zc1->ambientDimension();
+      int d2 = zc2->ambientDimension();
+      if (d1 != d2)
+      {
+        Werror("expected ambient dims of both cones to coincide\n"
+                "but got %d and %d", d1, d2);
+        return TRUE;
+      }
+      gfan::ZCone zc3 = gfan::intersection(*zc1, *zc2);
+      zc3.canonicalize();
+      res->rtyp = coneID;
+      res->data = (void *)new gfan::ZCone(zc3);
+      return FALSE;
+    }
+    if ((v != NULL) && (v->Typ() == polytopeID))
+    {
+      gfan::ZCone* zc11 = (gfan::ZCone*)u->Data();
+      gfan::ZCone zc1 = liftUp(*zc11);
+      gfan::ZCone* zc2 = (gfan::ZCone*)v->Data();
+      int d1 = zc1.ambientDimension();
+      int d2 = zc2->ambientDimension();
+      if (d1 != d2)
+      {
+        Werror("expected ambient dims of both cones to coincide\n"
+                "but got %d and %d", d1, d2);
+        return TRUE;
+      }
+      gfan::ZCone zc3 = gfan::intersection(zc1, *zc2);
+      zc3.canonicalize();
+      res->rtyp = polytopeID;
+      res->data = (void *)new gfan::ZCone(zc3);
+      return FALSE;
+    }
+  }
+  if ((u != NULL) && (u->Typ() == polytopeID))
+  {
+    leftv v = u->next;
+    if ((v != NULL) && (v->Typ() == coneID))
+    {
+      gfan::ZCone* zc1 = (gfan::ZCone*)u->Data();
+      gfan::ZCone* zc22 = (gfan::ZCone*)v->Data();
+      gfan::ZCone zc2 = liftUp(*zc22);
+      int d1 = zc1->ambientDimension();
+      int d2 = zc2.ambientDimension();
+      if (d1 != d2)
+      {
+        Werror("expected ambient dims of both cones to coincide\n"
+                "but got %d and %d", d1, d2);
+        return TRUE;
+      }
+      gfan::ZCone zc3 = gfan::intersection(*zc1, zc2);
+      zc3.canonicalize();
+      res->rtyp = polytopeID;
+      res->data = (void *)new gfan::ZCone(zc3);
+      return FALSE;
+    }
+    if ((v != NULL) && (v->Typ() == polytopeID))
+    {
+      gfan::ZCone* zc1 = (gfan::ZCone*)u->Data();
+      gfan::ZCone* zc2 = (gfan::ZCone*)v->Data();
+      int d1 = zc1->ambientDimension();
+      int d2 = zc2->ambientDimension();
+      if (d1 != d2)
+      {
+        Werror("expected ambient dims of both cones to coincide\n"
+                "but got %d and %d", d1, d2);
+        return TRUE;
+      }
+      gfan::ZCone zc3 = gfan::intersection(*zc1, *zc2);
+      zc3.canonicalize();
+      res->rtyp = polytopeID;
+      res->data = (void *)new gfan::ZCone(zc3);
+      return FALSE;
+    }
+  }
+  WerrorS("convexIntersectionOld: unexpected parameters");
+  return TRUE;
+}
+
 BOOLEAN containsRelatively(leftv res, leftv args)
 {
   leftv u = args;
@@ -1545,13 +1690,13 @@ BOOLEAN containsRelatively(leftv res, leftv args)
         res->rtyp = INT_CMD;
         res->data = (void *) b;
         delete zv;
-        if (v->Typ() == INTMAT_CMD)
+        if (v->Typ() == INTVEC_CMD)
           delete iv;
         gfan::deinitializeCddlibIfRequired();
         return FALSE;
       }
       delete zv;
-      if (v->Typ() == INTMAT_CMD)
+      if (v->Typ() == INTVEC_CMD)
         delete iv;
       gfan::deinitializeCddlibIfRequired();
       Werror("expected ambient dim of cone and size of vector\n"
@@ -1940,6 +2085,7 @@ void bbcone_setup(SModulFunctions* p)
   p->iiAddCproc("gfan.lib","containsRelatively",FALSE,containsRelatively);
   p->iiAddCproc("gfan.lib","convexHull",FALSE,convexHull);
   p->iiAddCproc("gfan.lib","convexIntersection",FALSE,intersectCones);
+  p->iiAddCproc("gfan.lib","convexIntersectionOld",FALSE,convexIntersectionOld);
   p->iiAddCproc("gfan.lib","dimension",FALSE,dimension);
   p->iiAddCproc("gfan.lib","dualCone",FALSE,dualCone);
   p->iiAddCproc("gfan.lib","equations",FALSE,equations);
