@@ -1,13 +1,13 @@
 #ifndef BBFAN_H
 #define BBFAN_H
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 #if HAVE_GFANLIB
 
-#include <Singular/ipid.h>
+#include "Singular/ipid.h"
 
-#include <gfanlib/gfanlib.h>
+#include "gfanlib/gfanlib.h"
 
 extern int fanID;
 
