@@ -1,4 +1,4 @@
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 #ifdef HAVE_PYTHON_MOD
 #include <sstream>
 #include <boost/python.hpp>
