@@ -1,7 +1,7 @@
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 #ifdef HAVE_PYTHON_MOD
 #include <boost/python.hpp>
-#include <Singular/ipshell.h>
+#include "Singular/ipshell.h"
 #include "ring_wrap.h"
 #include "poly_wrap.h"
 static boost::python::object Ring_as_str(const Ring& r)
@@ -22,7 +22,7 @@ void ring_set(Ring & R)
       static int ending=0;
       ending++;
       sprintf(name_buffer, "PYTHON_RING_VAR%d",ending);
-      h=enterid(omStrDup(name_buffer),0,RING_CMD,&IDROOT);
+      h=enterid(name_buffer,0,RING_CMD,&IDROOT);
       IDRING(h)=r;
       r->ref++;
     }
