@@ -8,25 +8,22 @@
 
 
 
-#include <kernel/mod2.h>
-#include <omalloc/omalloc.h>
-#include <resources/feResource.h>
-#include <Singular/feOpt.h>
+#include "kernel/mod2.h"
+#include "omalloc/omalloc.h"
+#include "resources/feResource.h"
+#include "Singular/feOpt.h"
 
 #ifdef __CYGWIN__
 #define BOOLEAN boolean
 #endif
 
-#include <stdio.h>
 #include <unistd.h>
 
 #ifdef DecAlpha_OSF1
 #define _BSD
 #endif
 
-#include <stdlib.h>
 #include <stdarg.h>
-#include <string.h>
 
 #ifdef __CYGWIN__
 #include <windows.h>
