@@ -5,13 +5,8 @@
 * ABSTRACT: Implementation of option business
 */
 
-#include <string.h>
-#include <stdlib.h>
 
-
-
-
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 #define FE_OPT_STRUCTURE
 
@@ -26,7 +21,6 @@ const char SHORT_OPTS_STRING[] = "bdhqstvxec:r:u:";
 // Generation of feOptIndex
 //
 #include <stdio.h>
-#include <unistd.h>
 #include <stdlib.h>
 int main()
 {
