@@ -5,27 +5,17 @@
 * ABSTRACT: help system
 */
 
-#include <string.h>
-#include <unistd.h>
-#include <stdio.h>
-#include <stddef.h>
-#include <stdlib.h>
-#include <time.h>
+#include "kernel/mod2.h"
 
+#include "omalloc/omalloc.h"
+#include "misc/mylimits.h"
 
+#include "resources/feResource.h"
+#include "reporter/reporter.h"
 
+#include "resources/omFindExec.h"
 
-#include <kernel/mod2.h>
-
-#include <omalloc/omalloc.h>
-#include <misc/mylimits.h>
-
-#include <resources/feResource.h>
-#include <reporter/reporter.h>
-
-#include <resources/omFindExec.h>
-
-#include <reporter/si_signals.h>
+#include "reporter/si_signals.h"
 
 #include "ipid.h"
 #include "ipshell.h"
@@ -172,7 +162,7 @@ void feHelp(char *str)
       Warn("No unique help for '%s'", str);
     else
       Warn("No help for topic '%s'", str);
-    Warn("Try one of");
+    WarnS("Try one of");
     char *matches=StringEndS();
     PrintS(matches);
     omFree(matches);
@@ -797,7 +787,7 @@ static void heBrowserHelp(heEntry hentry)
     //{
     //  Warn("Using URL '%s'.", feResource('u', 0));
     //}
-    Warn("Use 'system(\"--browser\", <browser>);' to change browser,");
+    WarnS("Use 'system(\"--browser\", <browser>);' to change browser,");
     StringSetS("where <browser> can be: ");
     int i = 0;
     i = 0;
@@ -1038,15 +1028,15 @@ static void heEmacsHelp(heEntry hentry, int /*br*/)
   WarnS("Your help command could not be executed. Use");
   Warn("C-h C-s %s",
        (hentry != NULL && *(hentry->node) != '\0' ? hentry->node : "Top"));
-  Warn("to enter the Singular online help. For general");
-  Warn("information on Singular running under Emacs, type C-h m.");
+  WarnS("to enter the Singular online help. For general");
+  WarnS("information on Singular running under Emacs, type C-h m.");
 }
 static int singular_manual(char *str, BOOLEAN isIndexEntry);
 static void heBuiltinHelp(heEntry hentry, int /*br*/)
 {
   char* node = omStrDup(hentry != NULL && *(hentry->key) != '\0' ?
                        hentry->key : "Top");
-  singular_manual(node,(hentry != NULL) && (hentry->url!=NULL));
+  singular_manual(node,(hentry != NULL) && *(hentry->url)!='\0');
   omFree(node);
 }
 
@@ -1061,7 +1051,6 @@ static void heBuiltinHelp(heEntry hentry, int /*br*/)
 #define HELP_NOT_FOUND 2
 #define BUF_LEN        256
 #define IDX_LEN        256
-#define MAX_LINES      21
 
 static inline char tolow(char p)
 {
@@ -1084,7 +1073,7 @@ static int show(unsigned long offset, char *close)
         && (buffer[0] != FIN_INDEX))
   {
     printf("%s", buffer);
-    if(lines++> MAX_LINES)
+    if(lines++==pagelength)
     {
       printf("\n Press <RETURN> to continue or x to exit help.\n");
       fflush(stdout);
@@ -1097,7 +1086,7 @@ static int show(unsigned long offset, char *close)
       lines=0;
     }
   }
-  if(*close!='x')
+  if((*close!='x')&&(pagelength>0))
   {
     printf("\nEnd of part. Press <RETURN> to continue or x to exit help.\n");
     fflush(stdout);
