@@ -4,26 +4,21 @@
 /*
 * ABSTRACT: i/o system
 */
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 /* I need myfread in standalone_parser */
 #ifndef STANDALONE_PARSER
 
-#include <omalloc/omalloc.h>
-#include <misc/options.h>
-#include <reporter/reporter.h>
-#include <kernel/oswrapper/feread.h>
-#include <Singular/fevoices.h>
-#include <Singular/subexpr.h>
-#include <Singular/ipshell.h>
-#include <Singular/sdb.h>
+#include "omalloc/omalloc.h"
+#include "misc/options.h"
+#include "reporter/reporter.h"
+#include "kernel/oswrapper/feread.h"
+#include "Singular/fevoices.h"
+#include "Singular/subexpr.h"
+#include "Singular/ipshell.h"
+#include "Singular/sdb.h"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <misc/mylimits.h>
-#include <stdarg.h>
-#include <sys/stat.h>
-#include <ctype.h>
+#include "misc/mylimits.h"
 #include <unistd.h>
 
 #ifdef HAVE_PWD_H
@@ -37,14 +32,10 @@
 char fe_promptstr[] ="  ";
 FILE *File_Profiling=NULL;
 
-// output/print buffer:
-#define INITIAL_PRINT_BUFFER 24*1024L
 // line buffer for reading:
 // minimal value for MAX_FILE_BUFFER: 4*4096 - see Tst/Long/gcd0_l.tst
 // this is an upper limit for the size of monomials/numbers read via the interpreter
 #define MAX_FILE_BUFFER 4*4096
-// static long feBufferLength=INITIAL_PRINT_BUFFER;
-//static char * feBuffer=(char *)omAlloc(INITIAL_PRINT_BUFFER);
 
 /**************************************************************************
 * handling of 'voices'
@@ -126,7 +117,7 @@ feBufferTypes Voice::Typ()
 * start the file 'fname' (STDIN is stdin) as a new voice (cf.VFile)
 * return FALSE on success, TRUE if an error occurs (file cannot be opened)
 */
-BOOLEAN newFile(char *fname,FILE* f)
+BOOLEAN newFile(char *fname)
 {
   currentVoice->Next();
   //Print(":File%d(%s):%s(%x)\n",
@@ -142,16 +133,11 @@ BOOLEAN newFile(char *fname,FILE* f)
   else
   {
     currentVoice->sw = BI_file; /* needed by exitVoice below */
-    if (f!=NULL)
-      currentVoice->files = f;
-    else
+    currentVoice->files = feFopen(fname,"r",NULL,TRUE);
+    if (currentVoice->files==NULL)
     {
-      currentVoice->files = feFopen(fname,"r",NULL,TRUE);
-      if (currentVoice->files==NULL)
-      {
-        exitVoice();
-        return TRUE;
-      }
+      exitVoice();
+      return TRUE;
     }
     currentVoice->start_lineno = 0;
   }
@@ -507,13 +493,13 @@ int feReadLine(char* b, int l)
     && (currentVoice->buffer[currentVoice->fptr]!='\0'))
     {
   NewBuff:
-      register int i=0;
+      REGISTER int i=0;
       long startfptr=currentVoice->fptr;
       long tmp_ptr=currentVoice->fptr;
       l--;
       loop
       {
-        register char c=
+        REGISTER char c=
         b[i]=currentVoice->buffer[tmp_ptr/*currentVoice->fptr*/];
         i++;
         if (yy_noeof==noeof_block)
@@ -537,31 +523,32 @@ int feReadLine(char* b, int l)
       b[i]='\0';
       if (currentVoice->sw==BI_buffer)
       {
+        BOOLEAN show_echo=FALSE;
+        char *anf;
+        long len;
         if (startfptr==0)
         {
-          char *anf=currentVoice->buffer;
+          anf=currentVoice->buffer;
           const char *ss=strchr(anf,'\n');
-          long len;
           if (ss==NULL) len=strlen(anf);
           else          len=ss-anf;
-          char *s=(char *)omAlloc(len+2);
-          strncpy(s,anf,len+2);
-          s[len+1]='\0';
-          fePrintEcho(s,b);
-          omFree((ADDRESS)s);
+          show_echo=TRUE;
         }
         else if (/*(startfptr>0) &&*/
         (currentVoice->buffer[startfptr-1]=='\n'))
         {
-          char *anf=currentVoice->buffer+startfptr;
+          anf=currentVoice->buffer+startfptr;
           const char *ss=strchr(anf,'\n');
-          long len;
           if (ss==NULL) len=strlen(anf);
           else          len=ss-anf;
+          yylineno++;
+          show_echo=TRUE;
+        }
+        if (show_echo)
+        {
           char *s=(char *)omAlloc(len+2);
           strncpy(s,anf,len+2);
           s[len+1]='\0';
-          yylineno++;
           fePrintEcho(s,b);
           omFree((ADDRESS)s);
         }
@@ -619,7 +606,7 @@ int feReadLine(char* b, int l)
     //s[strlen(s)+1]='\0'; add an second \0 at the end of the string
     s[rc]='\0';
     // handel \\ :
-    rc-=3;
+    rc-=3; if (rc<0) rc=0;
     if ((s[rc]=='\\')&&(currentVoice->sw!=BI_buffer))
     {
       s[rc]='\0';
@@ -689,10 +676,5 @@ Voice * feInitStdin(Voice *pp)
   omMarkAsStaticAddr(p->filename);
   return p;
 }
-
-
-#else /* ! STANDALONE_PARSER */
-#include <stdio.h>
-
 #endif
 
