@@ -6,41 +6,36 @@
 *           assignment of expressions and lists to objects or lists
 */
 
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
+#include "kernel/mod2.h"
 
-
-#include <kernel/mod2.h>
-
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
 #define TRANSEXT_PRIVATES
-#include <polys/ext_fields/transext.h>
+#include "polys/ext_fields/transext.h"
 
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <coeffs/coeffs.h>
-#include <coeffs/numbers.h>
-#include <coeffs/bigintmat.h>
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
+#include "coeffs/bigintmat.h"
 
 
-#include <polys/ext_fields/algext.h>
+#include "polys/ext_fields/algext.h"
 
-#include <polys/monomials/ring.h>
-#include <polys/matpol.h>
-#include <polys/monomials/maps.h>
-#include <polys/nc/nc.h>
-#include <polys/nc/sca.h>
-#include <polys/prCopy.h>
+#include "polys/monomials/ring.h"
+#include "polys/matpol.h"
+#include "polys/monomials/maps.h"
+#include "polys/nc/nc.h"
+#include "polys/nc/sca.h"
+#include "polys/prCopy.h"
 
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/oswrapper/timer.h>
-#include <kernel/combinatorics/stairc.h>
-#include <kernel/GBEngine/syz.h>
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/oswrapper/timer.h"
+#include "kernel/combinatorics/stairc.h"
+#include "kernel/GBEngine/syz.h"
 
 //#include "weight.h"
 #include "tok.h"
@@ -124,7 +119,8 @@ static BOOLEAN jjSHORTOUT(leftv, leftv a)
 #else
     currRing->ShortOut = shortOut;
     coeffs cf = currRing->cf;
-    while (nCoeff_is_Extension(cf)) {
+    while (nCoeff_is_Extension(cf))
+    {
       cf->extRing->ShortOut = shortOut;
       assume(cf->extRing != NULL);
       cf = cf->extRing->cf;
@@ -206,8 +202,10 @@ static BOOLEAN jjMINPOLY(leftv, leftv a)
     return TRUE;
   }
 
+  BOOLEAN redefine_from_algext=FALSE;
   if ( currRing->idroot != NULL )
   {
+    redefine_from_algext=(currRing->cf->extRing->qideal!=NULL);
 //    return TRUE;
 #ifndef SING_NDEBUG
     idhdl p = currRing->idroot;
@@ -216,7 +214,7 @@ static BOOLEAN jjMINPOLY(leftv, leftv a)
 
     while(p != NULL)
     {
-      PrintS(p->String(TRUE)); PrintLn();
+      PrintS(p->String(TRUE)); Print("(%s)\n",IDID(p));
       p = p->next;
     }
 #endif
@@ -263,17 +261,19 @@ static BOOLEAN jjMINPOLY(leftv, leftv a)
     rDelete( A.r );
     return TRUE;
   }
-  if (DEN((fraction)(p)) != NULL) // minpoly must be a fraction with poly numerator...!!
+  if (!redefine_from_algext && (DEN((fraction)(p)) != NULL)) // minpoly must be a fraction with poly numerator...!!
   {
-    poly z=NUM((fraction)p);
     poly n=DEN((fraction)(p));
-    z=p_Mult_nn(z,pGetCoeff(n),currRing->cf->extRing);
-    NUM((fraction)p)=z;
-    DEN((fraction)(p))=NULL;
+    if(!p_IsConstantPoly(n,currRing->cf->extRing))
+    {
+      WarnS("denominator must be constant - ignoring it");
+    }
     p_Delete(&n,currRing->cf->extRing);
+    DEN((fraction)(p))=NULL;
   }
 
-  q->m[0] = NUM((fraction)p);
+  if (redefine_from_algext) q->m[0]=(poly)p;
+  else          q->m[0] = NUM((fraction)p);
   A.r->qideal = q;
 
 #if 0
@@ -287,16 +287,14 @@ static BOOLEAN jjMINPOLY(leftv, leftv a)
   // :(
 //  NUM((fractionObject *)p) = NULL; // makes 0/ NULL fraction - which should not happen!
 //  n_Delete(&p, currRing->cf); // doesn't expect 0/ NULL :(
-  if(true)
+  if (!redefine_from_algext)
   {
     extern omBin fractionObjectBin;
     NUM((fractionObject *)p) = NULL; // not necessary, but still...
     omFreeBin((ADDRESS)p, fractionObjectBin);
   }
 
-
   coeffs new_cf = nInitChar(n_algExt, &A);
-
   if (new_cf==NULL)
   {
     WerrorS("Could not construct the alg. extension: llegal minpoly?");
@@ -308,9 +306,9 @@ static BOOLEAN jjMINPOLY(leftv, leftv a)
   {
     nKillChar(currRing->cf); currRing->cf=new_cf;
   }
-
   return FALSE;
 }
+
 static BOOLEAN jjNOETHER(leftv, leftv a)
 {
   poly p=(poly)a->CopyD(POLY_CMD);
@@ -1100,11 +1098,14 @@ static BOOLEAN jiAssign_1(leftv l, leftv r, BOOLEAN toplevel)
   }
   if(rt==NONE)
   {
-    WarnS("right side is not a datum, assignment ignored");
-    Warn("in line >>%s<<",my_yylinebuf);
-    // if (!errorreported)
-    //   WerrorS("right side is not a datum");
-    //return TRUE;
+    if ((!TEST_V_ASSIGN_NONE)||(lt!=DEF_CMD))
+    {
+      WarnS("right side is not a datum, assignment ignored");
+      Warn("in line >>%s<<",my_yylinebuf);
+      // if (!errorreported)
+      //   WerrorS("right side is not a datum");
+      //return TRUE;
+    }
     return FALSE;
   }
 
@@ -1356,9 +1357,9 @@ static BOOLEAN jiA_VECTOR_L(leftv l,leftv r)
   leftv h;
   sleftv t;
   int i=0;
+  memset(&t,0,sizeof(sleftv));
   while (l!=NULL)
   {
-    memset(&t,0,sizeof(sleftv));
     t.rtyp=POLY_CMD;
     if (i>=IDELEMS(I))
     {
@@ -1627,14 +1628,14 @@ static BOOLEAN jiA_MATRIX_L(leftv l,leftv r)
     {
       if (r!=NULL)
       {
-        Warn("list length mismatch in assign (l>r)");
+        WarnS("list length mismatch in assign (l>r)");
         nok=TRUE;
       }
       break;
     }
     else if (r==NULL)
     {
-      Warn("list length mismatch in assign (l<r)");
+      WarnS("list length mismatch in assign (l<r)");
       nok=TRUE;
       break;
     }
@@ -1736,12 +1737,12 @@ static BOOLEAN jiAssign_list(leftv l, leftv r)
   leftv ld=&(li->m[i]);
   ld->e=l->e->next;
   BOOLEAN b;
+  sleftv tmp;
+  memset(&tmp,0,sizeof(sleftv));
   if (/*(ld->rtyp!=LIST_CMD)
   &&*/(ld->e==NULL)
   && (ld->Typ()!=r->Typ()))
   {
-    sleftv tmp;
-    memset(&tmp,0,sizeof(sleftv));
     tmp.rtyp=DEF_CMD;
     b=iiAssign(&tmp,r,FALSE);
     ld->CleanUp();
@@ -1751,8 +1752,6 @@ static BOOLEAN jiAssign_list(leftv l, leftv r)
   && (ld->Typ()==r->Typ())
   && (ld->Typ()<MAX_TOK))
   {
-    sleftv tmp;
-    memset(&tmp,0,sizeof(sleftv));
     tmp.rtyp=r->Typ();
     tmp.data=(char*)idrecDataInit(r->Typ());
     b=iiAssign(&tmp,r,FALSE);
@@ -2002,7 +2001,11 @@ BOOLEAN iiAssign(leftv l, leftv r, BOOLEAN toplevel)
         break;
       }
       if ((hh->next==NULL)&&(hh->Typ()==IDEAL_CMD))
-        return jiAssign_1(l,hh,toplevel); /* map-assign: map f=r,i; */
+      {
+        BOOLEAN bo=jiAssign_1(l,hh,toplevel); /* map-assign: map f=r,i; */
+        omFreeBin(hh,sleftv_bin);
+        return bo;
+      }
       //no break, handle the rest like an ideal:
       map_assign=TRUE;
     }
