@@ -10,42 +10,40 @@
 
 
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <coeffs/numbers.h>
-#include <coeffs/bigintmat.h>
+#include "coeffs/numbers.h"
+#include "coeffs/bigintmat.h"
 
-#include <polys/matpol.h>
-#include <polys/monomials/ring.h>
+#include "polys/matpol.h"
+#include "polys/monomials/ring.h"
 
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/syz.h>
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/syz.h"
 
-#include <Singular/tok.h>
-#include <Singular/ipshell.h>
-#include <Singular/fevoices.h>
-#include <Singular/lists.h>
-#include <Singular/attrib.h>
-#include <Singular/links/silink.h>
-#include <Singular/ipid.h>
-#include <Singular/blackbox.h>
-#include <Singular/number2.h>
+#include "Singular/tok.h"
+#include "Singular/ipshell.h"
+#include "Singular/fevoices.h"
+#include "Singular/lists.h"
+#include "Singular/attrib.h"
+#include "Singular/links/silink.h"
+#include "Singular/ipid.h"
+#include "Singular/blackbox.h"
+#include "Singular/number2.h"
 
 #ifdef SINGULAR_4_2
-#include <Singular/number2.h>
+#include "Singular/number2.h"
 #endif
 #ifdef HAVE_DYNAMIC_LOADING
-#include <polys/mod_raw.h>
+#include "polys/mod_raw.h"
 #endif /* HAVE_DYNAMIC_LOADING */
 
-#include <string.h>
-
 omBin sip_command_bin = omGetSpecBin(sizeof(sip_command));
 omBin sip_package_bin = omGetSpecBin(sizeof(sip_package));
 //omBin ip_package_bin = omGetSpecBin(sizeof(ip_package));
@@ -53,8 +51,6 @@ omBin idrec_bin = omGetSpecBin(sizeof(idrec));
 
 coeffs coeffs_BIGINT;
 
-FILE   *feFilePending; /*temp. storage for grammar.y */
-
 proclevel *procstack=NULL;
 //idhdl idroot = NULL;
 
@@ -146,7 +142,10 @@ void *idrecDataInit(int t)
     case INTMAT_CMD:
       return (void *)new intvec();
     case NUMBER_CMD:
-      return (void *) nInit(0);
+    {
+      if (currRing!=NULL) return (void *) nInit(0);
+      else                return NULL;
+    }
     case BIGINT_CMD:
       return (void *) n_Init(0, coeffs_BIGINT);
     case IDEAL_CMD:
@@ -282,7 +281,7 @@ idhdl enterid(const char * s, int lev, int t, idhdl* root, BOOLEAN init, BOOLEAN
           {
             goto errlabel;
           }
-          else return *root;
+          else return h;
         }
         else
         {
@@ -420,14 +419,18 @@ void killhdl2(idhdl h, idhdl * ih, ring r)
   }
   if (h->attribute!=NULL)
   {
-    //h->attribute->killAll(r); MEMORY LEAK!
+    if ((IDTYP(h)==RING_CMD)&&(IDRING(h)!=r))
+       h->attribute->killAll(IDRING(h));
+    else
+       h->attribute->killAll(r);
     h->attribute=NULL;
   }
   if (IDTYP(h) == PACKAGE_CMD)
   {
-    if (strcmp(IDID(h),"Top")==0)
+    if (((IDPACKAGE(h)->language==LANG_C)&&(IDPACKAGE(h)->idroot!=NULL))
+    || (strcmp(IDID(h),"Top")==0))
     {
-      WarnS("can not kill `Top`");
+      Warn("cannot kill `%s`",IDID(h));
       return;
     }
     // any objects defined for this package ?
