@@ -5,29 +5,20 @@
 * ABSTRACT: interpreter: LIB and help
 */
 
+#include "kernel/mod2.h"
 
+#include "Singular/tok.h"
+#include "misc/options.h"
+#include "Singular/ipid.h"
+#include "omalloc/omalloc.h"
+#include "polys/monomials/ring.h"
+#include "Singular/subexpr.h"
+#include "Singular/ipid.h"
+#include "Singular/ipshell.h"
+#include "Singular/fevoices.h"
+#include "Singular/lists.h"
 
-
-
-#include <kernel/mod2.h>
-
-#include <Singular/tok.h>
-#include <misc/options.h>
-#include <Singular/ipid.h>
-#include <omalloc/omalloc.h>
-#include <polys/monomials/ring.h>
-#include <Singular/subexpr.h>
-#include <Singular/ipid.h>
-#include <Singular/ipshell.h>
-#include <Singular/fevoices.h>
-#include <Singular/lists.h>
-
-//#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include <ctype.h>
-#include <sys/stat.h>
-
 
 #if SIZEOF_LONG == 8
 #define SI_MAX_NEST 500
@@ -58,12 +49,11 @@ BOOLEAN load_modules(const char *newlib, char *fullname, BOOLEAN autoexport);
 procinfo *iiInitSingularProcinfo(procinfov pi, const char *libname,
               const char *procname, int line, long pos, BOOLEAN pstatic=FALSE);
 #endif /* HAVE_LIBPARSER */
-#define NS_LRING (procstack->cRing)
 
 extern int iiArithAddCmd(const char *szName, short nAlias, short nTokval,
                          short nToktype, short nPos);
 
-#include <Singular/mod_lib.h>
+#include "Singular/mod_lib.h"
 
 #ifdef HAVE_LIBPARSER
 void yylprestart (FILE *input_file );
@@ -95,15 +85,6 @@ BOOLEAN iiGetLibStatus(char *lib)
   return (strcmp(lib,IDPACKAGE(hl)->libname)==0);
 }
 
-/*2
-* find the library of an proc:
-*  => return (pi->libname)
-*/
-char * iiGetLibName(procinfov pi)
-{
-  return pi->libname;
-}
-
 /*2
 * given a line 'proc[ ]+{name}[ \t]*'
 * return a pointer to name and set the end of '\0'
@@ -369,7 +350,7 @@ BOOLEAN iiAllStart(procinfov pi, char *p,feBufferTypes t, int l)
 * TODO:interrupt
 * return FALSE on success, TRUE if an error occurs
 */
-BOOLEAN iiPStart(idhdl pn, sleftv  * v)
+BOOLEAN iiPStart(idhdl pn, leftv v)
 {
   procinfov pi=NULL;
   int old_echo=si_echo;
@@ -396,10 +377,12 @@ BOOLEAN iiPStart(idhdl pn, sleftv  * v)
   }
   else return TRUE;
   /* generate argument list ======================================*/
+  //iiCurrArgs should be NULL here, as the assignment for the parameters
+  // of the prevouis call are already done befor calling another routine
   if (v!=NULL)
   {
     iiCurrArgs=(leftv)omAllocBin(sleftv_bin);
-    memcpy(iiCurrArgs,v,sizeof(sleftv));
+    memcpy(iiCurrArgs,v,sizeof(sleftv)); // keeps track of v->next etc.
     memset(v,0,sizeof(sleftv));
   }
   else
@@ -418,10 +401,6 @@ BOOLEAN iiPStart(idhdl pn, sleftv  * v)
   {
     err=iiAllStart(pi,pi->data.s.body,BT_proc,pi->data.s.body_lineno-(v!=NULL));
 
-#ifdef USE_IILOCALRING
-#if 0
-  if(procstack->cRing != iiLocalRing[myynest]) Print("iiMake_proc: 1 ring not saved procs:%x, iiLocal:%x\n",procstack->cRing, iiLocalRing[myynest]);
-#endif
     if (iiLocalRing[myynest-1] != currRing)
     {
       if (iiRETURNEXPR.RingDependend())
@@ -438,7 +417,7 @@ BOOLEAN iiPStart(idhdl pn, sleftv  * v)
           nh=rFindHdl(currRing,NULL);
         if (nh!=NULL)          n=nh->id;
         else                   n="none";
-        Werror("ring change during procedure call: %s -> %s (level %d)",o,n,myynest);
+        Werror("ring change during procedure call %s: %s -> %s (level %d)",pi->procname,o,n,myynest);
         iiRETURNEXPR.CleanUp();
         err=TRUE;
       }
@@ -455,45 +434,6 @@ BOOLEAN iiPStart(idhdl pn, sleftv  * v)
       rSetHdl(rFindHdl(currRing,NULL));
       iiLocalRing[myynest-1]=NULL;
     }
-#else /* USE_IILOCALRING */
-    if (procstack->cRing != currRing)
-    {
-      //if (procstack->cRingHdl!=NULL)
-      //Print("procstack:%s,",IDID(procstack->cRingHdl));
-      //if (currRingHdl!=NULL)
-      //Print(" curr:%s\n",IDID(currRingHdl));
-      //Print("pr:%x, curr: %x\n",procstack->cRing,currRing);
-      if (iiRETURNEXPR.RingDependend())
-      {
-        //idhdl hn;
-        const char *n;
-        const char *o;
-        if (procstack->cRing!=NULL)
-        {
-          //PrintS("reset ring\n");
-          procstack->cRingHdl=rFindHdl(procstack->cRing,NULL);
-          o=IDID(procstack->cRingHdl);
-          currRing=procstack->cRing;
-          currRingHdl=procstack->cRingHdl;
-        }
-        else                            o="none";
-        if (currRing!=NULL)             n=IDID(currRingHdl);
-        else                            n="none";
-        if (currRing==NULL)
-        {
-          Werror("ring change during procedure call: %s -> %s (level %d)",o,n,myynest);
-          iiRETURNEXPR.CleanUp();
-          err=TRUE;
-        }
-      }
-      if (procstack->cRingHdl!=NULL)
-      {
-        rSetHdl(procstack->cRingHdl);
-      }
-      else
-      { currRingHdl=NULL; currRing=NULL; }
-    }
-#endif /* USE_IILOCALRING */
     //Print("kill locals for %s (level %d)\n",IDID(pn),myynest);
     killlocals(myynest);
 #ifndef SING_NDEBUG
@@ -511,9 +451,7 @@ BOOLEAN iiPStart(idhdl pn, sleftv  * v)
   return err;
 }
 
-#ifdef USE_IILOCALRING
 ring    *iiLocalRing;
-#endif
 sleftv  iiRETURNEXPR;
 int     iiRETURNEXPR_len=0;
 
@@ -521,7 +459,6 @@ int     iiRETURNEXPR_len=0;
 static void iiShowLevRings()
 {
   int i;
-#ifdef USE_IILOCALRING
   for (i=0;i<=myynest;i++)
   {
     Print("lev %d:",i);
@@ -529,19 +466,6 @@ static void iiShowLevRings()
     else                      Print("%lx",(long)iiLocalRing[i]);
     PrintLn();
   }
-#endif
-#if  0
-  i=myynest;
-  proclevel *p=procstack;
-  while (p!=NULL)
-  {
-    Print("lev %d:",i);
-    if (p->cRingHdl==NULL) PrintS("NULL");
-    else                   Print("%s",IDID(p->cRingHdl));
-    PrintLn();
-    p=p->next;
-  }
-#endif
   if (currRing==NULL) PrintS("curr:NULL\n");
   else                Print ("curr:%lx\n",(long)currRing);
 }
@@ -551,16 +475,14 @@ static void iiCheckNest()
 {
   if (myynest >= iiRETURNEXPR_len-1)
   {
-#ifdef USE_IILOCALRING
     iiLocalRing=(ring *)omreallocSize(iiLocalRing,
                                    iiRETURNEXPR_len*sizeof(ring),
                                    (iiRETURNEXPR_len+16)*sizeof(ring));
     memset(&(iiLocalRing[iiRETURNEXPR_len]),0,16*sizeof(ring));
-#endif
     iiRETURNEXPR_len+=16;
   }
 }
-BOOLEAN iiMake_proc(idhdl pn, package pack, sleftv* sl)
+BOOLEAN iiMake_proc(idhdl pn, package pack, leftv sl)
 {
   int err;
   procinfov pi = IDPROC(pn);
@@ -571,10 +493,8 @@ BOOLEAN iiMake_proc(idhdl pn, package pack, sleftv* sl)
     return TRUE;
   }
   iiCheckNest();
-#ifdef USE_IILOCALRING
   iiLocalRing[myynest]=currRing;
   //Print("currRing(%d):%s(%x) in %s\n",myynest,IDID(currRingHdl),currRing,IDID(pn));
-#endif
   iiRETURNEXPR.Init();
   procstack->push(pi->procname);
   if ((traceit&TRACE_SHOW_PROC)
@@ -647,7 +567,131 @@ BOOLEAN iiMake_proc(idhdl pn, package pack, sleftv* sl)
     return TRUE;
   return FALSE;
 }
+static void iiCallLibProcBegin()
+{
+  idhdl tmp_ring=NULL;
+  if (currRing!=NULL)
+  {
+    if (IDRING(currRingHdl)!=currRing)
+    {
+      // clean up things depending on currRingHdl:
+      sLastPrinted.CleanUp(IDRING(currRingHdl));
+      sLastPrinted.Init();
+      // need to define a ring-hdl for currRingHdl
+      tmp_ring=enterid(" tmpRing",myynest,RING_CMD,&IDROOT,FALSE);
+      IDRING(tmp_ring)=currRing;
+      currRing->ref++;
+      rSetHdl(tmp_ring);
+    }
+  }
+}
+static void iiCallLibProcEnd(idhdl save_ringhdl, ring save_ring)
+{
+  if ((currRing!=NULL)
+  &&(currRing!=save_ring))
+  {
+    currRing->ref--;
+    idhdl hh=IDROOT;
+    idhdl prev=NULL;
+    while((hh!=currRingHdl) && (hh!=NULL)) { prev=hh; hh=hh->next; }
+    if (hh!=NULL)
+    {
+      if (prev==NULL) IDROOT=hh->next;
+      else prev->next=hh->next;
+      omFree((ADDRESS)IDID(hh));
+      omFreeBin((ADDRESS)hh, idrec_bin);
+    }
+    else
+    {
+      WarnS("internal: lost ring in iiCallLib");
+    }
+  }
+  currRingHdl=save_ringhdl;
+  currRing=save_ring;
+}
 
+void* iiCallLibProc1(const char*n, void *arg, int arg_type, BOOLEAN &err)
+{
+  idhdl h=ggetid(n);
+  if ((h==NULL)
+  || (IDTYP(h)!=PROC_CMD))
+  {
+    err=2;
+    return NULL;
+  }
+  // ring handling
+  idhdl save_ringhdl=currRingHdl;
+  ring save_ring=currRing;
+  iiCallLibProcBegin();
+  // argument:
+  sleftv tmp;
+  tmp.Init();
+  tmp.data=arg;
+  tmp.rtyp=arg_type;
+  // call proc
+  err=iiMake_proc(h,currPack,&tmp);
+  // clean up ring
+  iiCallLibProcEnd(save_ringhdl,save_ring);
+  // return
+  if (err==FALSE)
+  {
+    void*r=iiRETURNEXPR.data;
+    iiRETURNEXPR.data=NULL;
+    iiRETURNEXPR.CleanUp();
+    return r;
+  }
+  return NULL;
+}
+/// args: NULL terminated arry of arguments
+/// arg_types: 0 terminated array of corresponding types
+void* iiCallLibProcM(const char*n, void **args, int* arg_types, BOOLEAN &err)
+{
+  idhdl h=ggetid(n);
+  if ((h==NULL)
+  || (IDTYP(h)!=PROC_CMD))
+  {
+    err=2;
+    return NULL;
+  }
+  // ring handling
+  idhdl save_ringhdl=currRingHdl;
+  ring save_ring=currRing;
+  iiCallLibProcBegin();
+  // argument:
+  if (arg_types[0]!=0)
+  {
+    sleftv tmp;
+    leftv tt=&tmp;
+    int i=1;
+    tmp.Init();
+    tmp.data=args[0];
+    tmp.rtyp=arg_types[0];
+    while(arg_types[i]!=0)
+    {
+      tt->next=(leftv)omAlloc0(sizeof(sleftv));
+      tt=tt->next;
+      tt->rtyp=arg_types[i];
+      tt->data=args[i];
+      i++;
+    }
+    // call proc
+    err=iiMake_proc(h,currPack,&tmp);
+  }
+  else
+  // call proc
+    err=iiMake_proc(h,currPack,NULL);
+  // clean up ring
+  iiCallLibProcEnd(save_ringhdl,save_ring);
+  // return
+  if (err==FALSE)
+  {
+    void*r=iiRETURNEXPR.data;
+    iiRETURNEXPR.data=NULL;
+    iiRETURNEXPR.CleanUp();
+    return r;
+  }
+  return NULL;
+}
 /*2
 * start an example (as a proc),
 * destroys the string 'example'
@@ -659,9 +703,7 @@ BOOLEAN iiEStart(char* example, procinfo *pi)
 
   iiCheckNest();
   procstack->push(example);
-#ifdef USE_IILOCALRING
   iiLocalRing[myynest]=currRing;
-#endif
   if (traceit&TRACE_SHOW_PROC)
   {
     if (traceit&TRACE_SHOW_LINENO) printf("\n");
@@ -679,7 +721,6 @@ BOOLEAN iiEStart(char* example, procinfo *pi)
     if (traceit&TRACE_SHOW_LINENO) printf("\n");
     printf("leaving  -example- (level %d)\n",myynest);
   }
-#ifdef USE_IILOCALRING
   if (iiLocalRing[myynest] != currRing)
   {
     if (iiLocalRing[myynest]!=NULL)
@@ -693,24 +734,6 @@ BOOLEAN iiEStart(char* example, procinfo *pi)
       currRing=NULL;
     }
   }
-#else /* USE_IILOCALRING */
-#endif /* USE_IILOCALRING */
-  if (NS_LRING != currRing)
-  {
-    if (NS_LRING!=NULL)
-    {
-      idhdl rh=procstack->cRingHdl;
-      if ((rh==NULL)||(IDRING(rh)!=NS_LRING))
-        rh=rFindHdl(NS_LRING,NULL);
-      rSetHdl(rh);
-    }
-    else
-    {
-      currRingHdl=NULL;
-      currRing=NULL;
-    }
-  }
-//#endif /* USE_IILOCALRING */
   procstack->pop();
   return err;
 }
@@ -741,7 +764,7 @@ iiGetBuiltinModInit(const char* libname)
 BOOLEAN iiTryLoadLib(leftv v, const char *id)
 {
   BOOLEAN LoadResult = TRUE;
-  char libnamebuf[128];
+  char libnamebuf[1024];
   char *libname = (char *)omAlloc(strlen(id)+5);
   const char *suffix[] = { "", ".lib", ".so", ".sl", NULL };
   int i = 0;
@@ -757,7 +780,7 @@ BOOLEAN iiTryLoadLib(leftv v, const char *id)
     {
       char *s=omStrDup(libname);
       #ifdef HAVE_DYNAMIC_LOADING
-      char libnamebuf[256];
+      char libnamebuf[1024];
       #endif
 
       if (LT==LT_SINGULAR)
@@ -802,7 +825,7 @@ BOOLEAN iiLocateLib(const char* lib, char* where)
 
 BOOLEAN iiLibCmd( char *newlib, BOOLEAN autoexport, BOOLEAN tellerror, BOOLEAN force )
 {
-  char libnamebuf[128];
+  char libnamebuf[1024];
   // procinfov pi;
   // idhdl h;
   idhdl pl;
@@ -918,7 +941,7 @@ BOOLEAN iiLoadLIB(FILE *fp, const char *libnamebuf, const char*newlib,
     }
     else
       Werror(yylp_errlist[yylp_errno], yylplineno);
-    Werror("Cannot load library,... aborting.");
+    WerrorS("Cannot load library,... aborting.");
     reinit_yylp();
     fclose( yylpin );
     iiCleanProcs(IDROOT);
@@ -929,8 +952,8 @@ BOOLEAN iiLoadLIB(FILE *fp, const char *libnamebuf, const char*newlib,
   if( (lib_style == OLD_LIBSTYLE) && (BVERBOSE(V_LOAD_LIB)))
   {
     Warn( "library %s has old format. This format is still accepted,", newlib);
-    Warn( "but for functionality you may wish to change to the new");
-    Warn( "format. Please refer to the manual for further information.");
+    WarnS( "but for functionality you may wish to change to the new");
+    WarnS( "format. Please refer to the manual for further information.");
   }
   reinit_yylp();
   fclose( yylpin );
@@ -966,26 +989,15 @@ BOOLEAN iiLoadLIB(FILE *fp, const char *libnamebuf, const char*newlib,
 
 /*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
 procinfo *iiInitSingularProcinfo(procinfov pi, const char *libname,
-              const char *procname, int line, long pos, BOOLEAN pstatic)
+              const char *procname, int, long pos, BOOLEAN pstatic)
 {
+  memset(pi,0,sizeof(*pi));
   pi->libname = omStrDup(libname);
   pi->procname = omStrDup(procname);
   pi->language = LANG_SINGULAR;
   pi->ref = 1;
-  pi->pack = NULL;
   pi->is_static = pstatic;
   pi->data.s.proc_start = pos;
-  pi->data.s.def_end    = 0L;
-  pi->data.s.help_start = 0L;
-  pi->data.s.help_end   = 0L;
-  pi->data.s.body_start = 0L;
-  pi->data.s.body_end   = 0L;
-  pi->data.s.example_start = 0L;
-  pi->data.s.proc_lineno = line;
-  pi->data.s.body_lineno = 0;
-  pi->data.s.example_lineno = 0;
-  pi->data.s.body = NULL;
-  pi->data.s.help_chksum = 0;
   return(pi);
 }
 
@@ -1005,21 +1017,60 @@ int iiAddCproc(const char *libname, const char *procname, BOOLEAN pstatic,
   }
   #endif
 
-  h = enterid(procname,0, PROC_CMD, &IDROOT, TRUE);
+  h=IDROOT->get(procname,0);
+  if ((h!=NULL)
+  && (IDTYP(h)==PROC_CMD))
+  {
+    pi = IDPROC(h);
+    if ((pi->language == LANG_SINGULAR)
+    &&(BVERBOSE(V_REDEFINE)))
+      Warn("extend `%s`",procname);
+  }
+  else
+  {
+    h = enterid(procname,0, PROC_CMD, &IDROOT, TRUE);
+  }
   if ( h!= NULL )
   {
     pi = IDPROC(h);
-    pi->libname = omStrDup(libname);
-    pi->procname = omStrDup(procname);
-    pi->language = LANG_C;
-    pi->ref = 1;
-    pi->is_static = pstatic;
-    pi->data.o.function = func;
+    if((pi->language == LANG_SINGULAR)
+    ||(pi->language == LANG_NONE))
+    {
+      omfree(pi->libname);
+      pi->libname = omStrDup(libname);
+      omfree(pi->procname);
+      pi->procname = omStrDup(procname);
+      pi->language = LANG_C;
+      pi->ref = 1;
+      pi->is_static = pstatic;
+      pi->data.o.function = func;
+    }
+    else if(pi->language == LANG_C)
+    {
+      if(pi->data.o.function == func)
+      {
+        pi->ref++;
+      }
+      else
+      {
+        omfree(pi->libname);
+        pi->libname = omStrDup(libname);
+        omfree(pi->procname);
+        pi->procname = omStrDup(procname);
+        pi->language = LANG_C;
+        pi->ref = 1;
+        pi->is_static = pstatic;
+        pi->data.o.function = func;
+      }
+    }
+    else
+      Warn("internal error: unknown procedure type %d",pi->language);
+    if (currPack->language==LANG_SINGULAR) currPack->language=LANG_MIX;
     return(1);
   }
   else
   {
-    PrintS("iiAddCproc: failed.\n");
+    WarnS("iiAddCproc: failed.");
   }
   return(0);
 }
@@ -1069,24 +1120,31 @@ BOOLEAN load_modules(const char *newlib, char *fullname, BOOLEAN autoexport)
   }
   pl = basePack->idroot->get(plib,0); /* packages only in top level
                                         (see enterid) */
-  if (pl==NULL)
+  if ((pl!=NULL)
+  &&(IDTYP(pl)==PACKAGE_CMD))
   {
-    pl = enterid( plib,0, PACKAGE_CMD, &IDROOT,
-                  TRUE );
-    IDPACKAGE(pl)->language = LANG_C;
-    IDPACKAGE(pl)->libname=omStrDup(newlib);
+    if(IDPACKAGE(pl)->language==LANG_C)
+    {
+      if (BVERBOSE(V_LOAD_LIB)) Warn( "%s already loaded as package", newlib);
+      omFree(plib);
+      return FALSE;
+    }
+    else if(IDPACKAGE(pl)->language==LANG_MIX)
+    {
+      if (BVERBOSE(V_LOAD_LIB)) Warn( "%s contain binary parts, cannot load", newlib);
+      omFree(plib);
+      return FALSE;
+    }
   }
   else
   {
-    if(IDTYP(pl)!=PACKAGE_CMD)
-    {
-      Warn("not of type package.");
-      goto load_modules_end;
-    }
+    pl = enterid( plib,0, PACKAGE_CMD, &IDROOT, TRUE );
+    IDPACKAGE(pl)->libname=omStrDup(newlib);
   }
+  IDPACKAGE(pl)->language = LANG_C;
   if (dynl_check_opened(FullName))
   {
-    if (BVERBOSE(V_LOAD_LIB)) Warn( "%s already loaded", fullname);
+    if (BVERBOSE(V_LOAD_LIB)) Warn( "%s already loaded as C library", fullname);
     return FALSE;
   }
   if((IDPACKAGE(pl)->handle=dynl_open(FullName))==(void *)NULL)
@@ -1118,13 +1176,15 @@ BOOLEAN load_modules(const char *newlib, char *fullname, BOOLEAN autoexport)
         Warn("loaded %s for a different version of Singular(expected MAX_TOK: %d, got %d)",fullname,MAX_TOK,ver);
       }
       currPack->loaded=1;
-      currPack=s;
+      currPack=s; /* reset currPack to previous */
       RET=FALSE;
     }
     else
     {
       Werror("mod_init not found:: %s\nThis is probably not a dynamic module for Singular!\n", dynl_error());
-      killhdl2(pl,&(basePack->idroot),NULL); // remove package
+      errorreported=0;
+      if(IDPACKAGE(pl)->idroot==NULL)
+        killhdl2(pl,&(basePack->idroot),NULL); // remove package
     }
   }
 
@@ -1149,18 +1209,23 @@ BOOLEAN load_builtin(const char *newlib, BOOLEAN autoexport, SModulFunc_t init)
   // BOOLEAN RET=TRUE;
   // int token;
 
-  pl = IDROOT->get(plib,0);
-  if (pl!=NULL)
+  pl = basePack->idroot->get(plib,0); // search PACKAGE only in Top
+  if ((pl!=NULL)
+  &&(IDTYP(pl)==PACKAGE_CMD))
   {
-    if (BVERBOSE(V_LOAD_LIB)) Warn( "(builtin) %s already loaded", newlib);
-    omFree(plib);
-    return FALSE;
+    if(IDPACKAGE(pl)->language==LANG_C)
+    {
+      if (BVERBOSE(V_LOAD_LIB)) Warn( "(builtin) %s already loaded", newlib);
+      omFree(plib);
+      return FALSE;
+    }
+  }
+  else
+  {
+    pl = enterid( plib,0, PACKAGE_CMD, &IDROOT, TRUE );
+    IDPACKAGE(pl)->libname=omStrDup(newlib);
   }
-
-  pl = enterid( plib,0, PACKAGE_CMD, &IDROOT,
-                TRUE );
   IDPACKAGE(pl)->language = LANG_C;
-  IDPACKAGE(pl)->libname=omStrDup(newlib);
 
   IDPACKAGE(pl)->handle=(void *)NULL;
   SModulFunctions sModulFunctions;
@@ -1191,7 +1256,7 @@ void module_help_main(const char *newlib,const char *help)
   {
     package s=currPack;
     currPack=IDPACKAGE(pl);
-    idhdl h=enterid(omStrDup("info"),0,STRING_CMD,&IDROOT,FALSE);
+    idhdl h=enterid("info",0,STRING_CMD,&IDROOT,FALSE);
     IDSTRING(h)=omStrDup(help);
     currPack=s;
   }
@@ -1210,22 +1275,20 @@ void module_help_proc(const char *newlib,const char *p, const char *help)
     buff[255]='\0';
     strncpy(buff,p,255);
     strncat(buff,"_help",255-strlen(p));
-    idhdl h=enterid(omStrDup(buff),0,STRING_CMD,&IDROOT,FALSE);
+    idhdl h=enterid(buff,0,STRING_CMD,&IDROOT,FALSE);
     IDSTRING(h)=omStrDup(help);
     currPack=s;
   }
 }
 /*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
 
+#ifdef HAVE_DYNAMIC_LOADING
 // loads a dynamic module from the binary path and returns a named function
 // returns NULL, if something fails
 void* binary_module_function(const char* newlib, const char* funcname)
 {
   void* result = NULL;
 
-#if defined(HAVE_STATIC) || !defined(HAVE_DYNAMIC_LOADING)
-  WerrorS("static version can not load function from dynamic modules");
-#else
   const char* bin_dir = feGetResource('b');
   if (!bin_dir)  { return NULL; }
 
@@ -1240,11 +1303,10 @@ void* binary_module_function(const char* newlib, const char* funcname)
   }
   result = dynl_sym(openlib, funcname);
   if (!result) Werror("%s: %s\n", funcname, dynl_error());
-#endif
 
   return result;
 }
-
+#endif
 
 /*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
 char mytoupper(char c)
@@ -1271,10 +1333,12 @@ char *iiConvName(const char *libname)
   char *tmpname = omStrDup(libname);
   char *p = strrchr(tmpname, DIR_SEP);
   char *r;
-  if(p==NULL) p = tmpname;
-  else p++;
-  r = (char *)strchr(p, '.');
-  if( r!= NULL) *r = '\0';
+  if(p==NULL) p = tmpname; else p++;
+  // p is now the start of the file name (without path)
+  r=p;
+  while(isalnum(*r)||(*r=='_')) r++;
+  // r point the the end of the main part of the filename
+  *r = '\0';
   r = omStrDup(p);
   *r = mytoupper(*r);
   // printf("iiConvName: '%s' '%s' => '%s'\n", libname, tmpname, r);
@@ -1309,12 +1373,12 @@ void piShowProcList()
         Print( "%d %-15s  %20s ", proc->is_static ? 1 : 0, proc->libname,
                proc->procname);
       if(proc->language==LANG_SINGULAR)
-        Print("line %4d,%-5ld  %4d,%-5ld  %4d,%-5ld\n",
-              proc->data.s.proc_lineno, proc->data.s.proc_start,
+        Print("line %-5ld  %4d,%-5ld  %4d,%-5ld\n",
+              proc->data.s.proc_start,
               proc->data.s.body_lineno, proc->data.s.body_start,
               proc->data.s.example_lineno, proc->data.s.example_start);
       else if(proc->language==LANG_C)
-        Print("type: object\n");
+        PrintS("type: object\n");
     }
   }
 }
@@ -1349,7 +1413,7 @@ void libstack::push(const char */*p*/, char *libn)
       ls->next = this;
       ls->libname = omStrDup(libn);
       ls->to_be_done = TRUE;
-      if(this != NULL) ls->cnt = this->cnt+1; else ls->cnt = 0;
+      if(library_stack != NULL) ls->cnt = library_stack->cnt+1; else ls->cnt = 0;
       library_stack = ls;
     }
   }
