@@ -7,57 +7,48 @@
  ***************************************************************/
 #define TRANSEXT_PRIVATES 1 /* allow access to transext internals */
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/intvec.h>
-#include <misc/options.h>
+#include "misc/intvec.h"
+#include "misc/options.h"
 
-#include <reporter/si_signals.h>
-#include <reporter/s_buff.h>
+#include "reporter/si_signals.h"
+#include "reporter/s_buff.h"
 
-#include <coeffs/bigintmat.h>
-#include <coeffs/longrat.h>
+#include "coeffs/bigintmat.h"
+#include "coeffs/longrat.h"
 
-#include <polys/monomials/ring.h>
-#include <polys/monomials/p_polys.h>
-#include <polys/ext_fields/transext.h>
-#include <polys/simpleideals.h>
-#include <polys/matpol.h>
+#include "polys/monomials/ring.h"
+#include "polys/monomials/p_polys.h"
+#include "polys/ext_fields/transext.h"
+#include "polys/simpleideals.h"
+#include "polys/matpol.h"
 
-#include <kernel/oswrapper/timer.h>
-#include <kernel/oswrapper/feread.h>
-#include <kernel/oswrapper/rlimit.h>
+#include "kernel/oswrapper/timer.h"
+#include "kernel/oswrapper/feread.h"
+#include "kernel/oswrapper/rlimit.h"
 
-#include <Singular/tok.h>
-#include <Singular/ipid.h>
-#include <Singular/ipshell.h>
-#include <Singular/subexpr.h>
-#include <Singular/links/silink.h>
-#include <Singular/cntrlc.h>
-#include <Singular/lists.h>
-#include <Singular/blackbox.h>
-#include <Singular/links/ssiLink.h>
+#include "Singular/tok.h"
+#include "Singular/ipid.h"
+#include "Singular/ipshell.h"
+#include "Singular/subexpr.h"
+#include "Singular/links/silink.h"
+#include "Singular/cntrlc.h"
+#include "Singular/lists.h"
+#include "Singular/blackbox.h"
+#include "Singular/links/ssiLink.h"
 
 #ifdef HAVE_SIMPLEIPC
-#include <Singular/links/simpleipc.h>
+#include "Singular/links/simpleipc.h"
 #endif
 
-#include <stdio.h>
-#include <fcntl.h>
 #include <errno.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <signal.h>
 #include <sys/types.h>          /* for portability */
-#include <sys/select.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
 #include <ctype.h>   /*for isdigit*/
 #include <netdb.h>
-#include <sys/wait.h>
-#include <time.h>
+#include <netinet/in.h> /* for htons etc.*/
 
 #define SSI_VERSION 10
 // 5->6: changed newstruct representation
@@ -94,7 +85,7 @@ BOOLEAN ssiSetCurrRing(const ring r) /* returned: not accepted */
       h=IDROOT->get(name, 0);
       if (h==NULL)
       {
-        h=enterid(omStrDup(name),0,RING_CMD,&IDROOT,FALSE);
+        h=enterid(name,0,RING_CMD,&IDROOT,FALSE);
         IDRING(h)=r;
         r->ref++;
         break;
@@ -575,7 +566,7 @@ poly ssiReadPoly_R(const ssiInfo *D, const ring r)
   for(l=0;l<n;l++) // read n terms
   {
 // coef,comp.exp1,..exp N
-    p=p_Init(r);
+    p=p_Init(r,r->PolyBin);
     pSetCoeff0(p,ssiReadNumber_CF(D,r->cf));
     int d;
     d=s_readint(D->f_read);
@@ -1446,13 +1437,16 @@ BOOLEAN ssiWrite(si_link l, leftv data)
     void *dd=data->Data();
     attr *aa=data->Attribute();
     BOOLEAN with_attr=FALSE;
-    if (((*aa)!=NULL)||(data->flag!=0))
+    if ((aa!=NULL) && ((*aa)!=NULL))
     {
       attr a=*aa;
       int n=0;
       while(a!=NULL) { n++; a=a->next;}
       fprintf(d->f_write,"21 %d %d ",data->flag,n);
-      a=*aa;
+    }
+    else if (data->flag!=0)
+    {
+      fprintf(d->f_write,"21 %d 0 ",data->flag);
     }
     if ((dd==NULL) && (data->name!=NULL) && (tt==0)) tt=DEF_CMD;
       // return pure undefined names as def
@@ -1823,7 +1817,7 @@ int ssiBatch(const char *host, const char * port)
   if (slOpen(l,SI_LINK_OPEN,NULL)) return 1;
   SI_LINK_SET_RW_OPEN_P(l);
 
-  idhdl id = enterid(omStrDup("link_ll"), 0, LINK_CMD, &IDROOT, FALSE);
+  idhdl id = enterid("link_ll", 0, LINK_CMD, &IDROOT, FALSE);
   IDLINK(id) = l;
 
   loop
