@@ -10,22 +10,22 @@
 
 
 
-#include <kernel/mod2.h>
-#include <Singular/tok.h>
+#include "kernel/mod2.h"
+#include "Singular/tok.h"
 //#include "ipid.h"
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
-#include <Singular/attrib.h>
-#include <Singular/ipshell.h>
-#include <misc/intvec.h>
-#include <Singular/lists.h>
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
+#include "Singular/attrib.h"
+#include "Singular/ipshell.h"
+#include "misc/intvec.h"
+#include "Singular/lists.h"
 
 omBin slists_bin = omGetSpecBin(sizeof(slists));
 
 int lSize(lists L)
 {
   int n=L->nr;
-   while ((n>=0)&&((L->m[n].rtyp==DEF_CMD)||(L->m[n].rtyp==0))) n--;
+  while ((n>=0)&&((L->m[n].rtyp==DEF_CMD)||(L->m[n].rtyp==0))) n--;
   return n;
 }
 
@@ -199,15 +199,16 @@ BOOLEAN lDelete(leftv res, leftv u, leftv v)
 BOOLEAN lRingDependend(lists L)
 {
   if (L==NULL) return FALSE;
-  int i=0;
-  while (i<=L->nr)
+  int i=L->nr;
+  while (i>=0)
   {
-    if ((BEGIN_RING<L->m[i].rtyp)
-    && (L->m[i].rtyp<END_RING))
+    REGISTER int t=L->m[i].rtyp;
+    if ((BEGIN_RING<t /*L->m[i].rtyp*/)
+    && (/*L->m[i].rtyp*/ t<END_RING))
       return TRUE;
-    if ((L->m[i].rtyp==LIST_CMD)&&lRingDependend((lists)L->m[i].data))
+    if ((/*L->m[i].rtyp*/ t==LIST_CMD)&&lRingDependend((lists)L->m[i].data))
       return TRUE;
-    i++;
+    i--;
   }
   return FALSE;
 }
@@ -215,6 +216,7 @@ BOOLEAN lRingDependend(lists L)
 lists liMakeResolv(resolvente r, int length, int reallen,
   int typ0, intvec ** weights, int add_row_shift)
 {
+  // re-uses r, weights[i]
   lists L=(lists)omAlloc0Bin(slists_bin);
   if (length<=0)
   {
@@ -264,7 +266,7 @@ lists liMakeResolv(resolvente r, int length, int reallen,
         L->m[i].data=(void *)r[i];
         if ((weights!=NULL) && (weights[i]!=NULL))
         {
-          intvec *w=ivCopy(weights[i]);
+          intvec *w=weights[i];
           (*w) += add_row_shift;
           atSet((idhdl)&L->m[i],omStrDup("isHomog"),w,INTVEC_CMD);
           weights[i] = NULL;
@@ -274,13 +276,14 @@ lists liMakeResolv(resolvente r, int length, int reallen,
       else
       {
         // should not happen:
-        Warn("internal NULL in resolvente");
+        WarnS("internal NULL in resolvente");
         L->m[i].data=(void *)idInit(1,1);
       }
       #endif
       i++;
     }
     omFreeSize((ADDRESS)r,oldlength*sizeof(ideal));
+    if (weights!=NULL) omFreeSize(weights,oldlength*sizeof(intvec*));
     if (i==0)
     {
       L->m[0].rtyp=typ0;
@@ -354,7 +357,7 @@ resolvente liFindRes(lists L, int * len, int *typ0,intvec *** weights)
   int j=0;
   while ((j<i) && hom_complex)
   {
-    hom_complex = hom_complex && (w[i]!=NULL);
+    hom_complex = hom_complex && (w[j]!=NULL);
     j++;
   }
   if ((!hom_complex) || (weights==NULL))
