@@ -13,28 +13,30 @@
 // include header files
 #define PLURAL_INTERNAL_DECLARATIONS 1
 
-#include <kernel/mod2.h>
-#include <misc/auxiliary.h>
-#include <misc/sirandom.h>
+#include "kernel/mod2.h"
+#include "misc/sirandom.h"
 
-#include <reporter/si_signals.h>
+#include "omalloc/omalloc.h"
+#include "misc/mylimits.h"
 
-#include <factory/factory.h>
+#include "reporter/si_signals.h"
 
-#include <coeffs/si_gmp.h>
-#include <coeffs/coeffs.h>
-#include <coeffs/OPAE.h>
-#include <coeffs/OPAEQ.h>
-#include <coeffs/OPAEp.h>
-#include <coeffs/flintcf_Q.h>
-#include <coeffs/flintcf_Zn.h>
+#include "factory/factory.h"
 
-#include <polys/ext_fields/algext.h>
-#include <polys/ext_fields/transext.h>
-#include <polys/nc/gb_hack.h>
+#include "coeffs/si_gmp.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/OPAE.h"
+#include "coeffs/OPAEQ.h"
+#include "coeffs/OPAEp.h"
+#include "coeffs/flintcf_Q.h"
+#include "coeffs/flintcf_Zn.h"
+
+#include "polys/ext_fields/algext.h"
+#include "polys/ext_fields/transext.h"
+#include "polys/nc/gb_hack.h"
 
 #ifdef HAVE_SIMPLEIPC
-#include <Singular/links/simpleipc.h>
+#include "Singular/links/simpleipc.h"
 #endif
 
 #include "misc_ip.h"
@@ -42,6 +44,42 @@
 #include "feOpt.h"
 #include "links/silink.h"
 #include "mod_lib.h"
+#include "Singular/distrib.h"
+
+#include "misc/options.h"
+#include "misc/intvec.h"
+
+#include "polys/monomials/ring.h"
+#include "polys/templates/p_Procs.h"
+
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/oswrapper/timer.h"
+#include "resources/feResource.h"
+#include "kernel/oswrapper/feread.h"
+
+#include "subexpr.h"
+#include "cntrlc.h"
+#include "ipshell.h"
+
+#include "fehelp.h"
+
+#ifdef HAVE_READLINE
+  #ifdef READLINE_READLINE_H_OK
+    #include <readline/readline.h>
+  #endif
+  #ifndef RL_VERSION_MAJOR
+    #define RL_VERSION_MAJOR 0
+  #endif
+#endif
+
+#ifdef HAVE_NTL
+#include <NTL/version.h>
+#include <NTL/tools.h>
+#ifdef NTL_CLIENT
+NTL_CLIENT
+#endif
+#endif
+
 
 static FORCE_INLINE void number2mpz(number n, mpz_t m){ number2mpz(n, coeffs_BIGINT, m); }
 static FORCE_INLINE number mpz2number(mpz_t m){ return mpz2number(m, coeffs_BIGINT); }
@@ -106,7 +144,7 @@ static int factor_using_division (mpz_t t, unsigned int limit,lists primes, int
   loop
   {
     mpz_tdiv_qr_ui (q, r, t, 3);
-    if (mpz_cmp_ui (r, 0) != 0)
+    if (mpz_sgn1 (r) != 0)
         break;
     mpz_set (t, q);
     f++;
@@ -120,7 +158,7 @@ static int factor_using_division (mpz_t t, unsigned int limit,lists primes, int
   loop
   {
     mpz_tdiv_qr_ui (q, r, t, 5);
-    if (mpz_cmp_ui (r, 0) != 0)
+    if (mpz_sgn1 (r) != 0)
         break;
     mpz_set (t, q);
     f++;
@@ -138,7 +176,7 @@ static int factor_using_division (mpz_t t, unsigned int limit,lists primes, int
   while (mpz_cmp_ui (t, 1) != 0)
   {
     mpz_tdiv_qr_ui (q, r, t, f);
-    if (mpz_cmp_ui (r, 0) != 0)
+    if (mpz_sgn1 (r) != 0)
     {
       f += addv[ai];
       if (mpz_cmp_ui (t, f) < 0)
@@ -186,10 +224,10 @@ static void factor_using_pollard_rho (mpz_t n, unsigned long a, lists primes, in
 
   mpz_init (t1);
   mpz_init (t2);
-  mpz_init_set_si (last_f, 0);
-  mpz_init_set_si (y, 2);
-  mpz_init_set_si (x, 2);
-  mpz_init_set_si (x1, 2);
+  mpz_init_set_ui (last_f, 0);
+  mpz_init_set_ui (y, 2);
+  mpz_init_set_ui (x, 2);
+  mpz_init_set_ui (x1, 2);
   mpz_init_set_ui (P, 1);
   k = 1;
   l = 1;
@@ -381,27 +419,6 @@ lists primeFactorisation(const number n, const int pBound)
   return L;
 }
 
-#include <omalloc/omalloc.h>
-#include <misc/mylimits.h>
-
-#include <misc/options.h>
-#include <misc/intvec.h>
-
-#include <polys/monomials/ring.h>
-#include <polys/templates/p_Procs.h>
-
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/oswrapper/timer.h>
-#include <resources/feResource.h>
-#include <kernel/oswrapper/feread.h>
-
-#include "subexpr.h"
-#include "cntrlc.h"
-#include "ipid.h"
-#include "ipshell.h"
-
-#include "fehelp.h"
-
 #ifdef HAVE_STATIC
 #undef HAVE_DYN_RL
 #endif
@@ -428,14 +445,6 @@ lists primeFactorisation(const number n, const int pBound)
 *}
 */
 
-#include <string.h>
-#include <unistd.h>
-#include <stdio.h>
-#include <stddef.h>
-#include <stdlib.h>
-#include <time.h>
-
-
 void singular_example(char *str)
 {
   assume(str!=NULL);
@@ -545,6 +554,7 @@ const struct soptionStruct optionStruct[]=
 
 const struct soptionStruct verboseStruct[]=
 {
+  {"assign_none",Sy_bit(V_ASSIGN_NONE),~Sy_bit(V_ASSIGN_NONE)},
   {"mem",      Sy_bit(V_SHOW_MEM),  ~Sy_bit(V_SHOW_MEM)   },
   {"yacc",     Sy_bit(V_YACC),      ~Sy_bit(V_YACC)       },
   {"redefine", Sy_bit(V_REDEFINE),  ~Sy_bit(V_REDEFINE)   },
@@ -619,9 +629,7 @@ BOOLEAN setOption(leftv res, leftv v)
 #if 0
         if (TEST_OPT_INTSTRATEGY && (currRing!=NULL)
         && rField_has_simple_inverse()
-#ifdef HAVE_RINGS
         && !rField_is_Ring(currRing)
-#endif
         ) {
           si_opt_1 &=~Sy_bit(OPT_INTSTRATEGY);
         }
@@ -647,13 +655,11 @@ BOOLEAN setOption(leftv res, leftv v)
             si_opt_1 &= ~Sy_bit(OPT_REDTHROUGH);
         }
         else
-          Warn("cannot set option");
+          WarnS("cannot set option");
 #if 0
         if (TEST_OPT_INTSTRATEGY && (currRing!=NULL)
         && rField_has_simple_inverse()
-#ifdef HAVE_RINGS
         && !rField_is_Ring(currRing)
-#endif
         ) {
           test &=~Sy_bit(OPT_INTSTRATEGY);
         }
@@ -668,7 +674,7 @@ BOOLEAN setOption(leftv res, leftv v)
           si_opt_1 &= optionStruct[i].resetval;
         }
         else
-          Warn("cannot clear option");
+          WarnS("cannot clear option");
         goto okay;
       }
     }
@@ -775,12 +781,21 @@ extern "C"
 }
 #endif
 
+#ifndef MAKE_DISTRIBUTION
+const char *singular_date=__DATE__ " " __TIME__;
+#endif
+
 char * versionString(/*const bool bShowDetails = false*/ )
 {
   StringSetS("");
   StringAppend("Singular for %s version %s (%d, %d bit) %s #%s",
                S_UNAME, VERSION, // SINGULAR_VERSION,
-               SINGULAR_VERSION, SIZEOF_VOIDP*8, singular_date, GIT_VERSION);
+               SINGULAR_VERSION, sizeof(void*)*8,
+#ifdef MAKE_DISTRIBUTION
+               VERSION_DATE, GIT_VERSION);
+#else
+               singular_date, GIT_VERSION);
+#endif
   StringAppendS("\nwith\n\t");
 
 #if defined(mpir_version)
@@ -798,14 +813,19 @@ char * versionString(/*const bool bShowDetails = false*/ )
 #ifdef HAVE_FLINT
               StringAppend("FLINT(%s),",version);
 #endif
-              StringAppend("factory(%s),\n\t", factoryVersion);
+              StringAppendS("factory(" FACTORYVERSION "),\n\t");
+#ifdef XMEMORY_H
+              StringAppendS("xalloc,");
+#else
+              StringAppendS("omalloc,");
+#endif
 #if defined(HAVE_DYN_RL)
               if (fe_fgets_stdin==fe_fgets_dummy)
                 StringAppendS("no input,");
               else if (fe_fgets_stdin==fe_fgets)
                 StringAppendS("fgets,");
               if (fe_fgets_stdin==fe_fgets_stdin_drl)
-                StringAppendS("dynamic readline,");
+                StringAppend("dynamic readline%d),",RL_VERSION_MAJOR);
               #ifdef HAVE_FEREAD
               else if (fe_fgets_stdin==fe_fgets_stdin_emu)
                 StringAppendS("emulated readline,");
@@ -814,7 +834,7 @@ char * versionString(/*const bool bShowDetails = false*/ )
                 StringAppendS("unknown fgets method,");
 #else
   #if defined(HAVE_READLINE) && !defined(FEREAD)
-              StringAppendS("static readline,");
+              StringAppend("static readline(%d),",RL_VERSION_MAJOR);
   #else
     #ifdef HAVE_FEREAD
               StringAppendS("emulated readline,");
@@ -838,9 +858,6 @@ char * versionString(/*const bool bShowDetails = false*/ )
 #if YYDEBUG
               StringAppendS("YYDEBUG=1,");
 #endif
-#ifdef HAVE_ASSUME
-             StringAppendS("ASSUME,");
-#endif
 #ifdef MDEBUG
               StringAppend("MDEBUG=%d,",MDEBUG);
 #endif
@@ -862,6 +879,7 @@ char * versionString(/*const bool bShowDetails = false*/ )
 #ifdef KDEBUG
               StringAppendS("KDEBUG,");
 #endif
+              StringAppendS("\n\t");
 #ifdef __OPTIMIZE__
               StringAppendS("CC:OPTIMIZE,");
 #endif
@@ -871,6 +889,22 @@ char * versionString(/*const bool bShowDetails = false*/ )
 #ifdef __NO_INLINE__
               StringAppendS("CC:NO_INLINE,");
 #endif
+#ifdef HAVE_GENERIC_ADD
+              StringAppendS("GenericAdd,");
+#else
+              StringAppendS("AvoidBranching,");
+#endif
+#ifdef HAVE_GENERIC_MULT
+              StringAppendS("GenericMult,");
+#else
+              StringAppendS("TableMult,");
+#endif
+#ifdef HAVE_INVTABLE
+              StringAppendS("invTable,");
+#else
+              StringAppendS("no invTable,");
+#endif
+              StringAppendS("\n\t");
 #ifdef HAVE_EIGENVAL
               StringAppendS("eigenvalues,");
 #endif
@@ -964,8 +998,7 @@ void listall(int showproc)
           else PrintS("   ");
           Print("::%s, typ %s level %d data %lx",
                  IDID(hh),Tok2Cmdname(IDTYP(hh)),IDLEV(hh),(long)IDDATA(hh));
-          if ((IDTYP(hh)==RING_CMD)
-          || (IDTYP(hh)==QRING_CMD))
+          if (IDTYP(hh)==RING_CMD)
             Print(" ref: %d\n",IDRING(hh)->ref);
           else
             PrintLn();
@@ -980,7 +1013,6 @@ void listall(int showproc)
           IDID(hh),Tok2Cmdname(IDTYP(hh)),IDLEV(hh),(long)IDDATA(hh));
         else
         if ((IDTYP(hh)==RING_CMD)
-        || (IDTYP(hh)==QRING_CMD)
         || (IDTYP(hh)==PACKAGE_CMD))
         {
           Print("====== %s ==============\n",IDID(hh));
@@ -990,7 +1022,7 @@ void listall(int showproc)
             if (showproc || (IDTYP(h2)!=PROC_CMD))
             {
               if ((IDDATA(h2)==(void *)currRing)
-              && ((IDTYP(h2)==RING_CMD)||(IDTYP(h2)==QRING_CMD)))
+              && (IDTYP(h2)==RING_CMD))
                 PrintS("(R)");
               else if (IDDATA(h2)==(void *)currPack) PrintS("(P)");
               else PrintS("   ");
@@ -1026,7 +1058,9 @@ void checkall()
       {
         if (IDTYP(hh)==PACKAGE_CMD)
         {
-          idhdl h2=IDPACKAGE(hh)->idroot;
+          idhdl h2=NULL;
+          if (IDPACKAGE(hh)!=NULL)
+            h2=IDPACKAGE(hh)->idroot;
           if (IDPACKAGE(hh)!=basePack)
           {
             while (h2!=NULL)
@@ -1046,10 +1080,6 @@ void checkall()
 }
 #endif
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
 extern "C"
 int singular_fstat(int fd, struct stat *buf)
 {
@@ -1080,7 +1110,11 @@ void m2_end(int i)
       {
         while (sem_acquired[j] > 0)
         {
+#if PORTABLE_SEMAPHORES
+          sem_post(semaphore[j]->sig);
+#else
           sem_post(semaphore[j]);
+#endif
           sem_acquired[j]--;
         }
       }
@@ -1130,6 +1164,9 @@ void m2_end(int i)
     {
       if (i<=0)
       {
+        //extern long all_farey;
+        //extern long farey_cnt;
+        //if (all_farey!=0L) printf("farey:%ld, cnt=%ld\n",all_farey,farey_cnt);
         if (TEST_V_QUIET)
         {
           if (i==0)
@@ -1155,8 +1192,6 @@ void m2_end(int i)
 }
 }
 
-const char *singular_date=__DATE__ " " __TIME__;
-
 extern "C"
 {
   void omSingOutOfMemoryFunc()
@@ -1169,7 +1204,7 @@ extern "C"
   }
 }
 
-#ifdef SINGULAR_4_1
+#ifdef SINGULAR_4_2
 static n_coeffType n_pAE=n_unknown;
 static BOOLEAN ii_pAE_init(leftv res,leftv a)
 {
@@ -1185,6 +1220,7 @@ static BOOLEAN ii_pAE_init(leftv res,leftv a)
     return FALSE;
   }
 }
+#endif
 #ifdef HAVE_FLINT
 static n_coeffType n_FlintZn=n_unknown;
 static BOOLEAN ii_FlintZn_init(leftv res,leftv a)
@@ -1207,7 +1243,67 @@ static BOOLEAN ii_FlintZn_init(leftv res,leftv a)
   }
 }
 #endif
-#endif
+
+static BOOLEAN iiFloat(leftv res, leftv pnn)
+{
+  short float_len=3;
+  short float_len2=SHORT_REAL_LENGTH;
+  coeffs cf=NULL;
+  if ((pnn!=NULL) && (pnn->Typ()==INT_CMD))
+  {
+    float_len=(int)(long)pnn->Data();
+    float_len2=float_len;
+    pnn=pnn->next;
+    if ((pnn!=NULL) && (pnn->Typ()==INT_CMD))
+    {
+      float_len2=(int)(long)pnn->Data();
+      pnn=pnn->next;
+    }
+  }
+  if (float_len2 <= (short)SHORT_REAL_LENGTH)
+       cf=nInitChar(n_R, NULL);
+  else // longR or longC?
+  {
+    LongComplexInfo param;
+    param.float_len = si_min (float_len, 32767);
+    param.float_len2 = si_min (float_len2, 32767);
+    cf = nInitChar(n_long_R, (void*)&param);
+  }
+  res->rtyp=CRING_CMD;
+  res->data=cf;
+  return cf==NULL;
+}
+static BOOLEAN iiCrossProd(leftv res, leftv args)
+{
+  leftv h=args;
+  coeffs *c=NULL;
+  coeffs cf=NULL;
+  int i=0;
+  if (h==NULL) goto crossprod_error;
+  while (h!=NULL)
+  {
+    if (h->Typ()!=CRING_CMD) goto crossprod_error;
+    i++;
+    h=h->next;
+  }
+  c=(coeffs*)omAlloc0((i+1)*sizeof(coeffs));
+  h=args;
+  i=0;
+  while (h!=NULL)
+  {
+    c[i]=(coeffs)h->CopyD();
+    i++;
+    h=h->next;
+  }
+  cf=nInitChar(n_nTupel,c);
+  res->data=cf;
+  res->rtyp=CRING_CMD;
+  return FALSE;
+
+  crossprod_error:
+    WerrorS("expected `crossprod(coeffs, ...)`");
+    return TRUE;
+}
 /*2
 * initialize components of Singular
 */
@@ -1222,6 +1318,14 @@ void siInit(char *name)
   Off(SW_USE_NTL_SORT); // may be changed by an command line option
   factoryError=WerrorS;
 
+// NTL error handling (>= 9.3.0)
+#ifdef HAVE_NTL
+#if (((NTL_MAJOR_VERSION==9)&&(NTL_MINOR_VERSION>=3))||(NTL_MAJOR_VERSION>=10))
+  ErrorMsgCallback=WerrorS;
+  ErrorCallback=HALT;
+#endif
+#endif
+
 // memory initialization: -----------------------------------------------
     om_Opts.OutOfMemoryFunc = omSingOutOfMemoryFunc;
 #ifndef OM_NDEBUG
@@ -1246,9 +1350,9 @@ void siInit(char *name)
   basePack=(package)omAlloc0(sizeof(*basePack));
   currPack=basePack;
   idhdl h;
-  h=enterid("Top", 0, PACKAGE_CMD, &IDROOT, TRUE);
-  IDPACKAGE(h)->language = LANG_TOP;
+  h=enterid("Top", 0, PACKAGE_CMD, &IDROOT, FALSE);
   IDPACKAGE(h)=basePack;
+  IDPACKAGE(h)->language = LANG_TOP;
   currPackHdl=h;
   basePackHdl=h;
 
@@ -1258,7 +1362,13 @@ void siInit(char *name)
    // def HAVE_POLYEXTENSIONS
   if(TRUE)
   {
-    n_coeffType type = nRegister(n_algExt, naInitChar);
+    n_coeffType type;
+    #ifdef SINGULAR_4_2
+    type = nRegister(n_polyExt, n2pInitChar);
+    assume(type == n_polyExt);
+    #endif
+
+    type = nRegister(n_algExt, naInitChar);
     assume(type == n_algExt);
 
     type = nRegister(n_transExt, ntInitChar);
@@ -1285,7 +1395,7 @@ void siInit(char *name)
 // singular links: --------------------------------------------------
   slStandardInit();
   myynest=0;
-// semapohore 0 -----------------------------------------------------
+// how many processes ? -----------------------------------------------------
   int cpus=2;
   int cpu_n;
   #ifdef _SC_NPROCESSORS_ONLN
@@ -1294,29 +1404,34 @@ void siInit(char *name)
   if ((cpu_n=sysconf(_SC_NPROCESSORS_CONF))>cpus) cpus=cpu_n;
   #endif
   feSetOptValue(FE_OPT_CPUS, cpus);
+// how many threads ? -----------------------------------------------------
+  feSetOptValue(FE_OPT_THREADS, cpus);
 
-#ifdef SINGULAR_4_1
 // default coeffs
   {
     idhdl h;
-    h=enterid(omStrDup("QQ"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+    h=enterid("QQ",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
     IDDATA(h)=(char*)nInitChar(n_Q,NULL);
-    h=enterid(omStrDup("ZZ"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+    h=enterid("ZZ",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
     IDDATA(h)=(char*)nInitChar(n_Z,NULL);
-    //h=enterid(omStrDup("RR"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+    iiAddCproc("kernel","crossprod",FALSE,iiCrossProd);
+    iiAddCproc("kernel","Float",FALSE,iiFloat);
+    //h=enterid("RR",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
     //IDDATA(h)=(char*)nInitChar(n_R,NULL);
-    //h=enterid(omStrDup("CC"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+    //h=enterid("CC",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
     //IDDATA(h)=(char*)nInitChar(n_long_C,NULL);
-    n_coeffType t=nRegister(n_unknown,n_AEInitChar);
+    n_coeffType t;
+#ifdef SINGULAR_4_2
+    t=nRegister(n_unknown,n_AEInitChar);
     if (t!=n_unknown)
     {
-      h=enterid(omStrDup("AE"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+      h=enterid("AE",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
       IDDATA(h)=(char*)nInitChar(t,NULL);
     }
     t=nRegister(n_unknown,n_QAEInitChar);
     if (t!=n_unknown)
     {
-      h=enterid(omStrDup("QAE"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+      h=enterid("QAE",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
       IDDATA(h)=(char*)nInitChar(t,NULL);
     }
     n_pAE=nRegister(n_unknown,n_pAEInitChar);
@@ -1324,11 +1439,12 @@ void siInit(char *name)
     {
       iiAddCproc("kernel","pAE",FALSE,ii_pAE_init);
     }
+#endif
     #ifdef HAVE_FLINT
     t=nRegister(n_unknown,flintQ_InitChar);
     if (t!=n_unknown)
     {
-      h=enterid(omStrDup("flint_poly_Q"),0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
+      h=enterid("flint_poly_Q",0/*level*/, CRING_CMD,&(basePack->idroot),FALSE /*init*/,FALSE /*search*/);
       IDDATA(h)=(char*)nInitChar(t,NULL);
     }
     n_FlintZn=nRegister(n_unknown,flintZn_InitChar);
@@ -1338,14 +1454,16 @@ void siInit(char *name)
     }
     #endif
   }
-#endif
 // setting routines for PLURAL QRINGS:
+// allowing to use libpolys without libSingular(kStd)
+#ifdef HAVE_PLURAL
   nc_NF=k_NF;
   gnc_gr_bba=k_gnc_gr_bba;
   gnc_gr_mora=k_gnc_gr_mora;
   sca_bba=k_sca_bba;
   sca_mora=k_sca_mora;
   sca_gr_bba=k_sca_gr_bba;
+#endif
 // loading standard.lib -----------------------------------------------
   if (! feOptValue(FE_OPT_NO_STDLIB))
   {
