@@ -9,23 +9,16 @@
 
 
 
-#include <kernel/mod2.h>
-#include <omalloc/omalloc.h>
+#include "kernel/mod2.h"
+#include "omalloc/omalloc.h"
 
-#include <misc/options.h>
+#include "misc/options.h"
 
-#include <factory/factory.h>
+#include "factory/factory.h"
 
-#include <kernel/oswrapper/feread.h>
-#include <Singular/fevoices.h>
-#include <kernel/oswrapper/timer.h>
-
-// #ifdef HAVE_FANS
-// #include <callgfanlib/bbcone.h>
-// #include <callgfanlib/bbpolytope.h>
-// #include <callgfanlib/bbfan.h>
-// #include <callgfanlib/gitfan.h>
-// #endif
+#include "kernel/oswrapper/feread.h"
+#include "Singular/fevoices.h"
+#include "kernel/oswrapper/timer.h"
 
 #include "ipshell.h"
 #include "cntrlc.h"
@@ -38,28 +31,28 @@
 #include "tok.h"
 #include "fegetopt.h"
 
-#include <Singular/countedref.h>
-#include <Singular/pyobject_setup.h>
+#include "Singular/countedref.h"
+#include "Singular/pyobject_setup.h"
 
 #include <unistd.h>
-#include <string.h>
-#include <stddef.h>
-#include <stdlib.h>
-#include <time.h>
-#include <errno.h>
+#ifdef HAVE_NTL
+#include <NTL/config.h>
+#endif
 
 
 extern int siInit(char *);
 
 int mmInit( void )
 {
-#if defined(OMALLOC_USES_MALLOC) || defined(X_OMALLOC)
+#ifndef X_OMALLOC
+#if defined(OMALLOC_USES_MALLOC)
     /* in mmstd.c, for some architectures freeSize() unconditionally uses the *system* free() */
     /* sage ticket 5344: http://trac.sagemath.org/sage_trac/ticket/5344 */
     /* do not rely on the default in Singular as libsingular may be different */
     mp_set_memory_functions(omMallocFunc,omReallocSizeFunc,omFreeSizeFunc);
 #else
     mp_set_memory_functions(malloc,reallocSize,freeSize);
+#endif
 #endif
   return 1;
 }
@@ -76,6 +69,13 @@ int main(          /* main entry to Singular */
 
   siInit(argv[0]);
   init_signals();
+  #ifdef HAVE_NTL
+  #if NTL_MAJOR_VERSION>=10
+  #ifdef NTL_THREAD_BOOST
+  SetNumThreads(feOptValue(FE_OPT_CPUS));
+  #endif
+  #endif
+  #endif
 
   // parse command line options
   int optc, option_index;
@@ -138,7 +138,7 @@ int main(          /* main entry to Singular */
 " by: W. Decker, G.-M. Greuel, G. Pfister, H. Schoenemann     \\   %s\n"
 "FB Mathematik der Universitaet, D-67653 Kaiserslautern        \\\n"
 , VERSION, VERSION_DATE);
-  if (feOptValue(FE_OPT_NO_SHELL)) Warn("running in restricted mode:"
+  if (feOptValue(FE_OPT_NO_SHELL)) WarnS("running in restricted mode:"
     " shell invocation and links are disallowed");
   }
   else
