@@ -8,8 +8,8 @@
 */
 
 #ifndef UMINUS
-#include <kernel/mod2.h>
-#include <Singular/grammar.h>
+#include "kernel/mod2.h"
+#include "Singular/grammar.h"
 #endif
 
 extern int      yylineno;
@@ -78,6 +78,7 @@ enum {
   FIND_CMD,
   FACSTD_CMD,
   FMD_CMD,
+  FRES_CMD,
   FWALK_CMD,
   FGLM_CMD,
   FGLMQUOT_CMD,
@@ -165,6 +166,7 @@ enum {
   REPART_CMD,
   RES_CMD,
   RESERVEDNAME_CMD,
+  RESTART_CMD,
   RESULTANT_CMD,
   RINGLIST_CMD,
   RING_LIST_CMD,
