@@ -1,24 +1,24 @@
 
 
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 #ifdef HAVE_F5
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/structs.h>
-#include <omalloc/omalloc.h>
-#include <kernel/polys.h>
-#include <polys/monomials/p_polys.h>
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/khstd.h>
-#include <polys/kbuckets.h>
-#include <polys/weight.h>
-#include <misc/intvec.h>
-#include <kernel/polys.h>
-#include <kernel/GBEngine/f5gb.h>
-#include <kernel/GBEngine/f5data.h>
-#include <kernel/GBEngine/f5lists.h>
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/structs.h"
+#include "omalloc/omalloc.h"
+#include "kernel/polys.h"
+#include "polys/monomials/p_polys.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/khstd.h"
+#include "polys/kbuckets.h"
+#include "polys/weight.h"
+#include "misc/intvec.h"
+#include "kernel/polys.h"
+#include "kernel/GBEngine/f5gb.h"
+#include "kernel/GBEngine/f5data.h"
+#include "kernel/GBEngine/f5lists.h"
 
 /**
  * functions working on the class PNode
