@@ -6,36 +6,33 @@
 */
 #define PLURAL_INTERNAL_DECLARATIONS
 
-
-
-
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 #ifdef HAVE_PLURAL
 
 
-#include <omalloc/omalloc.h>
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "omalloc/omalloc.h"
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <polys/weight.h>
-#include <kernel/polys.h>
-#include <polys/monomials/ring.h>
+#include "polys/weight.h"
+#include "kernel/polys.h"
+#include "polys/monomials/ring.h"
 
-#include <polys/nc/gb_hack.h>
-#include <polys/nc/nc.h>
-#include <polys/nc/sca.h>
+#include "polys/nc/gb_hack.h"
+#include "polys/nc/nc.h"
+#include "polys/nc/sca.h"
 
 
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/khstd.h>
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/khstd.h"
 //#include "spolys.h"
 //#include "cntrlc.h"
-#include <kernel/GBEngine/ratgring.h>
-#include <kernel/GBEngine/kutil.h>
+#include "kernel/GBEngine/ratgring.h"
+#include "kernel/GBEngine/kutil.h"
 
-#include <kernel/GBEngine/nc.h>
+#include "kernel/GBEngine/nc.h"
 
 #if 0
 /*3
@@ -109,8 +106,7 @@ int redGrFirst (LObject* h,kStrategy strat)
       }
       if (TEST_OPT_INTSTRATEGY)
       {
-        if (rField_is_Zp_a(currRing)) p_Content(h->p,currRing);
-        else h->pCleardenom();// also does a p_Content
+        h->pCleardenom();// also removes Content
       }
       /*computes the ecart*/
       d = currRing->pLDeg((*h).p,&((*h).length),currRing);
@@ -240,8 +236,7 @@ int redGrRatGB (LObject* h,kStrategy strat)
   reddeg = strat->LazyDegree+d;
   if (!TEST_OPT_INTSTRATEGY)
   {
-    if (rField_is_Zp_a(currRing)) p_Content(h->p,currRing);
-    else h->pCleardenom();// also does a pContentRat
+    h->pCleardenom();// also does a pContentRat
   }
   loop
   {
@@ -277,8 +272,7 @@ int redGrRatGB (LObject* h,kStrategy strat)
         (*h).p=c_p;
         if (!TEST_OPT_INTSTRATEGY)
         {
-          if (rField_is_Zp_a(currRing)) p_Content(h->p,currRing);
-          else h->pCleardenom();// also does a p_Content
+          h->pCleardenom();// also removes Content
         }
 
 #ifdef KDEBUG
@@ -479,8 +473,7 @@ static int nc_redHomog0 (LObject* h,kStrategy strat)
       {
         if (TEST_OPT_INTSTRATEGY)
         {
-          if (rField_is_Zp_a(currRing)) p_Content(h->p,currRing);
-          else h->pCleardenom();// also does a pContent
+          h->pCleardenom();// also removes Content
         }
         if (strat->syzComp!=0)
         {
@@ -503,8 +496,7 @@ static int nc_redHomog0 (LObject* h,kStrategy strat)
       {
         if (TEST_OPT_INTSTRATEGY)
         {
-          if (rField_is_Zp_a(currRing)) p_Content(h->p,currRing);
-          else h->pCleardenom();// also does a p_Content
+          h->pCleardenom();// also removes Content
         }
 /*
 *       (*h).length=pLength0((*h).p);
@@ -579,8 +571,7 @@ static int nc_redLazy (LObject* h,kStrategy strat)
         }
         if (TEST_OPT_INTSTRATEGY)
         {
-          p_Content(h->p,currRing);
-          //pCleardenom(h->p);// also does a p_Content
+          pCleardenom(h->p);// also removes Content
         }
       }
       /*- try to reduce the s-polynomial -*/
@@ -623,8 +614,7 @@ static int nc_redLazy (LObject* h,kStrategy strat)
         if (TEST_OPT_DEBUG) PrintLn();
         if (TEST_OPT_INTSTRATEGY)
         {
-          if (rField_is_Zp_a(currRing)) p_Content(h->p,currRing);
-          else h->pCleardenom();// also does a p_Content
+          h->pCleardenom();// also removes Content
         }
         enterT((*h),strat);
         return 0;
@@ -740,7 +730,7 @@ static int nc_redHoney (LObject*  h,kStrategy strat)
       }
       if (TEST_OPT_INTSTRATEGY)
       {
-        h->pCleardenom();// also does a p_Content
+        h->pCleardenom();// also does remove Content
       }
       /* compute the ecart */
       if (ei <= (*h).ecart)
@@ -805,7 +795,7 @@ static int nc_redHoney (LObject*  h,kStrategy strat)
         if (TEST_OPT_DEBUG) PrintLn();
         if (TEST_OPT_INTSTRATEGY)
         {
-          h->pCleardenom();// also does a p_Content
+          h->pCleardenom();// also does remove Content
         }
         enterT((*h),strat);
         return 0;
@@ -959,7 +949,7 @@ static int nc_redBest (LObject*  h,kStrategy strat)
       {
         if (TEST_OPT_INTSTRATEGY)
         {
-          h->pCleardenom();// also does a p_Content
+          h->pCleardenom();// also removes Content
         }
         enterT((*h),strat);
         return 0;
