@@ -1,24 +1,18 @@
 
 
+#include "kernel/mod2.h"
+#include "omalloc/omalloc.h"
 
+#include "coeffs/numbers.h"
 
-#include <kernel/mod2.h>
-#include <omalloc/omalloc.h>
+#include "polys/monomials/ring.h"
+#include "polys/monomials/p_polys.h"
+#include "polys/kbuckets.h"
 
-#include <coeffs/numbers.h>
-// #include <coeffs/longrat.h>
-
-#include <polys/monomials/ring.h>
-#include <polys/monomials/p_polys.h>
-#include <polys/kbuckets.h>
-
-#include <kernel/ideals.h>
-#include <kernel/polys.h>
-#include <kernel/GBEngine/kutil.h>
-
-// #include "subexpr.h"
-
-#include <kernel/GBEngine/janet.h>
+#include "kernel/ideals.h"
+#include "kernel/polys.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/GBEngine/janet.h"
 
 
 #include <stdio.h>
@@ -83,7 +77,7 @@ int ReducePolyLead(Poly *x,Poly *y)
   if (!x->root || !y->root)
     return 0;
 
-/*  poly b1=pDivide(x->root,y->root);
+/*  poly b1=pMDivide(x->root,y->root);
 
   number gcd=n_Gcd(pGetCoeff(x->root),pGetCoeff(y->root),currRing->cf);
 
@@ -118,8 +112,7 @@ int ReducePolyLead(Poly *x,Poly *y)
 #else
   x->root=ksOldSpolyRed(y->root,x->root,NULL);
 #endif
-//  if (x->root) p_Content(x->root,currRing);
-//  if (x->root) pSimpleContent(x->root,5);
+//  if (x->root) p_SimpleContent(x->root,5,currRing);
 
   return 1;
 }
@@ -129,7 +122,7 @@ int ReducePoly(Poly *x,poly from,Poly *y)
   if (!x->root || !y->root)
     return 0;
 
-/*  poly b1=pDivide(from,y->root);
+/*  poly b1=pMDivide(from,y->root);
 
   number gcd=n_Gcd(pGetCoeff(from),pGetCoeff(y->root),currRing->cf);
 
@@ -175,8 +168,8 @@ void PNF(Poly *p, TreeM *F)
         && (nSize(pGetCoeff(pp))>old_size)
         )
         {
-           //pSimpleContent(pp,2);
-           p_Content(pp,currRing);
+           p_SimpleContent(pp,1,currRing);
+           //p_Content(pp,currRing);
            count=0;
          //  old_size=nSize(pGetCoeff(pp));
         }
@@ -187,8 +180,8 @@ void PNF(Poly *p, TreeM *F)
       temp=temp->next;
    }
 
-  if (done) p_Content(p->root,currRing);
-  //if (done) pSimpleContent(p->root,-1);
+  if (done) p_ContentForGB(p->root,currRing);
+  //if (done) p_SimpleContent(p->root,-1,currRing);
   pTest(p->root);
 }
 
@@ -243,7 +236,8 @@ void NFL(Poly *p, TreeM *F)
     if ((pX == pF) && (pF == phF))
     {
       pLmFree(&f->history);
-      f->history=p_Copy_noCheck(p->history,currRing); /* cf of p->history is NULL */
+      if (p->history!=NULL)
+        f->history=p_Copy_noCheck(p->history,currRing); /* cf of p->history is NULL */
     }
   }
 
@@ -265,7 +259,7 @@ void NFL(Poly *p, TreeM *F)
       if ((count>4) && (3<nSize(pGetCoeff(p->root)))
       && (nSize(pGetCoeff(p->root))>old_size))
       {
-        pSimpleContent(p->root,old_size);
+        p_SimpleContent(p->root,old_size,currRing);
         count=0;
       }
 #else
@@ -298,8 +292,8 @@ void NFL(Poly *p, TreeM *F)
   InitLead(p);
   p->changed=1;
 
-  p_Content(p->root,currRing);
-  //pSimpleContent(p->root,-1);
+  p_ContentForGB(p->root,currRing);
+  //p_SimpleContent(p->root,-1i,currRing);
   pTest(p->root);
 }
 
@@ -314,8 +308,8 @@ int ValidatePoly(Poly *x, TreeM */*F*/)
 
   if (!g)  return 0; //if not - kill him !
 
-  poly lmX=pDivide(x->lead,g->root);
-  pGetCoeff(lmX)=nInit(1);
+  poly lmX=pMDivide(x->lead,g->root);
+  pSetCoeff0(lmX,nInit(1));
 
 /*  if ((f=is_div_(F,lmX)) != NULL)
   {
@@ -391,7 +385,7 @@ void DestroyPoly(Poly *x)
 {
   pDelete(&x->root);
   pLmFree(&x->history);
-  if (x->lead) pDelete(&x->lead);
+  if (x->lead!=NULL) pLmFree(&x->lead);
   GCF(x->mult);
   GCF(x);
 }
@@ -415,7 +409,7 @@ void InitHistory(Poly *p)
 
 void InitLead(Poly *p)
 {
-  if (p->lead) pLmDelete(&p->lead);
+  if (p->lead!=NULL) pLmFree(&p->lead);
   p->lead=pLmInit(p->root);
   p->prolonged=-1;
 }
@@ -498,7 +492,7 @@ void ProlVar(Poly *temp,int i)
     Pr->lead=pLmInit(temp->lead);
     pIncrExp(Pr->lead,i+1);
     pSetm(Pr->lead);
-     InitProl(temp);
+    InitProl(temp);
 
      Pr->changed=0;
 //    pTest(Pr->root);
