@@ -17,13 +17,13 @@
  * (remark: NO_KINLINE is defined by KDEBUG, i.e. in the debug version)
  */
 
-#include <omalloc/omalloc.h>
-#include <misc/options.h>
+#include "omalloc/omalloc.h"
+#include "misc/options.h"
 
-#include <polys/monomials/p_polys.h>
-#include <polys/kbuckets.h>
+#include "polys/monomials/p_polys.h"
+#include "polys/kbuckets.h"
 
-#include <kernel/polys.h>
+#include "kernel/polys.h"
 
 
 #define HAVE_TAIL_BIN
@@ -124,9 +124,10 @@ KINLINE void sTObject::Set(poly p_in, ring r)
   }
   else
   {
-    pp_Test(p_in, currRing, tailRing);
+    p_Test(p_in, currRing);
     p = p_in;
   }
+  pLength=::pLength(p_in);
 }
 
 KINLINE sTObject::sTObject(poly p_in, ring r)
@@ -140,8 +141,9 @@ KINLINE void sTObject::Set(poly p_in, ring c_r, ring t_r)
   if (c_r != t_r)
   {
     assume(c_r == currRing && t_r == tailRing);
-    pp_Test(p_in, currRing, t_r);
+    p_Test(p_in, currRing);
     p = p_in;
+    pLength=::pLength(p_in);
   }
   else
   {
@@ -167,7 +169,7 @@ KINLINE sTObject::sTObject(sTObject* T, int copy)
     }
     else
     {
-      p = p_Copy(p, currRing, tailRing);
+      p = p_Copy(p, currRing);
     }
   }
 }
@@ -182,7 +184,7 @@ KINLINE void sTObject::Delete()
   }
   else
   {
-    p_Delete(&p, currRing, tailRing);
+    p_Delete(&p, currRing);
   }
 }
 
@@ -202,15 +204,16 @@ KINLINE void sTObject::Copy()
   if (t_p != NULL)
   {
     t_p = p_Copy(t_p, tailRing);
-    if (p != NULL)
+    if (p != NULL) /* and t_p!=NULL*/
     {
-      p = p_Head(p, currRing);
-      if (pNext(t_p) != NULL) pNext(p) = pNext(t_p);
+      p = p_LmInit(p, currRing);
+      pGetCoeff(p)=pGetCoeff(t_p);
+      pNext(p) = pNext(t_p);
     }
   }
   else
   {
-    p = p_Copy(p, currRing, tailRing);
+    p = p_Copy(p, currRing);
   }
 }
 
@@ -309,7 +312,8 @@ KINLINE void sTObject::LmDeleteAndIter()
 KINLINE void sTObject::Mult_nn(number n)
 {
   if (t_p != NULL)
-  {    t_p = p_Mult_nn(t_p, n, tailRing);
+  {
+    t_p = p_Mult_nn(t_p, n, tailRing);
     if (p != NULL) pSetCoeff0(p, pGetCoeff(t_p));
   }
   else
@@ -362,7 +366,7 @@ sTObject::ShallowCopyDelete(ring new_tailRing, omBin new_tailBin,
       t_p = NULL;
     }
   }
-  else if (p != NULL)
+  else if (p != NULL) /* && t_p==NULL */
   {
     if (pNext(p) != NULL)
     {
@@ -426,38 +430,38 @@ KINLINE void  sTObject::pCleardenom()
 {
   assume(p != NULL);
   if (TEST_OPT_CONTENTSB)
+  {
+    number n;
+    if (t_p != NULL)
     {
-      number n;
-      if (t_p != NULL)
-        {
-          p_Cleardenom_n(t_p, tailRing, n);
-          pSetCoeff0(p, pGetCoeff(t_p));
-        }
-      else
-        {
-          p_Cleardenom_n(p, currRing, n);
-        }
-      if (!nIsOne(n))
-        {
-          denominator_list denom=(denominator_list)omAlloc(sizeof(denominator_list_s));
-          denom->n=nInvers(n);
-          denom->next=DENOMINATOR_LIST;
-          DENOMINATOR_LIST=denom;
-        }
-      nDelete(&n);
+      p_Cleardenom_n(t_p, tailRing, n);
+      pSetCoeff0(p, pGetCoeff(t_p));
     }
+    else
+    {
+      p_Cleardenom_n(p, currRing, n);
+    }
+    if (!nIsOne(n))
+    {
+      denominator_list denom=(denominator_list)omAlloc(sizeof(denominator_list_s));
+      denom->n=nInvers(n);
+      denom->next=DENOMINATOR_LIST;
+      DENOMINATOR_LIST=denom;
+    }
+    nDelete(&n);
+  }
   else
+  {
+    if (t_p != NULL)
     {
-      if (t_p != NULL)
-      {
-        p_ProjectiveUnique(t_p, tailRing);
-        pSetCoeff0(p, pGetCoeff(t_p));
-      }
-      else
-      {
-        p_ProjectiveUnique(p, currRing);
-      }
+      p_ProjectiveUnique(t_p, tailRing);
+      pSetCoeff0(p, pGetCoeff(t_p));
     }
+    else
+    {
+      p_ProjectiveUnique(p, currRing);
+    }
+  }
 }
 
 KINLINE void sTObject::pNorm() // pNorm seems to be a _bad_ method name...
@@ -563,7 +567,7 @@ KINLINE void sLObject::Tail_Mult_nn(number n)
   {
     poly _p = (t_p != NULL ? t_p : p);
     assume(_p != NULL);
-    pNext(_p) = p_Mult_nn(pNext(_p), n, tailRing);
+    pNext(_p) = __p_Mult_nn(pNext(_p), n, tailRing);
   }
 }
 
@@ -753,7 +757,7 @@ KINLINE long sLObject::pLDeg(BOOLEAN deg_last)
 
   long ldeg;
   ldeg = tailRing->pLDeg(GetLmTailRing(), &length, tailRing);
-#ifdef HAVE_ASSUME
+#ifndef SING_NDEBUG
   if ( pLength == 0)
     p_Last(GetLmTailRing(), pLength, tailRing);
   assume ( pLength == length || rIsSyzIndexRing(currRing));
@@ -876,18 +880,18 @@ KINLINE void    sLObject::T_1_2(const skStrategy* strat,
 KINLINE poly k_LmInit_currRing_2_tailRing(poly p, ring tailRing, omBin tailBin)
 {
 
-  poly np = p_LmInit(p, currRing, tailRing, tailBin);
-  pNext(np) = pNext(p);
-  pSetCoeff0(np, pGetCoeff(p));
-  return np;
+  poly t_p = p_LmInit(p, currRing, tailRing, tailBin);
+  pNext(t_p) = pNext(p);
+  pSetCoeff0(t_p, pGetCoeff(p));
+  return t_p;
 }
 
-KINLINE poly k_LmInit_tailRing_2_currRing(poly p, ring tailRing, omBin lmBin)
+KINLINE poly k_LmInit_tailRing_2_currRing(poly t_p, ring tailRing, omBin lmBin)
 {
-  poly np = p_LmInit(p, tailRing, currRing, lmBin);
-  pNext(np) = pNext(p);
-  pSetCoeff0(np, pGetCoeff(p));
-  return np;
+  poly p = p_LmInit(t_p, tailRing, currRing, lmBin);
+  pNext(p) = pNext(t_p);
+  pSetCoeff0(p, pGetCoeff(t_p));
+  return p;
 }
 
 // this should be made more efficient
@@ -940,8 +944,8 @@ KINLINE BOOLEAN k_GetLeadTerms(const poly p1, const poly p2, const ring p_r,
 
   int i;
   long x;
-  m1 = p_Init(m_r);
-  m2 = p_Init(m_r);
+  m1 = p_Init(m_r,m_r->PolyBin);
+  m2 = p_Init(m_r,m_r->PolyBin);
 
   for (i = p_r->N; i; i--)
   {
@@ -986,9 +990,9 @@ KINLINE void k_GetStrongLeadTerms(const poly p1, const poly p2, const ring leadR
   int e1;
   int e2;
   int s;
-  m1 = p_Init(tailRing);
-  m2 = p_Init(tailRing);
-  lcm = p_Init(leadRing);
+  m1 = p_Init(tailRing,tailRing->PolyBin);
+  m2 = p_Init(tailRing,tailRing->PolyBin);
+  lcm = p_Init(leadRing,leadRing->PolyBin);
 
   for (i = leadRing->N; i>=0; i--)
   {
@@ -1108,17 +1112,6 @@ KINLINE poly redtailBba_Z (poly p,int pos,kStrategy strat)
 }
 #endif
 
-KINLINE poly redtailBba(TObject *T, int pos,kStrategy strat)
-{
-  LObject L;
-  L = *T;
-  poly p = redtailBba(&L, pos, strat, FALSE);
-  *T = L;
-  //kTest_T(T);
-  assume( p == T->p);
-  return p;
-}
-
 KINLINE void clearS (poly p, unsigned long p_sev, int* at, int* k,
                     kStrategy strat)
 {
