@@ -9,21 +9,17 @@
 
 
 
-#include <kernel/mod2.h>
-#include <misc/options.h>
-#include <kernel/GBEngine/kutil.h>
-#include <coeffs/numbers.h>
-#include <polys/monomials/p_polys.h>
-#include <polys/templates/p_Procs.h>
-#include <polys/nc/nc.h>
-#ifdef KDEBUG
-#endif
+#include "kernel/mod2.h"
+#include "misc/options.h"
+#include "kernel/GBEngine/kutil.h"
+#include "coeffs/numbers.h"
+#include "polys/monomials/p_polys.h"
+#include "polys/templates/p_Procs.h"
+#include "polys/nc/nc.h"
 #ifdef HAVE_RINGS
-#include <kernel/polys.h>
+#include "kernel/polys.h"
 #endif
 
-//#define ADIDEBUG 0
-
 #ifdef KDEBUG
 int red_count = 0;
 int create_count = 0;
@@ -517,11 +513,6 @@ int ksReducePolySigRing(LObject* PR,
                  number *coef,
                  kStrategy strat)
 {
-#ifdef ADIDEBUG
-printf("\nksReducePolySig\n");
-pWrite(PR->p);pWrite(PR->sig);
-pWrite(PW->p);pWrite(PW->sig);
-#endif
 #ifdef KDEBUG
   red_count++;
 #ifdef TEST_OPT_DEBUG_RED
@@ -615,9 +606,6 @@ pWrite(PW->p);pWrite(PW->sig);
       //It may happen that now the signature is 0 (drop)
       if(PR->sig == NULL)
       {
-        #ifdef ADIDEBUG
-        printf("\nPossible sigdrop in ksreducepolysig (lost signature)\n");
-        #endif
         strat->sigdrop=TRUE;
       }
       else
@@ -634,9 +622,6 @@ pWrite(PW->p);pWrite(PW->sig);
         }
         if(pLtCmp(PR->sig,origsig) == -1)
         {
-          #ifdef ADIDEBUG
-          printf("\nSigdrop in ksreducepolysig from * to *\n");pWrite(origsig);pWrite(PR->sig);
-          #endif
           strat->sigdrop=TRUE;
         }
       }
@@ -794,17 +779,20 @@ void ksCreateSpoly(LObject* Pair,   poly spNoether,
 
   int l1=0, l2=0;
 
-  if (p_GetComp(p1, currRing)!=p_GetComp(p2, currRing))
+  if (currRing->pCompIndex >= 0)
   {
-    if (p_GetComp(p1, currRing)==0)
+    if (__p_GetComp(p1, currRing)!=__p_GetComp(p2, currRing))
     {
-      co=1;
-      p_SetCompP(p1,p_GetComp(p2, currRing), currRing, tailRing);
-    }
-    else
-    {
-      co=2;
-      p_SetCompP(p2, p_GetComp(p1, currRing), currRing, tailRing);
+      if (__p_GetComp(p1, currRing)==0)
+      {
+        co=1;
+        p_SetCompP(p1,__p_GetComp(p2, currRing), currRing, tailRing);
+      }
+      else
+      {
+        co=2;
+        p_SetCompP(p2, __p_GetComp(p1, currRing), currRing, tailRing);
+      }
     }
   }
 
@@ -1009,7 +997,7 @@ int ksReducePolyTailBound(LObject* PR, TObject* PW, int bound, poly Current, pol
 * creates the leading term of the S-polynomial of p1 and p2
 * do not destroy p1 and p2
 * remarks:
-*   1. the coefficient is 0 (nNew)
+*   1. the coefficient is 0 (p_Init)
 *   1. a) in the case of coefficient ring, the coefficient is calculated
 *   2. pNext is undefined
 */
@@ -1082,9 +1070,7 @@ x2:
           nDelete(&t2);
           pSetCoeff0(m2, t1);
       }
-      else
 #endif
-        nNew(&(pGetCoeff(m2)));
       return m2;
     }
     else
@@ -1134,9 +1120,7 @@ x1:
       nDelete(&lc2);
       nDelete(&t1);
     }
-    else
 #endif
-      nNew(&(pGetCoeff(m1)));
     return m1;
   }
   m1 = p_Init(currRing);
@@ -1191,9 +1175,7 @@ x1:
           nDelete(&lc2);
           nDelete(&t1);
         }
-        else
 #endif
-          nNew(&(pGetCoeff(m1)));
         return m1;
       }
       else
@@ -1207,9 +1189,7 @@ x1:
           nDelete(&lc2);
           nDelete(&t2);
         }
-        else
 #endif
-          nNew(&(pGetCoeff(m2)));
         return m2;
       }
     }
@@ -1239,9 +1219,7 @@ x1:
           nDelete(&t1);
           nDelete(&t2);
       }
-      else
 #endif
-        nNew(&(pGetCoeff(m1)));
       return m1;
     }
     pIter(a1);
