@@ -11,37 +11,33 @@
 // define if buckets should be used
 #define MORA_USE_BUCKETS
 
-//#define ADIDEBUG 0
-//#define ADIDEBUG_NF 0
 #define PRE_INTEGER_CHECK 0
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <polys/weight.h>
-#include <kernel/polys.h>
+#include "polys/weight.h"
+#include "kernel/polys.h"
 
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/khstd.h>
-#include <kernel/combinatorics/stairc.h>
-//#include "cntrlc.h"
-#include <kernel/ideals.h>
-//#include "../Singular/ipid.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/khstd.h"
+#include "kernel/combinatorics/stairc.h"
+#include "kernel/ideals.h"
 
 //#include "ipprint.h"
 
 #ifdef HAVE_PLURAL
-#include <polys/nc/nc.h>
-#include <polys/nc/sca.h>
-#include <kernel/GBEngine/nc.h>
+#include "polys/nc/nc.h"
+#include "polys/nc/sca.h"
+#include "kernel/GBEngine/nc.h"
 #endif
 
-#include <kernel/GBEngine/kInline.h>
+#include "kernel/GBEngine/kInline.h"
 
 
 /* the list of all options which give a warning by test */
@@ -352,49 +348,12 @@ int redRiloc (LObject* h,kStrategy strat)
   int pass = 0;
   long d,reddeg;
 
-
-#ifdef ADIDEBUG_NF
-  int iii;
-  PrintS("\n---------------------------- NEW REDRILOC COMPUTATION ----------------------------\n");
-  PrintS("    The pair h :\n");
-  PrintS("\n      p1 = "); p_Write(h->p1,strat->tailRing);
-  PrintS("\n      p2 = "); p_Write(h->p2,strat->tailRing);
-  PrintS("\n      p  = "); p_Write(h->p,strat->tailRing);
-  PrintS("\n    The actual reducer T is: ");
-  if(strat->tl<0)
-    {PrintS(" Empty.\n");}
-  else
-  {
-    for (iii=0;iii<=strat->tl;iii++)
-    {
-      Print("\n      T[%i] = ",iii);p_Write(strat->T[iii].p,strat->tailRing);
-    }
-  }
-#endif /* ADIDEBUG_NF */
-
   d = h->GetpFDeg()+ h->ecart;
   reddeg = strat->LazyDegree+d;
   h->SetShortExpVector();
-#ifdef ADIDEBUG_NF
-  Print("\n  Searching for a poly in T that divides h (of ecart %i) ...\n",h->ecart);
-#endif
   loop
   {
     j = kFindDivisibleByInT(strat, h);
-#ifdef ADIDEBUG_NF
-    if(j != -1)
-    {
-      ei = strat->T[j].ecart;
-      Print("\n    Found one: T[%i] of ecart %i: ",j,ei);
-      p_Write(strat->T[j].p,strat->tailRing);
-      PrintS("\n    Try to find another with smaller ecart:\n");
-    }
-    else
-    {
-      PrintS("\n    No poly in T divides h.\n");
-    }
-    //getchar();
-#endif
     if (j < 0)
     {
       // over ZZ: cleanup coefficients by complete reduction with monomials
@@ -421,9 +380,6 @@ int redRiloc (LObject* h,kStrategy strat)
 
     ei = strat->T[j].ecart;
     ii = j;
-#ifdef ADIDEBUG_NF
-    iii=ii;
-#endif
     if (ei > h->ecart && ii < strat->tl)
     {
       li = strat->T[j].length;
@@ -452,37 +408,17 @@ int redRiloc (LObject* h,kStrategy strat)
 #endif
         {
           // the polynomial to reduce with is now
-          #ifdef ADIDEBUG_NF
-          printf("\n    Intermidiate one, h.ecart = %i < ecart = %i < ei = %i: ",h->ecart,strat->T[i].ecart, ei);
-          pWrite(strat->T[i].p);
-          #endif
           ii = i;
           ei = strat->T[i].ecart;
           if (ei <= h->ecart) break;
           li = strat->T[i].length;
         }
       }
-
-#ifdef ADIDEBUG_NF
-      if(iii == ii)
-      {
-        PrintS("\n    None was found.\n");
-      }
-      else
-      {
-        Print("\n    A better one (ecart = %i): T[%i] = ",ei,ii);
-        p_Write(strat->T[ii].p,strat->tailRing);
-        PrintLn();
-      }
-#endif
     }
 
     // end of search: have to reduce with pi
     if (ei > h->ecart)
     {
-      #ifdef ADIDEBUG_NF
-      printf("\nHAD TO REDUCE WITH BIGGER ECART!!!\n");
-      #endif
       // It is not possible to reduce h with smaller ecart;
       // if possible h goes to the lazy-set L,i.e
       // if its position in L would be not the last one
@@ -517,9 +453,6 @@ int redRiloc (LObject* h,kStrategy strat)
     // are we done ???
     if (h->IsNull())
     {
-      #ifdef ADIDEBUG_NF
-      printf("\nReduced to 0. Exit\n");
-      #endif
       if (h->lcm!=NULL) pLmDelete(h->lcm);
       h->Clear();
       return 0;
@@ -538,10 +471,6 @@ int redRiloc (LObject* h,kStrategy strat)
     else
       // this has the side effect of setting h->length
       h->ecart = h->pLDeg(strat->LDegLast) - h->GetpFDeg();
-    #ifdef ADIDEBUG_NF
-    printf("\n  Partial Reduced (ecart %i) h = ",h->ecart);p_Write(h->p,strat->tailRing);
-    PrintLn();
-    #endif
     /*- try to reduce the s-polynomial -*/
     pass++;
     d = h->GetpFDeg()+h->ecart;
@@ -854,9 +783,6 @@ static poly redMoraNFRing (poly h,kStrategy strat, int flag)
       if (kModDeg(H.p)>Kstd1_deg) pLmDelete(&H.p);
       if (H.p==NULL) return NULL;
     }
-    #ifdef ADIDEBUG_NF
-    printf("\nSearching for a reducer...\n");
-    #endif
     if (p_LmShortDivisibleBy(strat->T[j].GetLmTailRing(), strat->sevT[j], H.GetLmTailRing(), not_sev, strat->tailRing)
         && (n_DivBy(H.p->coef, strat->T[j].p->coef,strat->tailRing->cf))
         )
@@ -866,9 +792,6 @@ static poly redMoraNFRing (poly h,kStrategy strat, int flag)
       int ei = strat->T[j].ecart;
       int li = strat->T[j].length;
       int ii = j;
-      #ifdef ADIDEBUG_NF
-      printf("\nFound: j = %i, ecart = %i\nTrying to find a better one...\n",j,ei);pWrite(strat->T[j].p);
-      #endif
       /*
       * the polynomial to reduce with (up to the moment) is;
       * pi with ecart ei and length li
@@ -894,10 +817,6 @@ static poly redMoraNFRing (poly h,kStrategy strat, int flag)
           ei = strat->T[j].ecart;
           li = strat->T[j].length;
           ii = j;
-          #ifdef ADIDEBUG_NF
-          printf("\nFound a better one: j = %i, ecart = %i\nTrying to find a better one...\n",j,ei);
-          pWrite(strat->T[j].p);
-          #endif
         }
       }
       /*
@@ -915,9 +834,6 @@ static poly redMoraNFRing (poly h,kStrategy strat, int flag)
         * It is not possible to reduce h with smaller ecart;
         * we have to reduce with bad ecart: H has to enter in T
         */
-        #ifdef ADIDEBUG_NF
-        printf("\nHAVE TO REDUCE IT WITH BIGGER ECART\n");
-        #endif
         doRed(&H,&(strat->T[ii]),TRUE,strat,TRUE);
         if (H.p == NULL)
           return NULL;
@@ -931,10 +847,6 @@ static poly redMoraNFRing (poly h,kStrategy strat, int flag)
         if (H.p == NULL)
           return NULL;
       }
-      #ifdef ADIDEBUG_NF
-      printf("\nAfter the small reduction it looks like this:\n");pWrite(H.p);
-      getchar();
-      #endif
       /*- try to reduce the s-polynomial -*/
       o = H.SetpFDeg();
       if ((flag &2 ) == 0) cancelunit(&H,TRUE);
@@ -1605,12 +1517,6 @@ void kDebugPrint(kStrategy strat);
 
 ideal mora (ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat)
 {
-#ifdef HAVE_RINGS
-#ifdef ADIDEBUG
-int loop_count;
-loop_count = 1;
-#endif
-#endif
   int olddeg = 0;
   int reduc = 0;
   int red_result = 1;
@@ -1673,30 +1579,15 @@ loop_count = 1;
   /*- compute-------------------------------------------*/
   while (strat->Ll >= 0)
   {
-    #ifdef ADIDEBUG
-    printf("\n      ------------------------NEW LOOP\n");
-    printf("\nShdl = \n");
-    for(int iii = 0; iii<= strat->sl; iii++)
-    {
-        printf("S[%i]:",iii);
-        p_Write(strat->S[iii], strat->tailRing);
-    }
-    printf("\n   list   L has %i\n", strat->Ll);
-    int iii;
-    #ifdef ADIDEBUG
-    for(iii = 0; iii<= strat->Ll; iii++)
-    {
-        printf("L[%i]:",iii);
-        pWrite(strat->L[iii].p);
-        pWrite(strat->L[iii].p1);
-        pWrite(strat->L[iii].p2);
-    }
-    #endif
-    getchar();
-    #endif
     #ifdef KDEBUG
     if (TEST_OPT_DEBUG) messageSets(strat);
     #endif
+    if (siCntrlc)
+    {
+      while (strat->Ll >= 0)
+        deleteInL(strat->L,&strat->Ll,strat->Ll,strat);
+      strat->noClearS=TRUE;
+    }
     if (TEST_OPT_DEGBOUND
     && (strat->L[strat->Ll].ecart+strat->L[strat->Ll].GetpFDeg()> Kstd1_deg))
     {
@@ -1760,15 +1651,7 @@ loop_count = 1;
       if (TEST_OPT_PROT)
         message(strat->P.ecart+strat->P.GetpFDeg(),&olddeg,&reduc,strat, red_result);
       // reduce
-      #ifdef ADIDEBUG
-      printf("\nThis is P vor red:\n");p_Write(strat->P.p,strat->tailRing);p_Write(strat->P.p1,strat->tailRing);p_Write(strat->P.p2,strat->tailRing);
-      printf("\nBefore Ll = %i\n", strat->Ll);
-      #endif
       red_result = strat->red(&strat->P,strat);
-      #ifdef ADIDEBUG
-      printf("\nThis is P nach red:\n");p_Write(strat->P.p,strat->tailRing);p_Write(strat->P.p1,strat->tailRing);p_Write(strat->P.p2,strat->tailRing);
-      printf("\nAfter Ll = %i\n", strat->Ll);
-      #endif
     }
 
     // the reduced s-poly
@@ -1806,27 +1689,9 @@ loop_count = 1;
       else
         enterpairs(strat->P.p,strat->sl,strat->P.ecart,0,strat, strat->tl);
       // put in S
-
-        #ifdef ADIDEBUG
-        Print("\n    The new pair list L -- after superenterpairs in loop %d -- is:\n",loop_count);
-        for(int iii=0;iii<=strat->Ll;iii++)
-        {
-          printf("\n    L[%d]:\n",iii);
-          PrintS("         ");p_Write(strat->L[iii].p,strat->tailRing);
-          PrintS("         ");p_Write(strat->L[iii].p1,strat->tailRing);
-          PrintS("         ");p_Write(strat->L[iii].p2,strat->tailRing);
-        }
-        #endif
       strat->enterS(strat->P,
                     posInS(strat,strat->sl,strat->P.p, strat->P.ecart),
                     strat, strat->tl);
-      #ifdef ADIDEBUG
-      printf("\nThis pair has been added to S:\n");
-      pWrite(strat->P.p);
-      pWrite(strat->P.p1);
-      pWrite(strat->P.p2);
-      #endif
-
       // apply hilbert criterion
       if (hilb!=NULL)
       {
@@ -1883,10 +1748,10 @@ loop_count = 1;
     else
       Kstd1_mu=-1;
   }
-  pDelete(&strat->kHEdge);
+  if (strat->kHEdge!=NULL) pLmFree(&strat->kHEdge);
   strat->update = TRUE; //???
   strat->lastAxis = 0; //???
-  pDelete(&strat->kNoether);
+  if (strat->kNoether!=NULL) pLmDelete(&strat->kNoether);
   omFreeSize((ADDRESS)strat->NotUsedAxis,((currRing->N)+1)*sizeof(BOOLEAN));
   if ((TEST_OPT_PROT)||(TEST_OPT_DEBUG))  messageStat(hilbcount,strat);
 //  if (TEST_OPT_WEIGHTM)
@@ -1938,7 +1803,7 @@ poly kNF1 (ideal F,ideal Q,poly q, kStrategy strat, int lazyReduce)
   && ((!strat->kHEdgeFound)
     ||(TEST_OPT_DEGBOUND && (pWTotaldegree(strat->kNoether)<Kstd1_deg))))
   {
-    pDelete(&strat->kNoether);
+    pLmDelete(&strat->kNoether);
     strat->kNoether=pOne();
     pSetExp(strat->kNoether,1, Kstd1_deg+1);
     pSetm(strat->kNoether);
@@ -1973,7 +1838,7 @@ poly kNF1 (ideal F,ideal Q,poly q, kStrategy strat, int lazyReduce)
       pSetmComp(p);
       p=pAdd(strat->kNoether,p);
       strat->kNoether=pNext(p);
-      p_LmFree(p,currRing);
+      p_LmDelete(p,currRing);
     }
   }
   if ((lazyReduce & KSTD_NF_LAZY)==0)
@@ -2033,8 +1898,8 @@ poly kNF1 (ideal F,ideal Q,poly q, kStrategy strat, int lazyReduce)
     omFreeSize((ADDRESS)strat->fromQ,i*sizeof(int));
     strat->fromQ=NULL;
   }
-  pDelete(&strat->kHEdge);
-  pDelete(&strat->kNoether);
+  if (strat->kHEdge!=NULL) pLmFree(&strat->kHEdge);
+  if (strat->kNoether!=NULL) pLmDelete(&strat->kNoether);
 //  if ((TEST_OPT_WEIGHTM)&&(F!=NULL))
 //  {
 //    pRestoreDegProcs(currRing,strat->pOrigFDeg, strat->pOrigLDeg);
@@ -2082,7 +1947,7 @@ ideal kNF1 (ideal F,ideal Q,ideal q, kStrategy strat, int lazyReduce)
   && ((!strat->kHEdgeFound)
     ||(TEST_OPT_DEGBOUND && (pWTotaldegree(strat->kNoether)<Kstd1_deg))))
   {
-    pDelete(&strat->kNoether);
+    pLmDelete(&strat->kNoether);
     strat->kNoether=pOne();
     pSetExp(strat->kNoether,1, Kstd1_deg+1);
     pSetm(strat->kNoether);
@@ -2117,7 +1982,7 @@ ideal kNF1 (ideal F,ideal Q,ideal q, kStrategy strat, int lazyReduce)
       pSetmComp(p);
       p=pAdd(strat->kNoether,p);
       strat->kNoether=pNext(p);
-      p_LmFree(p,currRing);
+      p_LmDelete(p,currRing);
     }
   }
   if (TEST_OPT_INTSTRATEGY && ((lazyReduce & KSTD_NF_LAZY)==0))
@@ -2181,12 +2046,12 @@ ideal kNF1 (ideal F,ideal Q,ideal q, kStrategy strat, int lazyReduce)
   omFree(strat->R);
   if ((Q!=NULL)&&(strat->fromQ!=NULL))
   {
-    i=((IDELEMS(Q)+IDELEMS(F)+15)/16)*16;
+    i=((IDELEMS(F)+IDELEMS(Q)+(setmaxTinc-1))/setmaxTinc)*setmaxTinc;
     omFreeSize((ADDRESS)strat->fromQ,i*sizeof(int));
     strat->fromQ=NULL;
   }
-  pDelete(&strat->kHEdge);
-  pDelete(&strat->kNoether);
+  if (strat->kHEdge!=NULL) pLmFree(&strat->kHEdge);
+  if (strat->kNoether!=NULL) pLmDelete(&strat->kNoether);
 //  if ((TEST_OPT_WEIGHTM)&&(F!=NULL))
 //  {
 //    pFDeg=strat->pOrigFDeg;
@@ -2208,7 +2073,7 @@ intvec * kModW, * kHomW;
 long kModDeg(poly p, ring r)
 {
   long o=p_WDegree(p, r);
-  long i=p_GetComp(p, r);
+  long i=__p_GetComp(p, r);
   if (i==0) return o;
   //assume((i>0) && (i<=kModW->length()));
   if (i<=kModW->length())
@@ -2223,7 +2088,7 @@ long kHomModDeg(poly p, ring r)
   for (i=r->N;i>0;i--)
     j+=p_GetExp(p,i,r)*(*kHomW)[i-1];
   if (kModW == NULL) return j;
-  i = p_GetComp(p,r);
+  i = __p_GetComp(p,r);
   if (i==0) return j;
   return j+(*kModW)[i-1];
 }
@@ -2272,7 +2137,10 @@ ideal kStd(ideal F, ideal Q, tHomog h,intvec ** w, intvec *hilb,int syzComp,
     }
     else if (!TEST_OPT_DEGBOUND)
     {
-      h = (tHomog)idHomModule(F,Q,w);
+      if (w!=NULL)
+        h = (tHomog)idHomModule(F,Q,w);
+      else
+        h = (tHomog)idHomIdeal(F,Q);
     }
   }
   currRing->pLexOrder=b;
@@ -2319,10 +2187,6 @@ ideal kStd(ideal F, ideal Q, tHomog h,intvec ** w, intvec *hilb,int syzComp,
       if(pFmon != NULL)
       {
         idInsertPoly(FCopy, pFmon);
-        #ifdef ADIDEBUG
-        printf("\nPreintegerCheck found this constant:\n");pWrite(pFmon);
-        #endif
-
         strat->kModW=kModW=NULL;
         if (h==testHomog)
         {
@@ -2355,12 +2219,6 @@ ideal kStd(ideal F, ideal Q, tHomog h,intvec ** w, intvec *hilb,int syzComp,
         }
         strat->homog=h;
       }
-      else
-      {
-        #ifdef ADIDEBUG
-        printf("\npreIntegerCheck didn't found any new information\n");
-        #endif
-      }
       omTestMemory(1);
       if(w == NULL)
       {
@@ -2551,9 +2409,6 @@ ideal kSba(ideal F, ideal Q, tHomog h,intvec ** w, int sbaOrder, int arri, intve
     r = idCopy(F);
     int sbaEnterS = -1;
     bool sigdrop = TRUE;
-    #ifdef ADIDEBUG
-    printf("\nEnter the nice kSba loop\n");
-    #endif
     //This is how we set the SBA algorithm;
     int totalsbaruns = 1,blockedreductions = 20,blockred = 0,loops = 0;
     while(sigdrop && (loops < totalsbaruns || totalsbaruns == -1)
@@ -2677,11 +2532,6 @@ ideal kSba(ideal F, ideal Q, tHomog h,intvec ** w, int sbaOrder, int arri, intve
           {
             r=sba(r,Q,NULL,hilb,strat);
           }
-          #ifdef ADIDEBUG
-          printf("\nSBA Run %i: %i elements (syzCrit = %i,rewCrit = %i)\n",loops,IDELEMS(r),strat->nrsyzcrit,strat->nrrewcrit);
-          idPrint(r);
-          //getchar();
-          #endif
         }
       }
     #ifdef KDEBUG
@@ -2698,20 +2548,12 @@ ideal kSba(ideal F, ideal Q, tHomog h,intvec ** w, int sbaOrder, int arri, intve
       sigdrop = strat->sigdrop;
       sbaEnterS = strat->sbaEnterS;
       blockred = strat->blockred;
-      #ifdef ADIDEBUG
-      printf("\nsbaEnterS = %i\n",sbaEnterS);
-      #endif
       delete(strat);
       if ((delete_w)&&(w!=NULL)&&(*w!=NULL)) delete *w;
     }
     // Go to std
     if(sigdrop || blockred > blockedreductions)
     {
-      #ifdef ADIDEBUG
-      printf("\nWent to std\n");
-      idPrint(r);
-      getchar();
-      #endif
       r = kStd(r, Q, h, w, hilb, syzComp, newIdeal, vw);
     }
     return r;
@@ -2785,7 +2627,7 @@ ideal kStdShift(ideal F, ideal Q, tHomog h,intvec ** w, intvec *hilb,int syzComp
   if (rHasLocalOrMixedOrdering(currRing))
   {
     /* error: no local ord yet with shifts */
-    PrintS("No local ordering possible for shifts");
+    WerrorS("No local ordering possible for shift algebra");
     return(NULL);
   }
   else
@@ -2945,7 +2787,7 @@ ideal kMin_std(ideal F, ideal Q, tHomog h,intvec ** w, ideal &M, intvec *hilb,
   else if (strat->M==NULL)
   {
     M=idInit(1,F->rank);
-    Warn("no minimal generating set computed");
+    WarnS("no minimal generating set computed");
   }
   else
   {
@@ -3226,7 +3068,8 @@ ideal kInterRedOld (ideal F, ideal Q)
   if (TEST_OPT_REDSB && TEST_OPT_INTSTRATEGY)
     completeReduce(strat);
   //else if (TEST_OPT_PROT) PrintLn();
-  pDelete(&strat->kHEdge);
+  cleanT(strat);
+  if (strat->kHEdge!=NULL) pLmFree(&strat->kHEdge);
   omFreeSize((ADDRESS)strat->T,strat->tmax*sizeof(TObject));
   omFreeSize((ADDRESS)strat->ecartS,IDELEMS(strat->Shdl)*sizeof(int));
   omFreeSize((ADDRESS)strat->sevS,IDELEMS(strat->Shdl)*sizeof(unsigned long));
@@ -3294,6 +3137,8 @@ ideal kInterRedBba (ideal F, ideal Q, int &need_retry)
   {
     h = (tHomog)idHomModule(F,Q,&w);
   }
+  else
+    h = isNotHomog;
   if (h==isHomog)
   {
     if (strat->ak > 0 && (w!=NULL) && (w!=NULL))
@@ -3383,7 +3228,7 @@ ideal kInterRedBba (ideal F, ideal Q, int &need_retry)
 
       // reduce the tail and normalize poly
       // in the ring case we cannot expect LC(f) = 1,
-      // therefore we call pContent instead of pNorm
+      // therefore we call pCleardenom instead of pNorm
       if ((TEST_OPT_INTSTRATEGY) || (rField_is_Ring(currRing)))
       {
         strat->P.pCleardenom();
@@ -3504,7 +3349,7 @@ ideal kInterRedBba (ideal F, ideal Q, int &need_retry)
 #ifdef HAVE_TAIL_RING
         if(currRing->bitmask>strat->tailRing->bitmask)
         {
-	  // retry without T
+          // retry without T
           strat->completeReduce_retry=FALSE;
           cleanT(strat);strat->tailRing=currRing;
           int i;
