@@ -8,21 +8,19 @@
 
 
 
-#include <kernel/mod2.h>
-#include <omalloc/omalloc.h>
-#include <misc/options.h>
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/khstd.h>
-//#include "cntrlc.h"
-#include <polys/weight.h>
-//#include "ipshell.h"
-#include <misc/intvec.h>
-#include <polys/clapsing.h>
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kstdfac.h>
+#include "kernel/mod2.h"
+#include "omalloc/omalloc.h"
+#include "misc/options.h"
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/khstd.h"
+#include "polys/weight.h"
+#include "misc/intvec.h"
+#include "polys/clapsing.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kstdfac.h"
 
 int strat_nr=0;
 /*3
@@ -80,7 +78,8 @@ static void copyL (kStrategy o,kStrategy n)
       l[j].p=pCopy(o->L[j].p);
     else
     {
-      l[j].p=pHead(o->L[j].p);
+      l[j].p=p_LmInit(o->L[j].p,currRing);
+      if (pGetCoeff(o->L[j].p)!=NULL) pSetCoeff0(l[j].p,nCopy(pGetCoeff(o->L[j].p)));
       pNext(l[j].p)=n->tail;
     }
     // copy .lcm ----------------------------------------------
@@ -101,7 +100,7 @@ static void copyL (kStrategy o,kStrategy n)
       i++;
       if(i>o->tl)
       {
-        Warn("poly p1 not found in T:");wrp(p);PrintLn();
+        WarnS("poly p1 not found in T:");wrp(p);PrintLn();
         l[j].p1=pCopy(p);
         l[j].i_r1=-1;
         break;
@@ -123,7 +122,7 @@ static void copyL (kStrategy o,kStrategy n)
       i++;
       if(i>o->tl)
       {
-        Warn("poly p2 not found in T:");wrp(p);PrintLn();
+        WarnS("poly p2 not found in T:");wrp(p);PrintLn();
         l[j].p2=pCopy(p);
         l[j].i_r2=-1;
         break;
@@ -338,7 +337,7 @@ static void completeReduceFac (kStrategy strat, ideal_list FL)
       }
 
       n->P.p=fac->m[i];
-      n->P.pLength=0;
+      //n->P.pLength=pLength(n->P.p); // by initEcart
       n->initEcart(&n->P);
       /* enter P.p into s and L */
       int pos;
@@ -354,7 +353,7 @@ static void completeReduceFac (kStrategy strat, ideal_list FL)
         pNorm(n->P.p);
         n->P.p = redtailBba(n->P.p,pos-1,n);
       }
-      n->P.pLength=0;
+      n->P.pLength=pLength(n->P.p);
       if (TEST_OPT_DEBUG)
       {
         Print("new s(%d)->S:",n->nr);
@@ -594,8 +593,8 @@ ideal bbafac (ideal /*F*/, ideal Q,intvec */*w*/,kStrategy strat, ideal_list FL)
           n->P.Init(strat->tailRing);
         }
 
-        n->P.pLength=0;
         n->P.p=fac->m[i];
+        //n->P.pLength=pLength(n->P.p); // by initEcart
         n->initEcart(&n->P);
         kTest_TS(n);
 
@@ -611,7 +610,7 @@ ideal bbafac (ideal /*F*/, ideal Q,intvec */*w*/,kStrategy strat, ideal_list FL)
           if (n->redTailChange)
           {
             n->P.pCleardenom();
-            n->P.pLength=0;
+            n->P.pLength=pLength(n->P.p);
           }
         }
         else
@@ -620,7 +619,7 @@ ideal bbafac (ideal /*F*/, ideal Q,intvec */*w*/,kStrategy strat, ideal_list FL)
           n->P.p = redtailBba(n->P.p,pos-1,n);
           if (n->redTailChange)
           {
-            n->P.pLength=0;
+            n->P.pLength=pLength(n->P.p);
           }
         }
         kTest_TS(n);
