@@ -10,34 +10,28 @@
 
 #include <string.h>
 
-#include <omalloc/omalloc.h>
-#include <omalloc/omallocClass.h>
-#include <misc/mylimits.h>
+#include "omalloc/omalloc.h"
+#ifndef XMEMORY_H
+#include "omalloc/omallocClass.h"
+#endif
+#include "misc/mylimits.h"
 
 
-#include <kernel/polys.h>
-#include <polys/operations/pShallowCopyDelete.h>
+#include "kernel/polys.h"
+#include "polys/operations/pShallowCopyDelete.h"
 
-#include <kernel/structs.h>
-#include <kernel/GBEngine/kstd1.h>   /* for s_poly_proc_t */
+#include "kernel/structs.h"
+#include "kernel/GBEngine/kstd1.h"   /* for s_poly_proc_t */
 
 // define if tailrings should be used
 #define HAVE_TAIL_RING
 
-#if 1
-#define setmax 16
+#define setmax 128
 #define setmaxL ((4096-12)/sizeof(LObject))
 #define setmaxLinc ((4096)/sizeof(LObject))
 
-#define setmaxT 64
-#define setmaxTinc 32
-#else
-#define setmax 16
-#define setmaxL 16
-#define setmaxLinc 16
-#define setmaxT 16
-#define setmaxTinc 16
-#endif
+#define setmaxT ((4096-12)/sizeof(TObject))
+#define setmaxTinc ((4096)/sizeof(TObject))
 
 // if you want std computations as in Singular version < 2:
 // This disables RedThrough, tailReductions against T (bba),
@@ -74,29 +68,29 @@ public:
   poly sig;   // the signature of the element
   poly p;       // Lm(p) \in currRing Tail(p) \in tailRing
   poly t_p;     // t_p \in tailRing: as monomials Lm(t_p) == Lm(p)
-  poly max;     // p_GetMaxExpP(pNext(p))
+  poly max_exp;     // p_GetMaxExpP(pNext(p))
   ring tailRing;
   long FDeg;    // pFDeg(p)
   int ecart,
     length,     // as of pLDeg
     pLength,    // either == 0, or == pLength(p)
     i_r;        // index of TObject in R set, or -1 if not in T
-  BOOLEAN is_normalized; // true, if pNorm was called on p, false otherwise
+  /*BOOLEAN*/ char is_normalized; // true, if pNorm was called on p, false otherwise
   // used in incremental sba() with F5C:
   // we know some of the redundant elements in
   // strat->T beforehand, so we can just discard
   // them and do not need to consider them in the
   // interreduction process
-  BOOLEAN is_redundant;
+  /*BOOLEAN*/ char is_redundant;
   // used in sba's sig-safe reduction:
   // sometimes we already know that a reducer
   // is sig-safe, so no need for a real
   // sig-safeness check
-  BOOLEAN is_sigsafe;
+  /*BOOLEAN*/ char is_sigsafe;
 
 
 #ifdef HAVE_PLURAL
-  BOOLEAN is_special; // true, it is a new special S-poly (e.g. for SCA)
+  /*BOOLEAN*/ char is_special; // true, it is a new special S-poly (e.g. for SCA)
 #endif
 
   // initialization
@@ -219,7 +213,7 @@ public:
   KINLINE void Tail_Minus_mm_Mult_qq(poly m, poly qq, int lq, poly spNoether);
   KINLINE void Tail_Mult_nn(number n);
   // deletes bucket, makes sure that p and t_p exists
-  KINLINE poly GetP(omBin lmBin = NULL);
+  KINLINE poly GetP(omBin lmBin = (omBin)NULL);
   // similar, except that only t_p exists
   KINLINE poly GetTP();
 
@@ -229,8 +223,6 @@ public:
 
   // makes a copy of the poly of L
   KINLINE void Copy();
-  // gets the poly and makes a copy of it
-  KINLINE poly CopyGetP();
 
   KINLINE int GetpLength();
   KINLINE long pLDeg(BOOLEAN use_last);
@@ -267,7 +259,10 @@ public:
 
 extern int HCord;
 
-class skStrategy : public omallocClass
+class skStrategy
+#ifndef XMEMORY_H
+                 : public omallocClass
+#endif
 {
 public:
   kStrategy next;
@@ -354,34 +349,43 @@ public:
   int lastAxis;
   int newIdeal;
   int minim;
+  #ifdef HAVE_RINGS
+  bool sigdrop; //This is used to check sigdrop in sba over Z
+  int nrsyzcrit; // counts how many pairs are deleted by SyzCrit
+  int nrrewcrit; // counts how many pairs are deleted by FaugereRewCrit
+  int sbaEnterS; // sba over Z strategy: if sigdrop element has _*gen(sbaEnterS+1), then
+                 // add directly sbaEnterS elements into S
+  int blockred;  // counter for blocked reductions in redSig
+  int blockredmax;
+  #endif
   #ifdef HAVE_SHIFTBBA
   int lV;
   int cv; // in shift bases: counting V criterion
   #endif
-  BOOLEAN interpt;
-  BOOLEAN homog;
+  /*BOOLEAN*/ char interpt;
+  /*BOOLEAN*/ char homog;
 #ifdef HAVE_PLURAL
-  BOOLEAN z2homog; // Z_2 - homogeneous input allows product criterion in commutative and SCA cases!
+  /*BOOLEAN*/ char z2homog; // Z_2 - homogeneous input allows product criterion in commutative and SCA cases!
 #endif
-  BOOLEAN kHEdgeFound;
-  BOOLEAN honey,sugarCrit;
-  BOOLEAN Gebauer,noTailReduction;
-  BOOLEAN fromT;
-  BOOLEAN noetherSet;
-  BOOLEAN update;
-  BOOLEAN posInLOldFlag;
-  BOOLEAN use_buckets;
+  /*BOOLEAN*/ char kHEdgeFound;
+  /*BOOLEAN*/ char honey,sugarCrit;
+  /*BOOLEAN*/ char Gebauer,noTailReduction;
+  /*BOOLEAN*/ char fromT;
+  /*BOOLEAN*/ char noetherSet;
+  /*BOOLEAN*/ char update;
+  /*BOOLEAN*/ char posInLOldFlag;
+  /*BOOLEAN*/ char use_buckets;
   // if set, pLDeg(p, l) == (pFDeg(pLast(p), pLength)
-  BOOLEAN LDegLast;
+  /*BOOLEAN*/ char LDegLast;
   // if set, then L.length == L.pLength
-  BOOLEAN length_pLength;
+  /*BOOLEAN*/ char length_pLength;
   // if set, then posInL does not depend on L.length
-  BOOLEAN posInLDependsOnLength;
+  /*BOOLEAN*/ char posInLDependsOnLength;
   /*FALSE, if posInL == posInL10*/
 #ifdef HAVE_PLURAL
   // set this flag to 1 to stop the product criteria
   // use ALLOW_PROD_CRIT(strat) to test
-  BOOLEAN no_prod_crit;
+  /*BOOLEAN*/ char no_prod_crit;
 #define ALLOW_PROD_CRIT(A) (!(A)->no_prod_crit)
 #else
 #define ALLOW_PROD_CRIT(A) (1)
@@ -418,6 +422,8 @@ void initEcartPairBba (LObject* Lp,poly f,poly g,int ecartF,int ecartG);
 void initEcartPairMora (LObject* Lp,poly f,poly g,int ecartF,int ecartG);
 int posInS (const kStrategy strat, const int length, const poly p,
             const int ecart_p);
+int posInSMonFirst (const kStrategy strat, const int length, const poly p);
+int posInIdealMonFirst (const ideal F, const poly p,int start = 0,int end = -1);
 int posInT0 (const TSet set,const int length,LObject &p);
 int posInT1 (const TSet set,const int length,LObject &p);
 int posInT2 (const TSet set,const int length,LObject &p);
@@ -427,8 +433,12 @@ int posInT110 (const TSet set,const int length,LObject &p);
 int posInT13 (const TSet set,const int length,LObject &p);
 int posInT15 (const TSet set,const int length,LObject &p);
 int posInT17 (const TSet set,const int length,LObject &p);
+int posInT17_c (const TSet set,const int length,LObject &p);
 int posInT19 (const TSet set,const int length,LObject &p);
 int posInT_EcartpLength(const TSet set,const int length,LObject &p);
+int posInT_EcartFDegpLength(const TSet set,const int length,LObject &p);
+int posInT_FDegpLength(const TSet set,const int length,LObject &p);
+int posInT_pLength(const TSet set,const int length,LObject &p);
 
 #ifdef HAVE_MORE_POS_IN_T
 int posInT_EcartFDegpLength(const TSet set,const int length,LObject &p);
@@ -442,6 +452,8 @@ int posInLF5C (const LSet set, const int length,
                LObject* L,const kStrategy strat);
 int posInLSig (const LSet set, const int length,
                LObject* L,const kStrategy strat);
+int posInLSigRing (const LSet set, const int length,
+               LObject* L,const kStrategy strat);
 int posInLRing (const LSet set, const int length,
                LObject* L,const kStrategy strat);
 int posInSyz (const kStrategy strat, const poly sig);
@@ -451,30 +463,39 @@ int posInL11 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
 int posInL11Ring (const LSet set, const int length,
              LObject* L,const kStrategy strat);
+int posInLF5CRing (const LSet set, int start , const int length,
+             LObject* L,const kStrategy strat);
 int posInL11Ringls (const LSet set, const int length,
              LObject* L,const kStrategy strat);
 int posInL13 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
 int posInL15 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
+int posInL15Ring (const LSet set, const int length,
+             LObject* L,const kStrategy strat);
 int posInL17 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
 int posInL10 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
+int posInL10Ring (const LSet set, const int length,
+             LObject* L,const kStrategy strat);
 int posInL110 (const LSet set, const int length,
              LObject* L,const kStrategy strat);
-KINLINE poly redtailBba (poly p,int pos,kStrategy strat,BOOLEAN normalize=FALSE);
+KINLINE poly redtailBba (poly p,int end_pos,kStrategy strat,BOOLEAN normalize=FALSE);
+KINLINE poly redtailBbaBound (poly p,int end_pos,kStrategy strat,int bound,BOOLEAN normalize=FALSE);
 #ifdef HAVE_RINGS
-KINLINE poly redtailBba_Z (poly p,int pos,kStrategy strat);
-poly redtailBba_Z (LObject* L, int pos, kStrategy strat );
+KINLINE poly redtailBba_Z (poly p,int end_pos,kStrategy strat);
+poly redtailBba_Z (LObject* L, int end_pos, kStrategy strat );
 #endif
-poly redtailBba (LObject *L, int pos,kStrategy strat,
+poly redtailBba (LObject *L, int end_pos,kStrategy strat,
                  BOOLEAN withT = FALSE,BOOLEAN normalize=FALSE);
-poly redtailSba (LObject *L, int pos,kStrategy strat,
+poly redtailBbaBound (LObject *L, int end_pos,kStrategy strat,int bound,
                  BOOLEAN withT = FALSE,BOOLEAN normalize=FALSE);
-poly redtailBba (TObject *T, int pos,kStrategy strat);
-poly redtail (poly p,int pos,kStrategy strat);
-poly redtail (LObject *L,int pos,kStrategy strat);
+poly redtailSba (LObject *L, int end_pos,kStrategy strat,
+                 BOOLEAN withT = FALSE,BOOLEAN normalize=FALSE);
+poly redtailBba (TObject *T, int end_pos,kStrategy strat);
+poly redtail (poly p,int end_pos,kStrategy strat);
+poly redtail (LObject *L,int end_pos,kStrategy strat);
 poly redNF (poly h,int & max_ind,int nonorm,kStrategy strat);
 int redNF0 (LObject *P,kStrategy strat);
 poly redNFTail (poly h,const int sl,kStrategy strat);
@@ -483,7 +504,9 @@ int redHoney (LObject* h, kStrategy strat);
 int redRing (LObject* h,kStrategy strat);
 int redRiloc (LObject* h,kStrategy strat);
 void enterExtendedSpoly(poly h,kStrategy strat);
+void enterExtendedSpolySig(poly h,poly hSig,kStrategy strat);
 void superenterpairs (poly h,int k,int ecart,int pos,kStrategy strat, int atR = -1);
+void superenterpairsSig (poly h,poly hSig,int hFrom,int k,int ecart,int pos,kStrategy strat, int atR = -1);
 poly kCreateZeroPoly(long exp[], long cabsind, poly* t_p, ring leadRing, ring tailRing);
 long ind2(long arg);
 
@@ -494,14 +517,16 @@ ideal createG0();
 int redLazy (LObject* h,kStrategy strat);
 int redHomog (LObject* h,kStrategy strat);
 int redSig (LObject* h,kStrategy strat);
+int redSigRing (LObject* h,kStrategy strat);
 //adds hSig to be able to check with F5's criteria when entering pairs!
 void enterpairsSig (poly h, poly hSig, int from, int k, int ec, int pos,kStrategy strat, int atR = -1);
 void enterpairs (poly h, int k, int ec, int pos,kStrategy strat, int atR = -1);
 void entersets (LObject h);
 void pairs ();
-BOOLEAN enterOneStrongPoly (int i,poly p,int /*ecart*/, int /*isFromQ*/,kStrategy strat, int atR = -1, bool enterTstrong = FALSE);
+BOOLEAN sbaCheckGcdPair (LObject* h,kStrategy strat);
 void message (int i,int* reduc,int* olddeg,kStrategy strat,int red_result);
 void messageStat (int hilbcount,kStrategy strat);
+void messageStatSBA (int hilbcount,kStrategy strat);
 #ifdef KDEBUG
 void messageSets (kStrategy strat);
 #else
@@ -526,13 +551,16 @@ void initSyzRules (kStrategy strat);
 void updateS(BOOLEAN toT,kStrategy strat);
 void enterSyz (LObject &p,kStrategy strat, int atT);
 void enterT (LObject &p,kStrategy strat, int atT = -1);
+#ifdef HAVE_RINGS
 void enterT_strong (LObject &p,kStrategy strat, int atT = -1);
+#endif
 void cancelunit (LObject* p,BOOLEAN inNF=FALSE);
 void HEckeTest (poly pp,kStrategy strat);
 void initBuchMoraCrit(kStrategy strat);
 void initSbaCrit(kStrategy strat);
 void initHilbCrit(ideal F, ideal Q, intvec **hilb,kStrategy strat);
 void initBuchMoraPos(kStrategy strat);
+void initBuchMoraPosRing(kStrategy strat);
 void initSbaPos(kStrategy strat);
 void initBuchMora (ideal F, ideal Q,kStrategy strat);
 void initSbaBuchMora (ideal F, ideal Q,kStrategy strat);
@@ -542,8 +570,6 @@ void updateResult(ideal r,ideal Q,kStrategy strat);
 void completeReduce (kStrategy strat, BOOLEAN withT=FALSE);
 void kFreeStrat(kStrategy strat);
 void enterOnePairNormal (int i,poly p,int ecart, int isFromQ,kStrategy strat, int atR);
-void enterOnePairLift (int i,poly p,int ecart, int isFromQ,kStrategy strat, int atR);
-void enterOnePairSig (int i,poly p,poly pSig,int ecart, int isFromQ,kStrategy strat, int atR);
 void chainCritNormal (poly p,int ecart,kStrategy strat);
 void chainCritOpt_1 (poly,int,kStrategy strat);
 void chainCritSig (poly p,int ecart,kStrategy strat);
@@ -569,9 +595,7 @@ int kFindDivisibleByInT(const kStrategy strat, const LObject* L, const int start
 int kFindDivisibleByInS(const kStrategy strat, int *max_ind, LObject* L);
 
 int kFindNextDivisibleByInS(const kStrategy strat, int start,int max_ind, LObject* L);
-TObject*
-kFindDivisibleByInS(kStrategy strat, int pos, LObject* L, TObject *T,
-                    long ecart = LONG_MAX);
+TObject* kFindDivisibleByInS_T(kStrategy strat, int end_pos, LObject* L, TObject *T, long ecart = LONG_MAX);
 
 /***************************************************************
  *
@@ -634,6 +658,8 @@ ideal bba (ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat);
 ideal sba (ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat);
 poly kNF2 (ideal F, ideal Q, poly q, kStrategy strat, int lazyReduce);
 ideal kNF2 (ideal F,ideal Q,ideal q, kStrategy strat, int lazyReduce);
+poly kNF2Bound (ideal F, ideal Q, poly q,int bound, kStrategy strat, int lazyReduce);
+ideal kNF2Bound (ideal F,ideal Q,ideal q,int bound, kStrategy strat, int lazyReduce);
 void initBba(kStrategy strat);
 void initSba(ideal F,kStrategy strat);
 void f5c (kStrategy strat, int& olddeg, int& minimcnt, int& hilbeledeg,
@@ -664,6 +690,13 @@ int ksReducePoly(LObject* PR,
                  number *coef = NULL,
                  kStrategy strat = NULL);
 
+int ksReducePolyBound(LObject* PR,
+                 TObject* PW,
+                 int bound,
+                 poly spNoether = NULL,
+                 number *coef = NULL,
+                 kStrategy strat = NULL);
+
 // Reduces PR with PW
 // Assumes PR != NULL, PW != NULL, Lm(PW) divides Lm(PR)
 // Changes: PR
@@ -685,6 +718,13 @@ int ksReducePolySig(LObject* PR,
                  number *coef = NULL,
                  kStrategy strat = NULL);
 
+int ksReducePolySigRing(LObject* PR,
+                 TObject* PW,
+                 long idx,
+                 poly spNoether = NULL,
+                 number *coef = NULL,
+                 kStrategy strat = NULL);
+
 // Reduces PR at Current->next with PW
 // Assumes PR != NULL, Current contained in PR
 //         Current->next != NULL, LM(PW) devides LM(Current->next)
@@ -739,6 +779,7 @@ BOOLEAN kCheckSpolyCreation(LObject* L, kStrategy strat, poly &m1, poly &m2);
 BOOLEAN kCheckStrongCreation(int atR, poly m1, int atS, poly m2, kStrategy strat);
 poly preIntegerCheck(ideal F, ideal Q);
 void postReduceByMon(LObject* h, kStrategy strat);
+void postReduceByMonSig(LObject* h, kStrategy strat);
 void finalReduceByMon(kStrategy strat);
 #endif
 // change strat->tailRing and adjust all data in strat, L, and T:
@@ -763,10 +804,10 @@ ring sbaRing(kStrategy strat, const ring r=currRing, BOOLEAN complete=TRUE, int
 KINLINE void clearS (poly p, unsigned long p_sev, int* at, int* k,
   kStrategy strat);
 
-#include <kernel/GBEngine/kInline.h>
+#include "kernel/GBEngine/kInline.h"
 
 /* shiftgb stuff */
-#include <kernel/GBEngine/shiftgb.h>
+#include "kernel/GBEngine/shiftgb.h"
 
 poly pMove2CurrTail(poly p, kStrategy strat);
 
@@ -778,16 +819,12 @@ void enterTShift(LObject p, kStrategy strat, int atT, int uptodeg, int lV);
 
 void initBuchMoraShift (ideal F,ideal Q,kStrategy strat);
 
-void enterOnePairManyShifts (int i, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int uptodeg, int lV); // ok
-
 void enterOnePairSelfShifts (poly qq, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int uptodeg, int lV);
 
 void enterOnePairShift (poly q, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int ecartq, int qisFromQ, int shiftcount, int ifromS, int uptodeg, int lV); // ok
 
 void enterpairsShift (poly h,int k,int ecart,int pos,kStrategy strat, int atR,int uptodeg, int lV);
 
-void initenterpairsShift (poly h,int k,int ecart,int isFromQ,kStrategy strat, int atR,int uptodeg, int lV);
-
 void updateSShift(kStrategy strat,int uptodeg,int lV);
 
 void initBbaShift(kStrategy strat);
