@@ -1,24 +1,21 @@
 #define PLURAL_INTERNAL_DECLARATIONS
 
+#include "kernel/mod2.h"
 
+#include "misc/options.h"
 
+#include "polys/simpleideals.h"
+#include "polys/prCopy.h"
 
-#include <kernel/mod2.h>
+#include "polys/nc/sca.h"
+#include "polys/nc/gb_hack.h"
 
-#include <misc/options.h>
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/kutil.h"
 
-#include <polys/simpleideals.h>
-#include <polys/prCopy.h>
-
-#include <polys/nc/sca.h>
-#include <polys/nc/gb_hack.h>
-
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/kutil.h>
-
-#include <kernel/GBEngine/nc.h>
+#include "kernel/GBEngine/nc.h"
 
 /// nc_gr_initBba is needed for sca_gr_bba and gr_bba.
 void nc_gr_initBba(ideal F, kStrategy strat); // from gr_kstd2.cc!
@@ -47,7 +44,6 @@ void addLObject(LObject& h, kStrategy& strat)
     else
     {
       pNorm(h.p);
-      p_Content(h.p,currRing);
     }
 
     if ((strat->syzComp==0)||(!strat->homog))
@@ -56,8 +52,7 @@ void addLObject(LObject& h, kStrategy& strat)
 
       if (TEST_OPT_INTSTRATEGY)
       {
-//        pCleardenom(h.p);
-        p_Content(h.p,currRing);
+        p_Cleardenom(h.p,currRing);
       }
       else
       {
@@ -269,8 +264,7 @@ ideal k_sca_gr_bba(const ideal F, const ideal Q, const intvec *, const intvec *,
 
         if (TEST_OPT_INTSTRATEGY)
         {
-//           h.pCleardenom(); // also does a p_Content
-          p_Content(h.p,currRing);
+          h.pCleardenom(); // also removes Content
         }
         else
         {
@@ -522,7 +516,7 @@ ideal k_sca_bba (const ideal F, const ideal Q, const intvec */*w*/, const intvec
               h.is_special = TRUE;
 
               if (TEST_OPT_INTSTRATEGY)
-                h.pCleardenom(); // also does a p_Content
+                h.pCleardenom(); // also removes Content
               else
                 h.pNorm();
 
@@ -713,8 +707,7 @@ ideal k_sca_bba (const ideal F, const ideal Q, const intvec */*w*/, const intvec
 
         if (TEST_OPT_INTSTRATEGY)
         {
-//          p_Content(h.p);
-          h.pCleardenom(); // also does a p_Content
+          h.pCleardenom(); // also removes Content
         }
         else
         {
@@ -888,10 +881,6 @@ static BOOLEAN kMoraUseBucket(kStrategy)
   return FALSE;
 }
 
-#ifdef HAVE_ASSUME
-static int sca_mora_count = 0;
-#endif
-
 // ideal sca_mora (ideal F, ideal Q, intvec *w, intvec *, kStrategy strat)
 ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec *, kStrategy strat, const ring _currRing)
 {
@@ -921,10 +910,6 @@ ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec
   assume( strat->homog == bIdHomog );
 #endif
 
-#ifdef HAVE_ASSUME
-  sca_mora_count++;
-#endif
-
   strat->update = TRUE;
   //- setting global variables ------------------- -
   initBuchMoraCrit(strat);
@@ -1013,7 +998,7 @@ ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec
               LObject h(p_new); // h = x_i * strat->P
 
               if (TEST_OPT_INTSTRATEGY)
-                h.pCleardenom(); // also does a p_Content
+                h.pCleardenom(); // also removes Content
               else
                 h.pNorm();
 
@@ -1149,7 +1134,7 @@ ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec
         LObject h(p_new); // h = x_i * strat->P
 
         if (TEST_OPT_INTSTRATEGY)
-           h.pCleardenom(); // also does a p_Content
+           h.pCleardenom(); // also removes Content
         else
           h.pNorm();
 
@@ -1200,7 +1185,7 @@ ideal k_sca_mora(const ideal F, const ideal Q, const intvec */*w*/, const intvec
     else
       Kstd1_mu=-1;
   }
-  pDelete(&strat->kHEdge);
+  if(strat->kHEdge!=NULL) pLmFree(&strat->kHEdge);
   strat->update = TRUE; //???
   strat->lastAxis = 0; //???
   pDelete(&strat->kNoether);
