@@ -5,35 +5,32 @@
 * ABSTRACT: kernel: utils for shift GB and free GB
 */
 
-
-
-
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
 #ifdef HAVE_SHIFTBBA
-#include <polys/monomials/ring.h>
-#include <kernel/polys.h>
-#include <coeffs/numbers.h>
-#include <kernel/ideals.h>
-#include <polys/matpol.h>
-#include <polys/kbuckets.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <polys/sbuckets.h>
-#include <polys/operations/p_Mult_q.h>
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/structs.h>
-#include <omalloc/omalloc.h>
-#include <kernel/GBEngine/khstd.h>
-#include <polys/kbuckets.h>
-#include <polys/weight.h>
-#include <misc/intvec.h>
-#include <kernel/structs.h>
-#include <kernel/GBEngine/kInline.h>
-#include <kernel/combinatorics/stairc.h>
-#include <polys/weight.h>
-#include <misc/intvec.h>
-#include <kernel/GBEngine/shiftgb.h>
-#include <polys/nc/sca.h>
+#include "polys/monomials/ring.h"
+#include "kernel/polys.h"
+#include "coeffs/numbers.h"
+#include "kernel/ideals.h"
+#include "polys/matpol.h"
+#include "polys/kbuckets.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "polys/sbuckets.h"
+#include "polys/operations/p_Mult_q.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/structs.h"
+#include "omalloc/omalloc.h"
+#include "kernel/GBEngine/khstd.h"
+#include "polys/kbuckets.h"
+#include "polys/weight.h"
+#include "misc/intvec.h"
+#include "kernel/structs.h"
+#include "kernel/GBEngine/kInline.h"
+#include "kernel/combinatorics/stairc.h"
+#include "polys/weight.h"
+#include "misc/intvec.h"
+#include "kernel/GBEngine/shiftgb.h"
+#include "polys/nc/sca.h"
 
 
 #define freeT(A,v) omFreeSize((ADDRESS)A,(v+1)*sizeof(int))
@@ -105,7 +102,7 @@ poly p_mLPshift(poly p, int sh, int uptodeg, int lV, const ring r)
 
   assume(sh>=0);
   int L = p_mLastVblock(p,lV,r);
-  assume(L+sh-1<=uptodeg);
+  assume(L+sh<=uptodeg);
 
   int *e=(int *)omAlloc0((r->N+1)*sizeof(int));
   int *s=(int *)omAlloc0((r->N+1)*sizeof(int));
@@ -219,7 +216,7 @@ int pmFirstVblock(poly p, int lV)
   /* for a monomial p, returns the number of the first block */
   /* where a nonzero exponent is sitting */
   int *e=(int *)omAlloc0((currRing->N+1)*sizeof(int));
-  pGetExpV(p,e);
+  p_GetExpV(p,e,currRing);
   int j,b;
   j = 1;
   while ( (!e[j]) && (j<=currRing->N-1) ) j++;
@@ -250,7 +247,7 @@ int isInV(poly p, int lV)
   int  b = (int)((currRing->N +lV-1)/lV); /* the number of blocks */
   //int b  = (int)(currRing->N)/lV;
   int *B = (int *)omAlloc0((b+1)*sizeof(int)); /* the num of elements in a block */
-  pGetExpV(p,e);
+  p_GetExpV(p,e,currRing);
   int i,j;
   for (j=1; j<=b; j++)
   {
