@@ -7,9 +7,9 @@
 * ABSTRACT: kernel: utils for kStd
 */
 
-#include <kernel/structs.h>
+#include "kernel/structs.h"
 #ifdef HAVE_SHIFTBBA
-#include <polys/nc/nc.h>
+#include "polys/nc/nc.h"
 
 poly p_LPshiftT(poly p, int sh, int uptodeg, int lV, kStrategy strat, const ring r);
 int p_LastVblockT(poly p, int lV, kStrategy strat, const ring r);
@@ -26,9 +26,6 @@ poly p_mLPshift(poly p, int sh, int uptodeg, int lV,const ring r);
 int p_mLastVblock(poly p, int lV,const ring r);
 int p_LastVblock(poly p, int lV, const ring r);
 
-//poly pLPshift(poly p, int sh, int uptodeg, int lV);
-#define pLPshift(p,sh,uptodeg,lV) p_LPshift(p,sh,uptodeg,lV,currRing)
-
 //int pLastVblock(poly p, int lV);
 #define pLastVblock(p,lV) p_LastVblock(p,lV,currRing)
 //int pmLastVblock(poly p, int lV);
