@@ -6,26 +6,22 @@
 * ABSTRACT: resolutions
 */
 
+#include "kernel/mod2.h"
+#include "misc/options.h"
+#include "omalloc/omalloc.h"
+#include "kernel/polys.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/combinatorics/stairc.h"
+#include "misc/intvec.h"
+#include "coeffs/numbers.h"
+#include "kernel/ideals.h"
+#include "misc/intvec.h"
+#include "polys/monomials/ring.h"
+#include "kernel/GBEngine/syz.h"
+#include "polys/prCopy.h"
 
-
-
-
-#include <kernel/mod2.h>
-#include <misc/options.h>
-#include <omalloc/omalloc.h>
-#include <kernel/polys.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/combinatorics/stairc.h>
-#include <misc/intvec.h>
-#include <coeffs/numbers.h>
-#include <kernel/ideals.h>
-#include <misc/intvec.h>
-#include <polys/monomials/ring.h>
-#include <kernel/GBEngine/syz.h>
-#include <polys/prCopy.h>
-
-#include <polys/nc/sca.h>
+#include "polys/nc/sca.h"
 
 static intvec * syPrepareModComp(ideal arg,intvec ** w)
 {
@@ -84,10 +80,9 @@ static void syDeleteAbove(ideal up, int k)
 *minimizes the module mod and cancel superfluous syzygies
 *from syz
 */
-static void syMinStep(ideal mod,ideal syz,BOOLEAN final=FALSE,ideal up=NULL,
+static void syMinStep(ideal mod,ideal &syz,BOOLEAN final=FALSE,ideal up=NULL,
                       tHomog h=isNotHomog)
 {
-  ideal deg0=NULL;
   poly Unit1,Unit2,actWith;
   int len,i,j,ModComp,m,k,l;
   BOOLEAN searchUnit,existsUnit;
@@ -96,7 +91,8 @@ static void syMinStep(ideal mod,ideal syz,BOOLEAN final=FALSE,ideal up=NULL,
   if ((final) && (h==isHomog))
   /*minim is TRUE, we are in the module: maxlength, maxlength <>0*/
   {
-    deg0=id_Jet(syz,0,currRing);
+    ideal deg0=id_Jet(syz,0,currRing);
+    id_Delete(&syz,currRing);
     idSkipZeroes(deg0);
     syz=deg0;
   }
@@ -121,13 +117,15 @@ static void syMinStep(ideal mod,ideal syz,BOOLEAN final=FALSE,ideal up=NULL,
 * in the module below--*/
   searchUnit = TRUE;
   int curr_syz_limit = rGetCurrSyzLimit(currRing);
+  BOOLEAN bHasGlobalOrdering=rHasGlobalOrdering(currRing);
+  BOOLEAN bField_has_simple_inverse=rField_has_simple_inverse(currRing);
   while (searchUnit)
   {
     i=0;
     j=IDELEMS(syz);
     while ((j>0) && (syz->m[j-1]==NULL)) j--;
     existsUnit = FALSE;
-    if (rHasGlobalOrdering(currRing))
+    if (bHasGlobalOrdering)
     {
       while ((i<j) && (!existsUnit))
       {
@@ -163,7 +161,7 @@ static void syMinStep(ideal mod,ideal syz,BOOLEAN final=FALSE,ideal up=NULL,
 //--takes out the founded syzygy--
       if (TEST_OPT_PROT) PrintS("f");
       actWith = syz->m[i];
-      if (!rField_has_simple_inverse(currRing)) p_Cleardenom(actWith, currRing);
+      if (!bField_has_simple_inverse) p_Cleardenom(actWith, currRing);
 //Print("actWith: ");pWrite(actWith);
       syz->m[i] = NULL;
       for (k=i;k<j-1;k++)  syz->m[k] = syz->m[k+1];
@@ -212,8 +210,6 @@ static void syMinStep(ideal mod,ideal syz,BOOLEAN final=FALSE,ideal up=NULL,
   if (TEST_OPT_PROT) PrintLn();
   idSkipZeroes(mod);
   idSkipZeroes(syz);
-  if (deg0!=NULL)
-    idDelete(&deg0);
 }
 
 /*2
@@ -295,7 +291,6 @@ static void syMinStep1(resolvente res, int length)
 {
   int i,j,k,index=0;
   poly p;
-  ideal deg0=NULL,reddeg0=NULL;
   intvec *have_del=NULL,*to_del=NULL;
 
   while ((index<length) && (res[index]!=NULL))
@@ -303,8 +298,8 @@ static void syMinStep1(resolvente res, int length)
 /*---we take out dependend elements from syz---------------------*/
     if (res[index+1]!=NULL)
     {
-      deg0 = id_Jet(res[index+1],0,currRing);
-      reddeg0 = kInterRedOld(deg0);
+      ideal deg0 = id_Jet(res[index+1],0,currRing);
+      ideal reddeg0 = kInterRedOld(deg0);
       idDelete(&deg0);
       have_del = new intvec(IDELEMS(res[index]));
       for (i=0;i<IDELEMS(reddeg0);i++)
@@ -355,6 +350,7 @@ static void syMinStep1(resolvente res, int length)
   }
   if (TEST_OPT_PROT) PrintLn();
   syKillEmptyEntres(res,length);
+  if (to_del!=NULL) delete to_del;
 }
 
 void syMinimizeResolvente(resolvente res, int length, int first)
@@ -363,7 +359,7 @@ void syMinimizeResolvente(resolvente res, int length, int first)
   intvec *dummy;
 
   if (syzIndex<1) syzIndex=1;
-  if ((syzIndex==1) && (idHomModule(res[0],currRing->qideal,&dummy)) && (!rIsPluralRing(currRing)))
+  if ((syzIndex==1) && (!rIsPluralRing(currRing)) && (idHomModule(res[0],currRing->qideal,&dummy)))
   {
     syMinStep1(res,length);
     delete dummy;
@@ -396,10 +392,8 @@ resolvente syResolvente(ideal arg, int maxlength, int * length,
 {
   BITSET save1;
   SI_SAVE_OPT1(save1);
-  resolvente res;
   resolvente newres;
   tHomog hom=isNotHomog;
-  ideal temp=NULL;
   intvec *w = NULL,**tempW;
   int i,k,syzIndex = 0,j,rk_arg=si_max(1,(int)id_RankFreeModule(arg,currRing));
   int Kstd1_OldDeg=Kstd1_deg;
@@ -417,7 +411,7 @@ resolvente syResolvente(ideal arg, int maxlength, int * length,
     omFreeSize((ADDRESS)*weights,wlength*sizeof(intvec*));
     *weights=wtmp;
   }
-  res = (resolvente)omAlloc0((*length)*sizeof(ideal));
+  resolvente res = (resolvente)omAlloc0((*length)*sizeof(ideal));
 
 /*--- initialize the syzygy-ring -----------------------------*/
   ring origR = currRing;
@@ -522,12 +516,11 @@ resolvente syResolvente(ideal arg, int maxlength, int * length,
     if(! TEST_OPT_NO_SYZ_MINIM )
     if (minim || (syzIndex!=0))
     {
-      temp = kInterRedOld(res[syzIndex],currRing->qideal);
+      ideal temp = kInterRedOld(res[syzIndex],currRing->qideal);
       idDelete(&res[syzIndex]);
       idSkipZeroes(temp);
       res[syzIndex] = temp;
     }
-    temp = NULL;
 /*--- computing the syzygy modules --------------------------------*/
     if ((currRing->qideal==NULL)&&(syzIndex==0)&& (!TEST_OPT_DEGBOUND))
     {
@@ -622,25 +615,15 @@ syStrategy syResolution(ideal arg, int maxlength,intvec * w, BOOLEAN minim)
 {
 
 #ifdef HAVE_PLURAL
-
   const ideal idSaveCurrRingQuotient = currRing->qideal;
-
   if( rIsSCA(currRing) )
   {
-
-#ifdef RDEBUG
-//    rWrite(currRing);
-//    rDebugPrint(currRing);
-#endif
-
     if( ncExtensions(TESTSYZSCAMASK) )
     {
       currRing->qideal = SCAQuotient(currRing);
     }
-
     const unsigned int m_iFirstAltVar = scaFirstAltVar(currRing);
     const unsigned int m_iLastAltVar  = scaLastAltVar(currRing);
-
     arg = id_KillSquares(arg, m_iFirstAltVar, m_iLastAltVar, currRing, false); // kill suares in input!
   }
 #endif
@@ -660,7 +643,8 @@ syStrategy syResolution(ideal arg, int maxlength,intvec * w, BOOLEAN minim)
     (result->weights)[0] = ivCopy(w);
     result->length = 1;
   }
-  resolvente fr = syResolvente(arg,maxlength,&(result->length),&(result->weights),minim),fr1;
+  resolvente fr = syResolvente(arg,maxlength,&(result->length),&(result->weights),minim);
+  resolvente fr1;
   if (minim)
   {
     result->minres = (resolvente)omAlloc0((result->length+1)*sizeof(ideal));
@@ -679,21 +663,17 @@ syStrategy syResolution(ideal arg, int maxlength,intvec * w, BOOLEAN minim)
   }
   omFreeSize((ADDRESS)fr,(result->length)*sizeof(ideal));
 
-
 #ifdef HAVE_PLURAL
   if( rIsSCA(currRing) )
   {
-
     if( ncExtensions(TESTSYZSCAMASK) )
     {
       currRing->qideal = idSaveCurrRingQuotient;
     }
-
     id_Delete(&arg, currRing);
   }
 #endif
 
-
   return result;
 }
 
@@ -830,7 +810,7 @@ intvec * syBetti(resolvente res,int length, int * regularity,
 #if 0
   if (idHomModule(res[0],currRing->qideal,&w)!=isHomog)
   {
-    Warn("betti-command: Input is not homogeneous!");
+    WarnS("betti-command: Input is not homogeneous!");
     weights=NULL;
   }
 #endif
@@ -866,7 +846,7 @@ intvec * syBetti(resolvente res,int length, int * regularity,
         //|| ((i>1) && (res[i-1]->m[pGetComp(res[i]->m[j])-1]==NULL))
 	)
         {
-          WerrorS("input not a resolvent");
+          WerrorS("input not a resolution");
           omFreeSize((ADDRESS)temp1,(l+1)*sizeof(int));
           omFreeSize((ADDRESS)temp2,(l+1)*sizeof(int));
           return NULL;
