@@ -5,26 +5,21 @@
 * ABSTRACT: resolutions
 */
 
-
-
-
-
-#include <kernel/mod2.h>
-#include <misc/options.h>
-#include <omalloc/omalloc.h>
-#include <kernel/polys.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/combinatorics/stairc.h>
-//#include "cntrlc.h"
-#include <misc/intvec.h>
-#include <coeffs/numbers.h>
-#include <kernel/ideals.h>
-#include <misc/intvec.h>
-#include <polys/monomials/ring.h>
-#include <kernel/GBEngine/syz.h>
-#include <polys/kbuckets.h>
-#include <polys/prCopy.h>
+#include "kernel/mod2.h"
+#include "misc/options.h"
+#include "omalloc/omalloc.h"
+#include "kernel/polys.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/combinatorics/stairc.h"
+#include "misc/intvec.h"
+#include "coeffs/numbers.h"
+#include "kernel/ideals.h"
+#include "misc/intvec.h"
+#include "polys/monomials/ring.h"
+#include "kernel/GBEngine/syz.h"
+#include "polys/kbuckets.h"
+#include "polys/prCopy.h"
 
 static void syInitSort(ideal arg,intvec **modcomp)
 {
@@ -595,7 +590,7 @@ static ideal sySchreyersSyzygiesFB(ideal arg,intvec ** modcomp,ideal mW,BOOLEAN
           syz->coef = nCopy(currRing->qideal->m[k-Fl]->coef);
           syz->coef = nInpNeg(syz->coef);
           lastmonom = syz;
-          multWith = pDivide(syz,F[j]);
+          multWith = pMDivide(syz,F[j]);
           multWith->coef = nCopy(currRing->qideal->m[k-Fl]->coef);
         }
         pSetComp(syz,j+1);
@@ -697,7 +692,7 @@ static ideal sySchreyersSyzygiesFB(ideal arg,intvec ** modcomp,ideal mW,BOOLEAN
 #ifdef WRITE_BUCKETS
               PrintS("multiplied with: ");nWrite(up);PrintLn();
 #endif
-              pMult_nn(syz,up);
+              syz=__p_Mult_nn(syz,up,currRing);
             }
             nDelete(&up);
 
