@@ -5,31 +5,26 @@
 * ABSTRACT: resolutions
 */
 
+#include "kernel/mod2.h"
 
+#include "misc/mylimits.h"
+#include "omalloc/omalloc.h"
 
+#include "misc/options.h"
+#include "misc/intvec.h"
+#include "coeffs/numbers.h"
 
-#include <kernel/mod2.h>
+#include "polys/monomials/ring.h"
+#include "polys/kbuckets.h"
+#include "polys/prCopy.h"
 
-#include <misc/mylimits.h>
-#include <omalloc/omalloc.h>
+#include "kernel/polys.h"
 
-#include <misc/options.h>
-#include <misc/intvec.h>
-#include <coeffs/numbers.h>
-
-#include <polys/monomials/ring.h>
-#include <polys/kbuckets.h>
-#include <polys/prCopy.h>
-
-#include <kernel/polys.h>
-
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/kutil.h>
-#include <kernel/combinatorics/stairc.h>
-//#include "cntrlc.h"
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/syz.h>
-// #include <kernel/idrec.h>
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/combinatorics/stairc.h"
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/syz.h"
 
 extern void p_Setm_Syz(poly p, ring r,
                        int* Components, long* ShiftedComponents);
@@ -40,8 +35,6 @@ int *  currcomponents=NULL;
 long *  currShiftedComponents=NULL;
 
 
-/*---head-term-polynomials for the reduction------------*/
-static poly redpol=NULL;
 /*---counts number of applications of GM-criteria-------*/
 //static int crit;
 //static int euler;
@@ -385,7 +378,7 @@ long syReorderShiftedComponents(long * sc, int n)
   }
 
   assume(LONG_MAX -  SYZ_SHIFT_BASE > tc[n-1]);
-#ifdef HAVE_ASSUME
+#ifndef SING_NDEBUG
   for (i=1; i<n; i++)
   {
     assume(tc[i] >= 0);
@@ -1531,7 +1524,7 @@ void syKillComputation(syStrategy syzstr, ring r)
       }
       omFreeSize((ADDRESS)syzstr->fullres,(syzstr->length+1)*sizeof(ideal));
     }
-    if (syzstr->weights!=0)
+    if (syzstr->weights!=NULL)
     {
       for (i=0;i<syzstr->length;i++)
       {
@@ -2403,6 +2396,13 @@ syStrategy syMinimize(syStrategy syzstr)
 {
   if (syzstr->minres==NULL)
   {
+    if (syzstr->resolution!=NULL)
+    {
+      // need to clear syzstr->resolution, as we are
+      // now displaying the minres instead of fullres
+      delete syzstr->resolution;
+      syzstr->resolution=NULL;
+    }
     if (syzstr->resPairs!=NULL)
     {
       if (syzstr->hilb_coeffs==NULL)
@@ -2451,7 +2451,6 @@ syStrategy syLaScala3(ideal arg,int * length)
 
   //crit = 0;
   //euler = -1;
-  redpol = pInit();
   syzstr->length = *length = (currRing->N)+2;
 
   // Creare dp,S ring and change to it
@@ -2536,7 +2535,6 @@ syStrategy syLaScala3(ideal arg,int * length)
 
   if (origR != syzstr->syRing)
     rChangeCurrRing(origR);
-  pLmDelete(&redpol);
 
   if (TEST_OPT_PROT) PrintLn();
 
@@ -2585,7 +2583,6 @@ syStrategy syLaScala(ideal arg, int& maxlength, intvec* weights)
 
   //crit = 0;
   //euler = -1;
-  redpol = pInit();
 
   if( maxlength > 0 )
     syzstr->length = maxlength; //  = (currRing->N)+2;
@@ -2680,7 +2677,6 @@ syStrategy syLaScala(ideal arg, int& maxlength, intvec* weights)
   kBucketDestroy(&(syzstr->bucket));
   if (origR != syzstr->syRing)
     rChangeCurrRing(origR);
-  pLmDelete(&redpol);
   if (TEST_OPT_PROT) PrintLn();
   return syzstr;
 }
