@@ -5,19 +5,19 @@
 *  ABSTRACT -  dimension, multiplicity, HC, kbase
 */
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
-#include <misc/intvec.h>
-#include <coeffs/numbers.h>
+#include "omalloc/omalloc.h"
+#include "misc/intvec.h"
+#include "coeffs/numbers.h"
 
-#include <kernel/structs.h>
-#include <kernel/ideals.h>
-#include <kernel/polys.h>
+#include "kernel/structs.h"
+#include "kernel/ideals.h"
+#include "kernel/polys.h"
 
-#include <kernel/combinatorics/hutil.h>
-#include <kernel/combinatorics/hilb.h>
-#include <kernel/combinatorics/stairc.h>
+#include "kernel/combinatorics/hutil.h"
+#include "kernel/combinatorics/hilb.h"
+#include "kernel/combinatorics/stairc.h"
 
 int  hCo, hMu, hMu2;
 omBin indlist_bin = omGetSpecBin(sizeof(indlist));
@@ -1408,7 +1408,7 @@ ende:
   hDelete(hexist, hNexist);
   omFreeSize((ADDRESS)act, ((currRing->N) + 1) * sizeof(int));
   hKill(stcmem, (currRing->N) - 1);
-  pLmDelete(&p);
+  pLmFree(&p);
   if (p == NULL)
     return idInit(1,s->rank);
 
