@@ -1,80 +1,73 @@
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <resources/feFopen.h>
-#include <resources/feResource.h>
+#include "resources/feFopen.h"
+#include "resources/feResource.h"
 
 
-#include <factory/factory.h> // :(
+#include "factory/factory.h" // :(
 
-#include <misc/intvec.h>
-#include <misc/int64vec.h>
-#include <misc/mylimits.h>
-#include <misc/options.h>
+#include "misc/intvec.h"
+#include "misc/int64vec.h"
+#include "misc/mylimits.h"
+#include "misc/options.h"
 
-#include <reporter/reporter.h>
+#include "reporter/reporter.h"
 
-#include <coeffs/si_gmp.h>
-#include <coeffs/coeffs.h>
-#include <coeffs/numbers.h>
+#include "coeffs/si_gmp.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
 
 #ifndef PLURAL_INTERNAL_DECLARATIONS
 #define PLURAL_INTERNAL_DECLARATIONS
 #endif
 
-#include <polys/nc/gb_hack.h>
-#include <polys/nc/nc.h>
-#include <polys/nc/ncSACache.h>
-#include <polys/nc/ncSAFormula.h>
-#include <polys/nc/ncSAMult.h>
-#include <polys/nc/sca.h>
-#include <polys/nc/summator.h>
+#include "polys/nc/gb_hack.h"
+#include "polys/nc/nc.h"
+#include "polys/nc/ncSACache.h"
+#include "polys/nc/ncSAFormula.h"
+#include "polys/nc/ncSAMult.h"
+#include "polys/nc/sca.h"
+#include "polys/nc/summator.h"
 
-#include <polys/kbuckets.h>
-#include <polys/matpol.h>
-#include <polys/mod_raw.h>
-#include <polys/prCopy.h>
-#include <polys/sbuckets.h>
-#include <polys/simpleideals.h>
-#include <polys/weight.h>
+#include "polys/kbuckets.h"
+#include "polys/matpol.h"
+#include "polys/mod_raw.h"
+#include "polys/prCopy.h"
+#include "polys/sbuckets.h"
+#include "polys/simpleideals.h"
+#include "polys/weight.h"
 
-#include <polys/monomials/maps.h>
-#include <polys/monomials/monomials.h>
-#include <polys/monomials/p_polys.h>
-#include <polys/monomials/ring.h>
+#include "polys/monomials/maps.h"
+#include "polys/monomials/monomials.h"
+#include "polys/monomials/p_polys.h"
+#include "polys/monomials/ring.h"
 
-#include <polys/templates/p_MemAdd.h>
-#include <polys/templates/p_Procs.h>
+#include "polys/templates/p_MemAdd.h"
+#include "polys/templates/p_Procs.h"
 
-#include <polys/operations/pShallowCopyDelete.h>
+#include "polys/operations/pShallowCopyDelete.h"
 
-#include <polys/clapsing.h>
-
-
-// // TODO: DUE to the use of HALT in npolygon.cc :(((
-extern "C" {void m2_end(int i){exit(i);}}
-
-// // TODO: DUE to its use in kutil.cc :(((
-// char * showOption(){return NULL;}
+#include "polys/clapsing.h"
 
 
 // #include "structs.h"
 
 
 // HEADERS:
-#include <kernel/combinatorics/hutil.h>
-#include <kernel/combinatorics/hilb.h>
-#include <kernel/combinatorics/stairc.h>
+#include "kernel/combinatorics/hutil.h"
+#include "kernel/combinatorics/hilb.h"
+#include "kernel/combinatorics/stairc.h"
 
-#include <kernel/ideals.h>
-#include <kernel/digitech.h>
-#include <kernel/fast_mult.h>
+#include "kernel/ideals.h"
+#include "kernel/digitech.h"
+#include "kernel/fast_mult.h"
 
-// #include <kernel/spectrum/kmatrix.h>
-#include <kernel/preimage.h>
-#include <kernel/structs.h>
-#include <kernel/polys.h>
+// #include "kernel/spectrum/kmatrix.h"
+#include "kernel/preimage.h"
+#include "kernel/structs.h"
+#include "kernel/polys.h"
 
 void TestGBEngine()
 {
