@@ -10,18 +10,18 @@
 
 
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <factory/factory.h>
-#include <misc/options.h>
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
-#include <polys/monomials/ring.h>
-#include <polys/monomials/maps.h>
-#include <omalloc/omalloc.h>
+#include "factory/factory.h"
+#include "misc/options.h"
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
+#include "polys/monomials/ring.h"
+#include "polys/monomials/maps.h"
+#include "omalloc/omalloc.h"
 #include "fglmvec.h"
 #include "fglmgauss.h"
-#include <kernel/GBEngine/kstd1.h>
+#include "kernel/GBEngine/kstd1.h"
 
 #include "fglm.h"
 
@@ -117,7 +117,7 @@ fglmReductionStep( poly * pptr, ideal source, int * w )
         nDelete( & n1 );
         n1= temp;
         n1= nInpNeg( n1 );
-        pMult_nn( p2, n1 );
+        p2=__p_Mult_nn( p2, n1, currRing );
 //         pNormalize( p2 );
         nDelete( & n1 );
         *pptr= pAdd( *pptr, p2 );
@@ -379,8 +379,7 @@ poly fglmNewLinearCombination( ideal source, poly monset )
                 pSetCoeff( sum, nCopy( temp.getconstelem( k ) ) );
             }
         }
-        p_Content( result, currRing );
-        if ( ! nGreaterZero( pGetCoeff( result ) ) ) result= pNeg( result );
+        p_Cleardenom( result, currRing );
     }
     // Free Memory
     omFreeSize( (ADDRESS)lengthes, numMonoms * sizeof( int ) );
