@@ -7,40 +7,36 @@
 
 /* includes */
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#ifndef SING_NDEBUG
-# define MYTEST 0
-#else /* ifndef SING_NDEBUG */
-# define MYTEST 0
-#endif /* ifndef SING_NDEBUG */
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <omalloc/omalloc.h>
-
-#include <misc/options.h>
-#include <misc/intvec.h>
-
-#include <coeffs/coeffs.h>
-#include <coeffs/numbers.h>
-// #include <coeffs/longrat.h>
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
+// #include "coeffs/longrat.h"
 
 
-#include <polys/monomials/ring.h>
-#include <polys/matpol.h>
-#include <polys/weight.h>
-#include <polys/sparsmat.h>
-#include <polys/prCopy.h>
-#include <polys/nc/nc.h>
+#include "polys/monomials/ring.h"
+#include "polys/matpol.h"
+#include "polys/weight.h"
+#include "polys/sparsmat.h"
+#include "polys/prCopy.h"
+#include "polys/nc/nc.h"
 
 
-#include <kernel/ideals.h>
+#include "kernel/ideals.h"
 
-#include <kernel/polys.h>
+#include "kernel/polys.h"
 
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/syz.h>
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/kutil.h"
+#include "kernel/GBEngine/tgb.h"
+#include "kernel/GBEngine/syz.h"
+#include "Singular/ipshell.h" // iiCallLibProc1
+#include "Singular/ipid.h" // ggetid
 
 
 /* #define WITH_OLD_MINOR */
@@ -57,14 +53,12 @@ ideal idMinBase (ideal h1)
   int i,l,ll;
   intvec * wth;
   BOOLEAN homog;
-  #ifdef HAVE_RINGS
   if(rField_is_Ring(currRing))
   {
       WarnS("minbase applies only to the local or homogeneous case over coefficient fields");
       e=idCopy(h1);
       return e;
   }
-  #endif
   homog = idHomModule(h1,currRing->qideal,&wth);
   if (rHasGlobalOrdering(currRing))
   {
@@ -134,10 +128,6 @@ ideal idMinBase (ideal h1)
 }
 
 
-/*2
-*initialized a field with r numbers between beg and end for the
-*procedure idNextChoise
-*/
 ideal idSectWithElim (ideal h1,ideal h2)
 // does not destroy h1,h2
 {
@@ -155,7 +145,7 @@ ideal idSectWithElim (ideal h1,ideal h2)
   r->block0[0]=1;
   r->block1[0]= r->N;
   omFree(r->order);
-  r->order=(int*)omAlloc0(3*sizeof(int*));
+  r->order=(rRingOrder_t*)omAlloc0(3*sizeof(rRingOrder_t));
   r->order[0]=ringorder_dp;
   r->order[1]=ringorder_C;
   char **names=(char**)omAlloc0(rVar(r) * sizeof(char_ptr));
@@ -173,8 +163,8 @@ ideal idSectWithElim (ideal h1,ideal h2)
   // create 1-t, t
   poly omt=p_One(currRing);
   p_SetExp(omt,r->N,1,currRing);
-  poly t=p_Copy(omt,currRing);
   p_Setm(omt,currRing);
+  poly t=p_Copy(omt,currRing);
   omt=p_Neg(omt,currRing);
   omt=p_Add_q(omt,pOne(),currRing);
   // compute (1-t)*h1
@@ -196,10 +186,10 @@ ideal idSectWithElim (ideal h1,ideal h2)
   idDelete(&h1);
   idDelete(&h2);
   // eliminate t:
-
   ideal res=idElimination(h,t);
   // cleanup
   idDelete(&h);
+  pDelete(&t);
   if (res!=NULL) res=idrMoveR(res,r,origRing);
   rChangeCurrRing(origRing);
   rDelete(r);
@@ -208,9 +198,10 @@ ideal idSectWithElim (ideal h1,ideal h2)
 /*2
 * h3 := h1 intersect h2
 */
-ideal idSect (ideal h1,ideal h2)
+ideal idSect (ideal h1,ideal h2, GbVariant alg)
 {
-  int i,j,k,length;
+  int i,j,k;
+  unsigned length;
   int flength = id_RankFreeModule(h1,currRing);
   int slength = id_RankFreeModule(h2,currRing);
   int rank=si_max(h1->rank,h2->rank);
@@ -244,8 +235,9 @@ ideal idSect (ideal h1,ideal h2)
   j = IDELEMS(first);
 
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE); rChangeCurrRing(syz_ring);
-  rSetSyzComp(length, syz_ring);
+  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE);
+  rSetSyzComp(length,syz_ring);
+  rChangeCurrRing(syz_ring);
 
   while ((j>0) && (first->m[j-1]==NULL)) j--;
   temp = idInit(j /*IDELEMS(first)*/+IDELEMS(second),length+j);
@@ -281,9 +273,88 @@ ideal idSect (ideal h1,ideal h2)
     }
   }
   intvec *w=NULL;
-  temp1 = kStd(temp,currRing->qideal,testHomog,&w,NULL,length);
-  if (w!=NULL) delete w;
-  idDelete(&temp);
+  if (alg==GbDefault) alg=GbStd;
+  if (alg==GbStd)
+  {
+    if (TEST_OPT_PROT) { PrintS("std:"); mflush(); }
+    temp1 = kStd(temp,currRing->qideal,testHomog,&w,NULL,length);
+    if (w!=NULL) delete w;
+    idDelete(&temp);
+  }
+  else if (alg==GbSlimgb)
+  {
+    if (TEST_OPT_PROT) { PrintS("slimgb:"); mflush(); }
+    temp1 = t_rep_gb(currRing, temp, temp->rank);
+    idDelete(&temp);
+  }
+  else if (alg==GbGroebner)
+  {
+    if (TEST_OPT_PROT) { PrintS("groebner:"); mflush(); }
+    BOOLEAN err;
+    temp1=(ideal)iiCallLibProc1("groebner",temp,MODUL_CMD,err);
+    if (err)
+    {
+      Werror("error %d in >>groebner<<",err);
+      temp1=idInit(1,1);
+    }
+  }
+  else if (alg==GbModstd)
+  {
+    if (TEST_OPT_PROT) { PrintS("modStd:"); mflush(); }
+    BOOLEAN err;
+    void *args[]={temp,(void*)1,NULL};
+    int arg_t[]={MODUL_CMD,INT_CMD,0};
+    temp1=(ideal)iiCallLibProcM("modStd",args,arg_t,err);
+    if (err)
+    {
+      Werror("error %d in >>modStd<<",err);
+      temp1=idInit(1,1);
+    }
+  }
+  else if (alg==GbStdSat)
+  {
+    if (TEST_OPT_PROT) { PrintS("std:sat:"); mflush(); }
+    BOOLEAN err;
+    // search for 2nd block of vars
+    int i=0;
+    int block=-1;
+    loop
+    {
+      if ((currRing->order[i]!=ringorder_c)
+      && (currRing->order[i]!=ringorder_C)
+      && (currRing->order[i]!=ringorder_s))
+      {
+        if (currRing->order[i]==0) { err=TRUE;break;}
+        block++;
+        if (block==1) { block=i; break;}
+      }
+      i++;
+    }
+    if (block>0)
+    {
+      if (TEST_OPT_PROT)
+      {
+        Print("sat(%d..%d)\n",currRing->block0[block],currRing->block1[block]);
+        mflush();
+      }
+      ideal v=idInit(currRing->block1[block]-currRing->block0[block]+1,1);
+      for(i=currRing->block0[block];i<=currRing->block1[block];i++)
+      {
+        v->m[i-currRing->block0[block]]=pOne();
+        pSetExp(v->m[i-currRing->block0[block]],i,1);
+        pSetm(v->m[i-currRing->block0[block]]);
+      }
+      void *args[]={temp,v,NULL};
+      int arg_t[]={MODUL_CMD,IDEAL_CMD,0};
+      temp1=(ideal)iiCallLibProcM("satstd",args,arg_t,err);
+    }
+    if (err)
+    {
+      Werror("error %d in >>satstd<<",err);
+      temp1=idInit(1,1);
+    }
+  }
+
   if(syz_ring!=orig_ring)
     rChangeCurrRing(orig_ring);
 
@@ -292,7 +363,7 @@ ideal idSect (ideal h1,ideal h2)
   for (i=0;i<IDELEMS(temp1);i++)
   {
     if ((temp1->m[i]!=NULL)
-    && (p_GetComp(temp1->m[i],syz_ring)>length))
+    && (__p_GetComp(temp1->m[i],syz_ring)>length))
     {
       if(syz_ring==orig_ring)
       {
@@ -347,9 +418,10 @@ ideal idSect (ideal h1,ideal h2)
 * ideal/module intersection for a list of objects
 * given as 'resolvente'
 */
-ideal idMultSect(resolvente arg, int length)
+ideal idMultSect(resolvente arg, int length, GbVariant alg)
 {
-  int i,j=0,k=0,syzComp,l,maxrk=-1,realrki;
+  int i,j=0,k=0,l,maxrk=-1,realrki;
+  unsigned syzComp;
   ideal bigmat,tempstd,result;
   poly p;
   int isIdeal=0;
@@ -383,8 +455,9 @@ ideal idMultSect(resolvente arg, int length)
   syzComp = k*maxrk;
 
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE); rChangeCurrRing(syz_ring);
-  rSetSyzComp(syzComp, syz_ring);
+  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE);
+  rSetSyzComp(syzComp,syz_ring);
+  rChangeCurrRing(syz_ring);
 
   bigmat = idInit(j,(k+1)*maxrk);
   /* create unit matrices ------------------------------------------*/
@@ -421,9 +494,53 @@ ideal idMultSect(resolvente arg, int length)
     }
   }
   /* std computation --------------------------------------------*/
-  tempstd = kStd(bigmat,currRing->qideal,testHomog,&w,NULL,syzComp);
-  if (w!=NULL) delete w;
-  idDelete(&bigmat);
+  if (alg==GbDefault) alg=GbStd;
+  if (alg==GbStd)
+  {
+    if (TEST_OPT_PROT) { PrintS("std:"); mflush(); }
+    tempstd = kStd(bigmat,currRing->qideal,testHomog,&w,NULL,syzComp);
+    if (w!=NULL) delete w;
+    idDelete(&bigmat);
+  }
+  else if (alg==GbSlimgb)
+  {
+    if (TEST_OPT_PROT) { PrintS("slimgb:"); mflush(); }
+    tempstd = t_rep_gb(currRing, bigmat, syzComp);
+    idDelete(&bigmat);
+  }
+  else if (alg==GbGroebner)
+  {
+    if (TEST_OPT_PROT) { PrintS("groebner:"); mflush(); }
+    BOOLEAN err;
+    tempstd=(ideal)iiCallLibProc1("groebner",bigmat,MODUL_CMD,err);
+    if (err)
+    {
+      Werror("error %d in >>groebner<<",err);
+      tempstd=idInit(1,1);
+    }
+  }
+//  else if (alg==GbModstd): requires ideal, not module
+//  {
+//    if (TEST_OPT_PROT) { PrintS("modstd:"); mflush(); }
+//    BOOLEAN err;
+//    tempstd=(ideal)iiCallLibProc1("modStd",bigmat,MODUL_CMD,err);
+//    if (err)
+//    {
+//      Werror("error %d in >>modStd<<",err);
+//      tempstd=idInit(1,1);
+//    }
+//  }
+  //else if (alg==GbSba): requires order C,...
+  //{
+  //  if (TEST_OPT_PROT) { PrintS("sba:"); mflush(); }
+  //  tempstd = kSba(bigmat,currRing->qideal,hom,w,1,0,NULL,syzComp);
+  //  idDelete(&bigmat);
+  //}
+  else
+  {
+    tempstd=idInit(1,1);
+    Werror("wrong algorithm %d for SB",(int)alg);
+  }
 
   if(syz_ring!=orig_ring)
     rChangeCurrRing(orig_ring);
@@ -433,7 +550,7 @@ ideal idMultSect(resolvente arg, int length)
   k = 0;
   for (j=0;j<IDELEMS(tempstd);j++)
   {
-    if ((tempstd->m[j]!=NULL) && (p_GetComp(tempstd->m[j],syz_ring)>syzComp))
+    if ((tempstd->m[j]!=NULL) && (__p_GetComp(tempstd->m[j],syz_ring)>syzComp))
     {
       if (syz_ring==orig_ring)
         p = pCopy(tempstd->m[j]);
@@ -462,9 +579,9 @@ ideal idMultSect(resolvente arg, int length)
 *if quot != NULL it computes in the quotient ring modulo "quot"
 *works always in a ring with ringorder_s
 */
-static ideal idPrepare (ideal  h1, tHomog hom, int syzcomp, intvec **w)
+static ideal idPrepare (ideal  h1, tHomog hom, int syzcomp, intvec **w, GbVariant alg)
 {
-  ideal   h2, h3;
+  ideal   h2;
   int     j,k;
   poly    p,q;
 
@@ -493,15 +610,6 @@ static ideal idPrepare (ideal  h1, tHomog hom, int syzcomp, intvec **w)
   //  }
   //}
 
-#if MYTEST
-#ifdef RDEBUG
-  Print("Prepare::h2: ");
-  idPrint(h2);
-
-  idTest(h2);
-#endif
-#endif
-
   for (j=0; j<i; j++)
   {
     p = h2->m[j];
@@ -517,32 +625,97 @@ static ideal idPrepare (ideal  h1, tHomog hom, int syzcomp, intvec **w)
       h2->m[j]=q;
   }
 
-#ifdef PDEBUG
-  for(j=0;j<IDELEMS(h2);j++) pTest(h2->m[j]);
-
-#if MYTEST
-#ifdef RDEBUG
-  Print("Prepare::Input: ");
-  idPrint(h2);
-
-  Print("Prepare::currQuotient: ");
-  idPrint(currRing->qideal);
-#endif
-#endif
-
-#endif
-
   idTest(h2);
 
-  h3 = kStd(h2,currRing->qideal,hom,w,NULL,syzcomp);
-
-#if MYTEST
-#ifdef RDEBUG
-  Print("Prepare::Output: ");
-  idPrint(h3);
-  idpTest(h3);
-#endif
-#endif
+  ideal h3=NULL;
+  if (alg==GbDefault) alg=GbStd;
+  if (alg==GbStd)
+  {
+    if (TEST_OPT_PROT) { PrintS("std:"); mflush(); }
+    h3 = kStd(h2,currRing->qideal,hom,w,NULL,syzcomp);
+  }
+  else if (alg==GbSlimgb)
+  {
+    if (TEST_OPT_PROT) { PrintS("slimgb:"); mflush(); }
+    h3 = t_rep_gb(currRing, h2, syzcomp);
+  }
+  else if (alg==GbGroebner)
+  {
+    if (TEST_OPT_PROT) { PrintS("groebner:"); mflush(); }
+    BOOLEAN err;
+    h3=(ideal)iiCallLibProc1("groebner",idCopy(h2),MODUL_CMD,err);
+    if (err)
+    {
+      Werror("error %d in >>groebner<<",err);
+      h3=idInit(1,1);
+    }
+  }
+  else if (alg==GbModstd)
+  {
+    if (TEST_OPT_PROT) { PrintS("modstd:"); mflush(); }
+    BOOLEAN err;
+    void *args[]={idCopy(h2),(void*)1,NULL};
+    int arg_t[]={MODUL_CMD,INT_CMD,0};
+    h3=(ideal)iiCallLibProcM("modStd",args,arg_t,err);
+    if (err)
+    {
+      Werror("error %d in >>modStd<<",err);
+      h3=idInit(1,1);
+    }
+  }
+  else if (alg==GbStdSat)
+  {
+    if (TEST_OPT_PROT) { PrintS("std:sat:"); mflush(); }
+    BOOLEAN err;
+    // search for 2nd block of vars
+    int i=0;
+    int block=-1;
+    loop
+    {
+      if ((currRing->order[i]!=ringorder_c)
+      && (currRing->order[i]!=ringorder_C)
+      && (currRing->order[i]!=ringorder_s))
+      {
+        if (currRing->order[i]==0) { err=TRUE;break;}
+        block++;
+        if (block==1) { block=i; break;}
+      }
+      i++;
+    }
+    if (block>0)
+    {
+      if (TEST_OPT_PROT)
+      {
+        Print("sat(%d..%d)\n",currRing->block0[block],currRing->block1[block]);
+        mflush();
+      }
+      ideal v=idInit(currRing->block1[block]-currRing->block0[block]+1,1);
+      for(i=currRing->block0[block];i<=currRing->block1[block];i++)
+      {
+        v->m[i-currRing->block0[block]]=pOne();
+        pSetExp(v->m[i-currRing->block0[block]],i,1);
+        pSetm(v->m[i-currRing->block0[block]]);
+      }
+      void *args[]={idCopy(h2),v,NULL};
+      int arg_t[]={MODUL_CMD,IDEAL_CMD,0};
+      h3=(ideal)iiCallLibProcM("satstd",args,arg_t,err);
+    }
+    if (err)
+    {
+      Werror("error %d in >>satstd<<",err);
+      h3=idInit(1,1);
+    }
+  }
+  //else if (alg==GbSba): requires order C,...
+  //{
+  //  if (TEST_OPT_PROT) { PrintS("sba:"); mflush(); }
+  //  h3 = kSba(h2,currRing->qideal,hom,w,1,0,NULL,syzcomp);
+  //}
+  else
+  {
+    h3=idInit(1,1);
+    Werror("wrong algorithm %d for SB",(int)alg);
+  }
 
   idDelete(&h2);
   return h3;
@@ -555,7 +728,7 @@ static ideal idPrepare (ideal  h1, tHomog hom, int syzcomp, intvec **w)
 * do not change h1,  w
 */
 ideal idSyzygies (ideal  h1, tHomog h,intvec **w, BOOLEAN setSyzComp,
-                  BOOLEAN setRegularity, int *deg)
+                  BOOLEAN setRegularity, int *deg, GbVariant alg)
 {
   ideal s_h1;
   int   j, k, length=0,reg;
@@ -578,13 +751,12 @@ ideal idSyzygies (ideal  h1, tHomog h,intvec **w, BOOLEAN setSyzComp,
 
   assume(currRing != NULL);
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzComp(orig_ring,TRUE); rChangeCurrRing(syz_ring);
-
-  if (setSyzComp)
-    rSetSyzComp(k,syz_ring);
+  ring syz_ring=rAssure_SyzComp(orig_ring,TRUE);
+  if (setSyzComp) rSetSyzComp(k,syz_ring);
 
   if (orig_ring != syz_ring)
   {
+    rChangeCurrRing(syz_ring);
     s_h1=idrCopyR_NoSort(h1,orig_ring,syz_ring);
   }
   else
@@ -594,10 +766,15 @@ ideal idSyzygies (ideal  h1, tHomog h,intvec **w, BOOLEAN setSyzComp,
 
   idTest(s_h1);
 
-  ideal s_h3=idPrepare(s_h1,h,k,w); // main (syz) GB computation
+  ideal s_h3=idPrepare(s_h1,h,k,w,alg); // main (syz) GB computation
 
   if (s_h3==NULL)
   {
+    if (orig_ring != syz_ring)
+    {
+      rChangeCurrRing(orig_ring);
+      rDelete(syz_ring);
+    }
     return idFreeModule( idElemens_h1 /*IDELEMS(h1)*/);
   }
 
@@ -655,11 +832,10 @@ ideal idSyzygies (ideal  h1, tHomog h,intvec **w, BOOLEAN setSyzComp,
   && (setRegularity)
   && (h==isHomog)
   && (!rIsPluralRing(currRing))
-  #ifdef HAVE_RINGS
   && (!rField_is_Ring(currRing))
-  #endif
   )
   {
+    assume(orig_ring==syz_ring);
     ring dp_C_ring = rAssure_dp_C(syz_ring); // will do rChangeCurrRing later
     if (dp_C_ring != syz_ring)
     {
@@ -676,9 +852,9 @@ ideal idSyzygies (ideal  h1, tHomog h,intvec **w, BOOLEAN setSyzComp,
     }
     omFreeSize((ADDRESS)res,length*sizeof(ideal));
     idDelete(&e);
-    if (dp_C_ring != syz_ring)
+    if (dp_C_ring != orig_ring)
     {
-      rChangeCurrRing(syz_ring);
+      rChangeCurrRing(orig_ring);
       rDelete(dp_C_ring);
     }
   }
@@ -686,6 +862,7 @@ ideal idSyzygies (ideal  h1, tHomog h,intvec **w, BOOLEAN setSyzComp,
   {
     idDelete(&e);
   }
+  assume(orig_ring==currRing);
   idTest(s_h3);
   if (currRing->qideal != NULL)
   {
@@ -705,9 +882,9 @@ ideal idXXX (ideal  h1, int k)
 
   assume(currRing != NULL);
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzComp(orig_ring,TRUE); rChangeCurrRing(syz_ring);
-
+  ring syz_ring=rAssure_SyzComp(orig_ring,TRUE);
   rSetSyzComp(k,syz_ring);
+  rChangeCurrRing(syz_ring);
 
   if (orig_ring != syz_ring)
   {
@@ -745,7 +922,7 @@ ideal idXXX (ideal  h1, int k)
 *computes a standard basis for h1 and stores the transformation matrix
 * in ma
 */
-ideal idLiftStd (ideal  h1, matrix* ma, tHomog hi, ideal * syz)
+ideal idLiftStd (ideal  h1, matrix* ma, tHomog hi, ideal * syz, GbVariant alg)
 {
   int  i, j, t, inputIsIdeal=id_RankFreeModule(h1,currRing);
   long k;
@@ -773,8 +950,9 @@ ideal idLiftStd (ideal  h1, matrix* ma, tHomog hi, ideal * syz)
   if ((k==1) && (!lift3)) si_opt_2 |=Sy_bit(V_IDLIFT);
 
   ring orig_ring = currRing;
-  ring syz_ring = rAssure_SyzOrder(orig_ring,TRUE);  rChangeCurrRing(syz_ring);
+  ring syz_ring = rAssure_SyzOrder(orig_ring,TRUE);
   rSetSyzComp(k,syz_ring);
+  rChangeCurrRing(syz_ring);
 
   ideal s_h1=h1;
 
@@ -783,7 +961,7 @@ ideal idLiftStd (ideal  h1, matrix* ma, tHomog hi, ideal * syz)
   else
     s_h1 = h1;
 
-  ideal s_h3=idPrepare(s_h1,hi,k,&w); // main (syz) GB computation
+  ideal s_h3=idPrepare(s_h1,hi,k,&w,alg); // main (syz) GB computation
 
   ideal s_h2 = idInit(IDELEMS(s_h3), s_h3->rank);
 
@@ -933,7 +1111,7 @@ static void idPrepareStd(ideal s_temp, int k)
 */
 
 ideal idLift(ideal mod, ideal submod,ideal *rest, BOOLEAN goodShape,
-             BOOLEAN isSB, BOOLEAN divide, matrix *unit)
+             BOOLEAN isSB, BOOLEAN divide, matrix *unit, GbVariant alg)
 {
   int lsmod =id_RankFreeModule(submod,currRing), j, k;
   int comps_to_add=0;
@@ -969,8 +1147,9 @@ ideal idLift(ideal mod, ideal submod,ideal *rest, BOOLEAN goodShape,
   if (k<submod->rank) { WarnS("rk(submod) > rk(mod) ?");k=submod->rank; }
 
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE);  rChangeCurrRing(syz_ring);
+  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE);
   rSetSyzComp(k,syz_ring);
+  rChangeCurrRing(syz_ring);
 
   ideal s_mod, s_temp;
   if (orig_ring != syz_ring)
@@ -991,7 +1170,7 @@ ideal idLift(ideal mod, ideal submod,ideal *rest, BOOLEAN goodShape,
   }
   else
   {
-    s_h3 = idPrepare(s_mod,(tHomog)FALSE,k+comps_to_add,NULL);
+    s_h3 = idPrepare(s_mod,(tHomog)FALSE,k+comps_to_add,NULL,alg);
   }
   if (!goodShape)
   {
@@ -1239,23 +1418,19 @@ static ideal idInitializeQuot (ideal  h1, ideal h2, BOOLEAN h1IsStb, BOOLEAN *ad
   pSetComp(p,kmax);
   pSetmComp(p);
 /*--- constructing the big matrix ------------------------*/
-  ideal h4 = idInit(16,kmax+k-1);
+  ideal h4 = idInit(k,kmax+k-1);
   h4->m[0] = q;
   if (k2 == 0)
   {
-    if (k > IDELEMS(h4))
-    {
-      pEnlargeSet(&(h4->m),IDELEMS(h4),k-IDELEMS(h4));
-      IDELEMS(h4) = k;
-    }
     for (i=1; i<k; i++)
     {
       if (h4->m[i-1]!=NULL)
       {
-        p = p_Copy_noCheck(h4->m[i-1], currRing); p_Shift(&p,1,currRing);
-        // pTest(p);
+        p = p_Copy_noCheck(h4->m[i-1], currRing); /*h4->m[i-1]!=NULL*/
+        p_Shift(&p,1,currRing);
         h4->m[i] = p;
       }
+      else break;
     }
   }
   idSkipZeroes(h4);
@@ -1292,15 +1467,12 @@ static ideal idInitializeQuot (ideal  h1, ideal h2, BOOLEAN h1IsStb, BOOLEAN *ad
       h4->m[i] = h4->m[i+1];
     }
     h4->m[IDELEMS(h4)-1] = p;
-    #ifdef HAVE_RINGS
-    if(!rField_is_Ring(currRing))
-    #endif
-    si_opt_1 |= Sy_bit(OPT_SB_1);
   }
   idDelete(&temph1);
   //idTest(h4);//see remark at the beginning
   return h4;
 }
+
 /*2
 *computes the quotient of h1,h2
 */
@@ -1319,8 +1491,6 @@ ideal idQuot (ideal  h1, ideal h2, BOOLEAN h1IsStb, BOOLEAN resultIsIdeal)
       res = idFreeModule(h1->rank);
     return res;
   }
-  BITSET old_test1;
-  SI_SAVE_OPT1(old_test1);
   int i, kmax;
   BOOLEAN  addOnlyOne=TRUE;
   tHomog   hom=isNotHomog;
@@ -1331,8 +1501,9 @@ ideal idQuot (ideal  h1, ideal h2, BOOLEAN h1IsStb, BOOLEAN resultIsIdeal)
   hom = (tHomog)idHomModule(s_h4,currRing->qideal,&weights1);
 
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE);  rChangeCurrRing(syz_ring);
+  ring syz_ring=rAssure_SyzOrder(orig_ring,TRUE);
   rSetSyzComp(kmax-1,syz_ring);
+  rChangeCurrRing(syz_ring);
   if (orig_ring!=syz_ring)
   //  s_h4 = idrMoveR_NoSort(s_h4,orig_ring, syz_ring);
     s_h4 = idrMoveR(s_h4,orig_ring, syz_ring);
@@ -1348,13 +1519,16 @@ ideal idQuot (ideal  h1, ideal h2, BOOLEAN h1IsStb, BOOLEAN resultIsIdeal)
   ideal s_h3;
   if (addOnlyOne)
   {
+    BITSET old_test1;
+    SI_SAVE_OPT1(old_test1);
+    if(!rField_is_Ring(currRing)) si_opt_1 |= Sy_bit(OPT_SB_1);
     s_h3 = kStd(s_h4,currRing->qideal,hom,&weights1,NULL,0/*kmax-1*/,IDELEMS(s_h4)-1);
+    SI_RESTORE_OPT1(old_test1);
   }
   else
   {
     s_h3 = kStd(s_h4,currRing->qideal,hom,&weights1,NULL,kmax-1);
   }
-  SI_RESTORE_OPT1(old_test1);
   #if 0
   // only together with the above debug stuff
   idSkipZeroes(s_h3);
@@ -1397,11 +1571,12 @@ ideal idQuot (ideal  h1, ideal h2, BOOLEAN h1IsStb, BOOLEAN resultIsIdeal)
 /*2
 * eliminate delVar (product of vars) in h1
 */
-ideal idElimination (ideal h1,poly delVar,intvec *hilb)
+ideal idElimination (ideal h1,poly delVar,intvec *hilb, GbVariant alg)
 {
   int    i,j=0,k,l;
   ideal  h,hh, h3;
-  int    *ord,*block0,*block1;
+  rRingOrder_t    *ord;
+  int    *block0,*block1;
   int    ordersize=2;
   int    **wv;
   tHomog hom;
@@ -1481,7 +1656,7 @@ ideal idElimination (ideal h1,poly delVar,intvec *hilb)
     // aa(1,1,1,...,0,0,0),wp(...),C
     // this seems to be better than version 2 below,
     // according to Tst/../elimiate_[3568].tat (- 17 %)
-    ord=(int*)omAlloc0(4*sizeof(int));
+    ord=(rRingOrder_t*)omAlloc0(4*sizeof(rRingOrder_t));
     block0=(int*)omAlloc0(4*sizeof(int));
     block1=(int*)omAlloc0(4*sizeof(int));
     wv=(int**) omAlloc0(4*sizeof(int**));
@@ -1495,12 +1670,12 @@ ideal idElimination (ideal h1,poly delVar,intvec *hilb)
       if (pGetExp(delVar,j+1)!=0) wv[0][j]=1;
     BOOLEAN wp=FALSE;
     for (j=0;j<rVar(origR);j++)
-      if (pWeight(j+1,origR)!=1) { wp=TRUE;break; }
+      if (p_Weight(j+1,origR)!=1) { wp=TRUE;break; }
     if (wp)
     {
       wv[1]=(int*)omAlloc0((rVar(origR) + 1)*sizeof(int));
       for (j=0;j<rVar(origR);j++)
-        wv[1][j]=pWeight(j+1,origR);
+        wv[1][j]=p_Weight(j+1,origR);
       ord[1] = ringorder_wp;
     }
     else
@@ -1524,13 +1699,13 @@ ideal idElimination (ideal h1,poly delVar,intvec *hilb)
       if (pGetExp(delVar,j+1)!=0) wv[1][j]=1;
     #endif
     ord[2] = ringorder_C;
-    ord[3] = 0;
+    ord[3] = (rRingOrder_t)0;
   }
   else
   {
     // we change to an ordering:
     // aa(....),orig_ordering
-    ord=(int*)omAlloc0(ordersize*sizeof(int));
+    ord=(rRingOrder_t*)omAlloc0(ordersize*sizeof(rRingOrder_t));
     block0=(int*)omAlloc0(ordersize*sizeof(int));
     block1=(int*)omAlloc0(ordersize*sizeof(int));
     wv=(int**) omAlloc0(ordersize*sizeof(int**));
@@ -1566,7 +1741,7 @@ ideal idElimination (ideal h1,poly delVar,intvec *hilb)
   {
     if ( nc_rComplete(origR, tmpR, false) ) // no quotient ideal!
     {
-      Werror("no elimination is possible: ordering condition is violated");
+      WerrorS("no elimination is possible: ordering condition is violated");
       // cleanup
       rDelete(tmpR);
       if (w!=NULL)
@@ -1601,7 +1776,51 @@ ideal idElimination (ideal h1,poly delVar,intvec *hilb)
   //Print("h: %d gen, rk=%d\n",IDELEMS(h),h->rank);
   //extern char * showOption();
   //Print("%s\n",showOption());
-  hh = kStd(h,NULL,hom,&w,hilb);
+  if (alg==GbDefault) alg=GbStd;
+  if (alg==GbStd)
+  {
+    if (TEST_OPT_PROT) { PrintS("std:"); mflush(); }
+    hh = kStd(h,NULL,hom,&w,hilb);
+  }
+  else if (alg==GbSlimgb)
+  {
+    if (TEST_OPT_PROT) { PrintS("slimgb:"); mflush(); }
+    hh = t_rep_gb(currRing, h, 0);
+  }
+  else if (alg==GbGroebner)
+  {
+    if (TEST_OPT_PROT) { PrintS("groebner:"); mflush(); }
+    BOOLEAN err;
+    hh=(ideal)iiCallLibProc1("groebner",idCopy(h),MODUL_CMD,err);
+    if (err)
+    {
+      Werror("error %d in >>groebner<<",err);
+      hh=idInit(1,1);
+    }
+  }
+  else if (alg==GbModstd)
+  {
+    if (TEST_OPT_PROT) { PrintS("modstd:"); mflush(); }
+    BOOLEAN err;
+    void *args[]={idCopy(h),(void*)1,NULL};
+    int arg_t[]={IDEAL_CMD,INT_CMD,0};
+    hh=(ideal)iiCallLibProcM("modStd",args,arg_t,err);
+    if (err)
+    {
+      Werror("error %d in >>modStd<<",err);
+      hh=idInit(1,1);
+    }
+  }
+  else if (alg==GbSba)
+  {
+    if (TEST_OPT_PROT) { PrintS("sba:"); mflush(); }
+    hh = kSba(h,currRing->qideal,hom,&w,1,0,NULL);
+  }
+  else
+  {
+    hh=idInit(1,1);
+    Werror("wrong algorithm %d for SB",(int)alg);
+  }
   //SI_RESTORE_OPT1(save1);
   idDelete(&h);
 #else
@@ -2105,14 +2324,16 @@ ideal idModulo (ideal h2,ideal h1, tHomog hom, intvec ** w)
   }
 
   ring orig_ring=currRing;
-  ring syz_ring=rAssure_SyzOrder(orig_ring, TRUE); rChangeCurrRing(syz_ring);
+  ring syz_ring=rAssure_SyzOrder(orig_ring, TRUE);
+  rSetSyzComp(length,syz_ring);
+  rChangeCurrRing(syz_ring);
   // we can use OPT_RETURN_SB only, if syz_ring==orig_ring,
   // therefore we disable OPT_RETURN_SB for modulo:
   // (see tr. #701)
   //if (TEST_OPT_RETURN_SB)
   //  rSetSyzComp(IDELEMS(h2)+length, syz_ring);
   //else
-    rSetSyzComp(length, syz_ring);
+  //  rSetSyzComp(length, syz_ring);
   ideal s_temp;
 
   if (syz_ring != orig_ring)
@@ -2380,7 +2601,7 @@ ideal idMinEmbedding(ideal arg,BOOLEAN inPlace, intvec **w)
   return res;
 }
 
-#include <polys/clapsing.h>
+#include "polys/clapsing.h"
 
 #if 0
 poly id_GCD(poly f, poly g, const ring r)
@@ -2404,7 +2625,10 @@ poly id_GCD(poly f, poly g, const ring r)
   ideal I=idInit(2,1); I->m[0]=f; I->m[1]=g;
   intvec *w = NULL;
 
-  ring save_r = currRing; rChangeCurrRing(r); ideal S=idSyzygies(I,testHomog,&w); rChangeCurrRing(save_r);
+  ring save_r = currRing;
+  rChangeCurrRing(r);
+  ideal S=idSyzygies(I,testHomog,&w);
+  rChangeCurrRing(save_r);
 
   if (w!=NULL) delete w;
   poly gg=p_TakeOutComp(&(S->m[0]), 2, r);
@@ -2587,42 +2811,6 @@ void idKeepFirstK(ideal id, const int k)
    IDELEMS(id) = kk;
 }
 
-/*
-* compare the leading terms of a and b
-*/
-static int tCompare(const poly a, const poly b)
-{
-  if (b == NULL) return(a != NULL);
-  if (a == NULL) return(-1);
-
-  /* a != NULL && b != NULL */
-  int r = pLmCmp(a, b);
-  if (r != 0) return(r);
-  number h = nSub(pGetCoeff(a), pGetCoeff(b));
-  r = -1 + nIsZero(h) + 2*nGreaterZero(h);   /* -1: <, 0:==, 1: > */
-  nDelete(&h);
-  return(r);
-}
-
-/*
-* compare a and b (rev-lex on terms)
-*/
-static int pCompare(const poly a, const poly b)
-{
-  int r = tCompare(a, b);
-  if (r != 0) return(r);
-
-  poly aa = a;
-  poly bb = b;
-  while (r == 0 && aa != NULL && bb != NULL)
-  {
-    pIter(aa);
-    pIter(bb);
-    r = tCompare(aa, bb);
-  }
-  return(r);
-}
-
 typedef struct
 {
   poly p;
@@ -2631,8 +2819,7 @@ typedef struct
 
 int pCompare_qsort(const void *a, const void *b)
 {
-  int res = pCompare(((poly_sort *)a)->p, ((poly_sort *)b)->p);
-  return(res);
+  return (p_Compare(((poly_sort *)a)->p, ((poly_sort *)b)->p,currRing));
 }
 
 void idSort_qsort(poly_sort *id_sort, int idsize)
@@ -2680,3 +2867,249 @@ void idDelEquals(ideal id)
   }
   omFreeSize((ADDRESS)(id_sort), idsize*sizeof(poly_sort));
 }
+
+static int * id_satstdSaturatingVariables=NULL;
+
+static BOOLEAN id_sat_vars_sp(kStrategy strat)
+{
+  BOOLEAN b = FALSE; // set b to TRUE, if spoly was changed,
+                     // let it remain FALSE otherwise
+  if (strat->P.t_p==NULL)
+  {
+    poly p=strat->P.p;
+
+    // iterate over all terms of p and
+    // compute the minimum mm of all exponent vectors
+    int *mm=(int*)omAlloc((1+rVar(currRing))*sizeof(int));
+    int *m0=(int*)omAlloc0((1+rVar(currRing))*sizeof(int));
+    p_GetExpV(p,mm,currRing);
+    bool nonTrivialSaturationToBeDone=true;
+    for (p=pNext(p); p!=NULL; pIter(p))
+    {
+      nonTrivialSaturationToBeDone=false;
+      p_GetExpV(p,m0,currRing);
+      for (int i=rVar(currRing); i>0; i--)
+      {
+        if (id_satstdSaturatingVariables[i]!=0)
+        {
+          mm[i]=si_min(mm[i],m0[i]);
+          if (mm[i]>0) nonTrivialSaturationToBeDone=true;
+        }
+        else mm[i]=0;
+      }
+      // abort if the minimum is zero in each component
+      if (!nonTrivialSaturationToBeDone) break;
+    }
+    if (nonTrivialSaturationToBeDone)
+    {
+      // std::cout << "simplifying!" << std::endl;
+      if (TEST_OPT_PROT) { PrintS("S"); mflush(); }
+      p=p_Copy(strat->P.p,currRing);
+      //pWrite(p);
+      //  for (int i=rVar(currRing); i>0; i--)
+      //    if (mm[i]!=0) Print("x_%d:%d ",i,mm[i]);
+      //PrintLn();
+      memset(&strat->P,0,sizeof(strat->P));
+      strat->P.tailRing = strat->tailRing;
+      strat->P.p=p;
+      while(p!=NULL)
+      {
+        for (int i=rVar(currRing); i>0; i--)
+        {
+          p_SubExp(p,i,mm[i],currRing);
+        }
+        p_Setm(p,currRing);
+        pIter(p);
+      }
+      b = TRUE;
+    }
+    omFree(mm);
+    omFree(m0);
+  }
+  else
+  {
+    poly p=strat->P.t_p;
+
+    // iterate over all terms of p and
+    // compute the minimum mm of all exponent vectors
+    int *mm=(int*)omAlloc((1+rVar(currRing))*sizeof(int));
+    int *m0=(int*)omAlloc0((1+rVar(currRing))*sizeof(int));
+    p_GetExpV(p,mm,strat->tailRing);
+    bool nonTrivialSaturationToBeDone=true;
+    for (p = pNext(p); p!=NULL; pIter(p))
+    {
+      nonTrivialSaturationToBeDone=false;
+      p_GetExpV(p,m0,strat->tailRing);
+      for(int i=rVar(currRing); i>0; i--)
+      {
+        if(id_satstdSaturatingVariables[i]!=0)
+        {
+          mm[i]=si_min(mm[i],m0[i]);
+          if (mm[i]>0) nonTrivialSaturationToBeDone = true;
+        }
+        else mm[i]=0;
+      }
+      // abort if the minimum is zero in each component
+      if (!nonTrivialSaturationToBeDone) break;
+    }
+    if (nonTrivialSaturationToBeDone)
+    {
+      if (TEST_OPT_PROT) { PrintS("S"); mflush(); }
+      p=p_Copy(strat->P.t_p,strat->tailRing);
+      //p_Write(p,strat->tailRing);
+      //  for (int i=rVar(currRing); i>0; i--)
+      //    if (mm[i]!=0) Print("x_%d:%d ",i,mm[i]);
+      //PrintLn();
+      memset(&strat->P,0,sizeof(strat->P));
+      strat->P.tailRing = strat->tailRing;
+      strat->P.t_p=p;
+      while(p!=NULL)
+      {
+        for(int i=rVar(currRing); i>0; i--)
+        {
+          p_SubExp(p,i,mm[i],strat->tailRing);
+        }
+        p_Setm(p,strat->tailRing);
+        pIter(p);
+      }
+      strat->P.GetP();
+      b = TRUE;
+    }
+    omFree(mm);
+    omFree(m0);
+  }
+  return b; // return TRUE if sp was changed, FALSE if not
+}
+
+ideal id_Satstd(const ideal I, ideal J, const ring r)
+{
+  ring save=currRing;
+  if (currRing!=r) rChangeCurrRing(r);
+  idSkipZeroes(J);
+  id_satstdSaturatingVariables=(int*)omAlloc0((1+rVar(currRing))*sizeof(int));
+  int k=IDELEMS(J);
+  if (k>1)
+  {
+    for (int i=0; i<k; i++)
+    {
+      poly x = J->m[i];
+      int li = p_Var(x,r);
+      if (li>0)
+        id_satstdSaturatingVariables[li]=1;
+      else
+      {
+        if (currRing!=save) rChangeCurrRing(save);
+        WerrorS("ideal generators must be variables");
+        return NULL;
+      }
+    }
+  }
+  else
+  {
+    poly x = J->m[0];
+    for (int i=1; i<=r->N; i++)
+    {
+      int li = p_GetExp(x,i,r);
+      if (li==1)
+        id_satstdSaturatingVariables[i]=1;
+      else if (li>1)
+      {
+        if (currRing!=save) rChangeCurrRing(save);
+        Werror("exponent(x(%d)^%d) must be 0 or 1",i,li);
+        return NULL;
+      }
+    }
+  }
+  ideal res=kStd(I,r->qideal,testHomog,NULL,NULL,0,0,NULL,id_sat_vars_sp);
+  omFreeSize(id_satstdSaturatingVariables,(1+rVar(currRing))*sizeof(int));
+  id_satstdSaturatingVariables=NULL;
+  if (currRing!=save) rChangeCurrRing(save);
+  return res;
+}
+
+GbVariant syGetAlgorithm(char *n, const ring r, const ideal /*M*/)
+{
+  GbVariant alg=GbDefault;
+  if (strcmp(n,"slimgb")==0) alg=GbSlimgb;
+  else if (strcmp(n,"std")==0) alg=GbStd;
+  else if (strcmp(n,"sba")==0) alg=GbSba;
+  else if (strcmp(n,"singmatic")==0) alg=GbSingmatic;
+  else if (strcmp(n,"groebner")==0) alg=GbGroebner;
+  else if (strcmp(n,"modstd")==0) alg=GbModstd;
+  else if (strcmp(n,"ffmod")==0) alg=GbFfmod;
+  else if (strcmp(n,"nfmod")==0) alg=GbNfmod;
+  else if (strcmp(n,"std:sat")==0) alg=GbStdSat;
+  else Warn(">>%s<< is an unknown algorithm",n);
+
+  if (alg==GbSlimgb) // test conditions for slimgb
+  {
+    if(rHasGlobalOrdering(r)
+    &&(!rIsPluralRing(r))
+    &&(r->qideal==NULL)
+    &&(!rField_is_Ring(r)))
+    {
+       return GbSlimgb;
+    }
+    if (TEST_OPT_PROT)
+      WarnS("requires: coef:field, commutative, global ordering, not qring");
+  }
+  else if (alg==GbSba) // cond. for sba
+  {
+    if(rField_is_Domain(r)
+    &&(!rIsPluralRing(r))
+    &&(rHasGlobalOrdering(r)))
+    {
+      return GbSba;
+    }
+    if (TEST_OPT_PROT)
+      WarnS("requires: coef:domain, commutative, global ordering");
+  }
+  else if (alg==GbGroebner) // cond. for groebner
+  {
+    return GbGroebner;
+  }
+  else if(alg==GbModstd)  // cond for modstd: Q or Q(a)
+  {
+    if(ggetid("modStd")==NULL)
+    {
+      WarnS(">>modStd<< not found");
+    }
+    else if(rField_is_Q(r)
+    &&(!rIsPluralRing(r))
+    &&(rHasGlobalOrdering(r)))
+    {
+      return GbModstd;
+    }
+    if (TEST_OPT_PROT)
+      WarnS("requires: coef:QQ, commutative, global ordering");
+  }
+  else if(alg==GbStdSat)  // cond for std:sat: 2 blocks of variables
+  {
+    if(ggetid("satstd")==NULL)
+    {
+      WarnS(">>satstd<< not found");
+    }
+    else
+    {
+      return GbStdSat;
+    }
+  }
+
+  return GbStd; // no conditions for std
+}
+//----------------------------------------------------------------------------
+// GB-algorithms and their pre-conditions
+// std   slimgb  sba singmatic modstd ffmod nfmod groebner
+// +     +       +   -         +      -     -     + coeffs: QQ
+// +     +       +   +         -      -     -     + coeffs: ZZ/p
+// +     +       +   -         ?      -     +     + coeffs: K[a]/f
+// +     +       +   -         ?      +     -     + coeffs: K(a)
+// +     -       +   -         -      -     -     + coeffs: domain, not field
+// +     -       -   -         -      -     -     + coeffs: zero-divisors
+// +     +       +   +         -      ?     ?     + also for modules: C
+// +     +       -   +         -      ?     ?     + also for modules: all orderings
+// +     +       -   -         -      -     -     + exterior algebra
+// +     +       -   -         -      -     -     + G-algebra
+// +     +       +   +         +      +     +     + degree ordering
+// +     -       +   +         +      +     +     + non-degree ordering
+// -     -       -   +         +      +     +     + parallel
