@@ -2,19 +2,19 @@
 *  Computer Algebra System SINGULAR     *
 ****************************************/
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <factory/factory.h>
+#include "factory/factory.h"
 
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <coeffs/longrat.h> // snumber ...
+#include "coeffs/longrat.h" // snumber ...
 
-#include <polys/monomials/ring.h>
+#include "polys/monomials/ring.h"
 
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
 
 #include "interpolation.h"
 
@@ -550,10 +550,10 @@ static void modp_Evaluate(modp_number *ev, mono_type mon, condition_type con)  /
 static void int_Evaluate(mpz_t ev, mono_type mon, condition_type con) // (***) evaluates monomial on condition for integer numbers
 {
     int i;
-    mpz_set_si(ev,0);
+    mpz_set_ui(ev,0);
     for (i=0;i<variables;i++)
         if (con.mon[i] > mon[i]) return ;;
-    mpz_set_si(ev,1);
+    mpz_set_ui(ev,1);
     mpz_t mon_conv;
     mpz_init(mon_conv);
     int j,k;
@@ -598,7 +598,7 @@ static void ProduceRow(mono_type mon)  // produces a row for monomial - first pa
 static void IntegerPoints ()  // produces integer points from rationals by scaling the coordinate system
 {
      int i,j;
-     mpz_set_si(common_denom,1); // this is common scaling factor
+     mpz_set_ui(common_denom,1); // this is common scaling factor
      for (i=0;i<n_points;i++)
      {
          for (j=0;j<variables;j++)
@@ -1063,7 +1063,7 @@ static void PrepareChinese (int n) // initialization for CRA
          in_gamma[i]=OneInverse(prod,congr[k]);
      }
      mpz_init(bigcongr);
-     mpz_set_ui(bigcongr,congr[0]);
+     mpz_set_si(bigcongr,congr[0]);
      for (k=1;k<n;k++) mpz_mul_ui(bigcongr,bigcongr,congr[k]);
 }
 
@@ -1302,7 +1302,7 @@ static bool CheckGenerator () // evaluates generator to check whether it is good
      mpz_init(sum);
      for (con=0;con<final_base_dim;con++)
      {
-       mpz_set_si(sum,0);
+       mpz_set_ui(sum,0);
        for (i=0;i<=final_base_dim;i++)
        {
          int_Evaluate(val, polyexp[i], condition_list[con]);
