@@ -10,15 +10,15 @@
 
 
 
-#include <kernel/mod2.h>
-#include <omalloc/omalloc.h>
-#include <misc/options.h>
-#include <polys/monomials/p_polys.h>
-#include <polys/prCopy.h>
-#include <kernel/ideals.h>
-#include <polys/monomials/ring.h>
-#include <polys/sbuckets.h>
-#include <kernel/maps/fast_maps.h>
+#include "kernel/mod2.h"
+#include "omalloc/omalloc.h"
+#include "misc/options.h"
+#include "polys/monomials/p_polys.h"
+#include "polys/prCopy.h"
+#include "kernel/ideals.h"
+#include "polys/monomials/ring.h"
+#include "polys/sbuckets.h"
+#include "kernel/maps/fast_maps.h"
 
 // define if you want to use special dest_ring
 #define HAVE_DEST_R 1
@@ -312,7 +312,7 @@ static void maMap_KillRings(ring map_r, ring image_r, ring src_r, ring dest_r)
   if (map_r != src_r)
     rKillModified_Wp_Ring(src_r);
   if (image_r != dest_r)
-    rKillModifiedRing_Simple(dest_r);
+    rKillModifiedRing(dest_r);
 }
 
 /*******************************************************************************
@@ -443,7 +443,7 @@ static int maPoly_Substitute(macoeff c, poly p, ring dest_r)
   while (c!=NULL)
   {
     done++;
-    poly t=pp_Mult_nn(p,c->n,dest_r);
+    poly t=__pp_Mult_nn(p,c->n,dest_r);
     #ifdef HAVE_RINGS
     if (zero_div) len=pLength(t);
     #endif
