@@ -11,31 +11,30 @@
 
 
 
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/mylimits.h>
-#include <misc/options.h>
-#include <misc/intvec.h>
-#include <misc/sirandom.h>
+#include "misc/mylimits.h"
+#include "misc/options.h"
+#include "misc/intvec.h"
+#include "misc/sirandom.h"
 
-#include <coeffs/numbers.h>
-#include <coeffs/mpr_global.h>
+#include "coeffs/numbers.h"
+#include "coeffs/mpr_global.h"
 
-#include <polys/matpol.h>
-#include <polys/sparsmat.h>
+#include "polys/matpol.h"
+#include "polys/sparsmat.h"
 
-#include <polys/clapsing.h>
+#include "polys/clapsing.h"
 
-#include <kernel/polys.h>
-#include <kernel/ideals.h>
+#include "kernel/polys.h"
+#include "kernel/ideals.h"
 
 #include "mpr_base.h"
 #include "mpr_numeric.h"
 
-#include <math.h>
+#include <cmath>
 //<-
 
 //%s
@@ -559,7 +558,7 @@ void pointSet::mergeWithPoly( const poly p )
 
   while ( piter )
   {
-    pGetExpV( piter, vert );
+    p_GetExpV( piter, vert, currRing );
 
     for ( i= 1; i <= num; i++ )
     {
@@ -586,7 +585,7 @@ int pointSet::getExpPos( const poly p )
   // hier unschoen...
   vert= (int *)omAlloc( (dim+1) * sizeof(int) );
 
-  pGetExpV( p, vert );
+  p_GetExpV( p, vert, currRing );
   for ( i= 1; i <= num; i++ )
   {
     for ( j= 1; j <= dim; j++ )
@@ -799,7 +798,7 @@ pointSet ** convexHull::newtonPolytopesP( const ideal gls )
     for( j= 1; j <= m; j++) {  // fr jeden Exponentvektor
       if( !inHull( (gls->m)[i], p, m, j ) )
       {
-        pGetExpV( p, vert );
+        p_GetExpV( p, vert, currRing );
         Q[i]->addPoint( vert );
         k++;
         mprSTICKYPROT(ST_SPARSE_VADD);
@@ -1355,7 +1354,7 @@ int resMatrixSparse::RC( pointSet **pQ, pointSet *E, int vert, mprfloat shift[]
       if ( !remapXiToPoint( LP->iposv[i+1], pQ, &(optSum[c].set), &(optSum[c].pnt) ) )
       {
         Werror(" resMatrixSparse::RC: Found bad solution in LP: %d!",LP->iposv[i+1]);
-        WerrorS(" resMatrixSparse::RC: remapXiToPoint faild!");
+        WerrorS(" resMatrixSparse::RC: remapXiToPoint failed!");
         return -1;
       }
       bucket[optSum[c].set]++;
@@ -2561,7 +2560,9 @@ number resMatrixDense::getDetAt( const number* evpoint )
     {
       for ( i= 0; i < (currRing->N); i++ )
       {
-        pSetCoeff( MATELEM(m,numVectors-k,numVectors-(getMVector(k)->numColParNr)[i]),
+        number np=pGetCoeff(MATELEM(m,numVectors-k,numVectors-(getMVector(k)->numColParNr)[i]));
+        if (np!=NULL) nDelete(&np);
+        pSetCoeff0( MATELEM(m,numVectors-k,numVectors-(getMVector(k)->numColParNr)[i]),
                    nCopy(evpoint[i]) );
       }
     }
@@ -3121,7 +3122,6 @@ rootContainer ** uResultant::specializeInU( BOOLEAN matchUp, const number subDet
     piter= pures;
     for ( i= tdg; i >= 0; i-- )
     {
-      //if ( piter ) Print("deg %d, pDeg(piter) %d\n",i,pTotaldegree(piter));
       if ( piter && pTotaldegree(piter) == i )
       {
         ncpoly[i]= nCopy( pGetCoeff( piter ) );
