@@ -9,11 +9,8 @@
 
 
 
-#include <kernel/mod2.h>
-#include <omalloc/omalloc.h>
-
-// #include <kernel/structs.h>
-
+#include "kernel/mod2.h"
+#include "omalloc/omalloc.h"
 
 #ifdef HAVE_FEREAD
   #include <unistd.h>
@@ -65,7 +62,6 @@ static BOOLEAN fe_stdout_is_tty;
 static BOOLEAN fe_stdin_is_tty;
 BOOLEAN fe_use_fgets=FALSE;
 static BOOLEAN fe_is_initialized=FALSE;
-static int     pagelength = 24;
 
 FILE *  fe_echo; /*the output file for echoed characters*/
 
@@ -73,8 +69,8 @@ FILE *  fe_echo; /*the output file for echoed characters*/
 char ** fe_hist=NULL;
 short   fe_hist_pos;
 BOOLEAN fe_is_raw_tty=0;
-int     fe_cursor_pos; /* 0..colmax-1*/
-int     fe_cursor_line; /* 0..pagelength-1*/
+short   fe_cursor_pos; /* 0..colmax-1*/
+short   fe_cursor_line; /* 0..pagelength-1*/
 
 #ifndef HAVE_ATEXIT
   int on_exit(void (*f)(int, void *), void *arg);
@@ -710,14 +706,7 @@ char * fe_fgets_stdin_fe(char *pr,char *s, int size)
 /* ================================================================ */
 #if defined(HAVE_DYN_RL)
 #include <unistd.h>
-//#include <stdio.h>
-//#include <stdlib.h>
-//#include <sys/types.h>
-//#include <sys/file.h>
-//#include <sys/stat.h>
-//#include <sys/errno.h>
-//#include <dlfcn.h>
-#include <kernel/mod_raw.h>
+#include "kernel/mod_raw.h"
 
   typedef char **CPPFunction ();
 
