@@ -1,22 +1,22 @@
-#include <kernel/mod2.h>
+#include "kernel/mod2.h"
 
-#include <omalloc/omalloc.h>
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "omalloc/omalloc.h"
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-#include <kernel/polys.h>
-#include <polys/monomials/ring.h>
+#include "kernel/polys.h"
+#include "polys/monomials/ring.h"
 
 
-#include <kernel/ideals.h>
-#include <kernel/GBEngine/kstd1.h>
-#include <kernel/GBEngine/khstd.h>
+#include "kernel/ideals.h"
+#include "kernel/GBEngine/kstd1.h"
+#include "kernel/GBEngine/khstd.h"
 
-#include <kernel/GBEngine/kutil.h>
+#include "kernel/GBEngine/kutil.h"
 
 
 #ifdef HAVE_PLURAL
-#include <polys/nc/nc.h>
+#include "polys/nc/nc.h"
 #endif
 
 /*2
@@ -39,7 +39,7 @@ static poly pChangeSizeOfPoly(ring p_ring, poly p,int minvar,int maxvar, const r
       p_SetExp(resultWorkP,i-minvar+1,p_GetExp(p,i,p_ring),dst_r);
     p_SetComp(resultWorkP,p_GetComp(p,p_ring),dst_r);
     n=n_Copy(pGetCoeff(p),dst_r->cf);
-    p_SetCoeff(resultWorkP,n,dst_r);
+    p_SetCoeff0(resultWorkP,n,dst_r);
     p_Setm(resultWorkP,dst_r);
     pIter(p);
     if (p!=NULL)
