@@ -3,12 +3,12 @@
 /****************************************
 *  Computer Algebra System SINGULAR     *
 ****************************************/
-#include <misc/auxiliary.h>
+#include "misc/auxiliary.h"
 
+#ifdef SINGULAR_4_2
 struct n_Procs_s; typedef struct  n_Procs_s  *coeffs;
 struct snumber; typedef struct snumber *   number;
 
-#ifdef SINGULAR_4_2
 BOOLEAN n_QAEInitChar(coeffs , void *);
 #endif
 
