@@ -4,11 +4,11 @@
 *  Computer Algebra System SINGULAR     *
 ****************************************/
 
-#include <misc/auxiliary.h>
-
-struct n_Procs_s; typedef struct  n_Procs_s  *coeffs;
+#include "misc/auxiliary.h"
 
 #ifdef SINGULAR_4_2
+struct n_Procs_s; typedef struct  n_Procs_s  *coeffs;
+
 BOOLEAN n_pAEInitChar(coeffs , void *);
 #endif
 
