@@ -2,20 +2,19 @@
  *  Computer Algebra System SINGULAR      *
  *****************************************/
 /*
- *  * ABSTRACT: class bigintmat: matrices of numbers.
- *   * a few functinos might be limited to bigint or euclidean rings.
- *    */
+ * ABSTRACT: class bigintmat: matrices of numbers.
+ * a few functinos might be limited to bigint or euclidean rings.
+ */
 
 
-#include <misc/auxiliary.h>
+#include "misc/auxiliary.h"
 
-#include "bigintmat.h"
-#include <misc/intvec.h>
+#include "coeffs/bigintmat.h"
+#include "misc/intvec.h"
 
-#include "rmodulon.h"
+#include "coeffs/rmodulon.h"
 
-#include <math.h>
-#include <string.h>
+#include <cmath>
 
 #ifdef HAVE_RINGS
 ///create Z/nA of type n_Zn
@@ -581,7 +580,6 @@ static int getShorter (int * a, int l, int j, int cols, int rows)
 int * bigintmat::getwid(int maxwid)
 {
   int const c = /*2**/(col-1)+1;
-  if (col + c > maxwid-1) return NULL;
   int * wv = (int*)omAlloc(sizeof(int)*col*row);
   int * cwv = (int*)omAlloc(sizeof(int)*col);
   for (int j=0; j<col; j++)
@@ -601,7 +599,7 @@ int * bigintmat::getwid(int maxwid)
   }
 
   // Groesse verkleinern, bis < maxwid
-  while (intArrSum(cwv, col)+c > maxwid)
+  if (intArrSum(cwv, col)+c > maxwid)
   {
     int j = findLongest(cwv, col);
     cwv[j] = getShorter(wv, cwv[j], j, col, row);
@@ -617,11 +615,6 @@ void bigintmat::pprint(int maxwid)
   else
   {
     int * colwid = getwid(maxwid);
-    if (colwid == NULL)
-    {
-      WerrorS("not enough space to print bigintmat");
-      return;
-    }
     char * ps;
     int slength = 0;
     for (int j=0; j<col; j++)
