@@ -9,18 +9,18 @@
 #ifndef COEFFS_H
 #define COEFFS_H
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
 
-#include <misc/sirandom.h>
+#include "misc/sirandom.h"
 /* for assume: */
-#include <reporter/reporter.h>
-#include <reporter/s_buff.h>
-#include <factory/factory.h>
+#include "reporter/reporter.h"
+#include "reporter/s_buff.h"
+#include "factory/factory.h"
 
-#include <coeffs/si_gmp.h>
-#include <coeffs/Enumerator.h>
-#include <coeffs/numstats.h> // for STATISTIC(F) counting macro
+#include "coeffs/si_gmp.h"
+#include "coeffs/Enumerator.h"
+#include "coeffs/numstats.h" // for STATISTIC(F) counting macro
 
 class CanonicalForm;
 
@@ -32,6 +32,7 @@ enum n_coeffType
   n_R,  /**< single prescision (6,6) real numbers */
   n_GF, /**< \GF{p^n < 2^16} */
   n_long_R, /**< real floating point (GMP) numbers */
+  n_polyExt, /**< used to represent polys as coeffcients */
   n_algExt,  /**< used for all algebraic extensions, i.e.,
                 the top-most extension in an extension tower
                 is algebraic */
@@ -39,10 +40,11 @@ enum n_coeffType
                   the top-most extension in an extension tower
                   is transcendental */
   n_long_C, /**< complex floating point (GMP) numbers */
-  n_Z, /**< only used if HAVE_RINGS is defined: ? */
-  n_Zn, /**< only used if HAVE_RINGS is defined: ? */
-  n_Znm, /**< only used if HAVE_RINGS is defined: ? */
-  n_Z2m, /**< only used if HAVE_RINGS is defined: ? */
+  n_nTupel, /**< n-tupel of cf: ZZ/p1,... ZZ/pn, R, long_R */
+  n_Z, /**< only used if HAVE_RINGS is defined  */
+  n_Zn, /**< only used if HAVE_RINGS is defined */
+  n_Znm, /**< only used if HAVE_RINGS is defined */
+  n_Z2m, /**< only used if HAVE_RINGS is defined */
   n_CF /**< ? */
 };
 
@@ -226,6 +228,8 @@ struct n_Procs_s
            (*cfEqual)(number a,number b, const coeffs r),
            (*cfIsZero)(number a, const coeffs r),
            (*cfIsOne)(number a, const coeffs r),
+       // IsMOne is used for printing os polynomials:
+       // -1 is only printed for constant monomials
            (*cfIsMOne)(number a, const coeffs r),
        //GreaterZero is used for printing of polynomials:
        //  a "+" is only printed in front of a coefficient
@@ -312,10 +316,6 @@ struct n_Procs_s
    number (*convFactoryNSingN)( const CanonicalForm n, const coeffs r);
    CanonicalForm (*convSingNFactoryN)( number n, BOOLEAN setChar, const coeffs r );
 
-
-   /// the 0 as constant, NULL by default
-   number nNULL;
-
    /// Number of Parameters in the coeffs (default 0)
    int iNumberOfParameters;
 
@@ -581,15 +581,15 @@ static FORCE_INLINE void   n_Normalize(number& n, const coeffs r)
 
 /// write to the output buffer of the currently used reporter
 //CF: the "&" should be removed, as one wants to write constants as well
-static FORCE_INLINE void   n_WriteLong(number& n,  const coeffs r)
+static FORCE_INLINE void   n_WriteLong(number n,  const coeffs r)
 { STATISTIC(n_WriteLong); assume(r != NULL); assume(r->cfWriteLong!=NULL); r->cfWriteLong(n,r); }
 
 /// write to the output buffer of the currently used reporter
 /// in a shortest possible way, e.g. in K(a): a2 instead of a^2
-static FORCE_INLINE void   n_WriteShort(number& n,  const coeffs r)
+static FORCE_INLINE void   n_WriteShort(number n,  const coeffs r)
 { STATISTIC(n_WriteShort); assume(r != NULL); assume(r->cfWriteShort!=NULL); r->cfWriteShort(n,r); }
 
-static FORCE_INLINE void   n_Write(number& n,  const coeffs r, const BOOLEAN bShortOut = TRUE)
+static FORCE_INLINE void   n_Write(number n,  const coeffs r, const BOOLEAN bShortOut = TRUE)
 { STATISTIC(n_Write); if (bShortOut) n_WriteShort(n, r); else n_WriteLong(n, r); }
 
 
@@ -743,6 +743,7 @@ static FORCE_INLINE void   n_CoeffWrite(const coeffs r, BOOLEAN details = TRUE)
 { STATISTIC(n_CoeffWrite); assume(r != NULL); assume(r->cfCoeffWrite != NULL); r->cfCoeffWrite(r, details); }
 
 // Tests:
+#ifdef HAVE_RINGS
 static FORCE_INLINE BOOLEAN nCoeff_is_Ring_2toM(const coeffs r)
 { assume(r != NULL); return (getCoeffType(r)==n_Z2m); }
 
@@ -757,6 +758,13 @@ static FORCE_INLINE BOOLEAN nCoeff_is_Ring_Z(const coeffs r)
 
 static FORCE_INLINE BOOLEAN nCoeff_is_Ring(const coeffs r)
 { assume(r != NULL); return (r->is_field==0); }
+#else
+#define nCoeff_is_Ring_2toM(A) 0
+#define nCoeff_is_Ring_ModN(A) 0
+#define nCoeff_is_Ring_PtoM(A) 0
+#define nCoeff_is_Ring_Z(A)    0
+#define nCoeff_is_Ring(A)      0
+#endif
 
 /// returns TRUE, if r is a field or r has no zero divisors (i.e is a domain)
 static FORCE_INLINE BOOLEAN nCoeff_is_Domain(const coeffs r)
@@ -829,6 +837,9 @@ static FORCE_INLINE BOOLEAN nCoeff_is_Zp(const coeffs r, int p)
 static FORCE_INLINE BOOLEAN nCoeff_is_Q(const coeffs r)
 { assume(r != NULL); return getCoeffType(r)==n_Q && (r->is_field); }
 
+static FORCE_INLINE BOOLEAN nCoeff_is_Z(const coeffs r)
+{ assume(r != NULL); return getCoeffType(r)==n_Z || ((getCoeffType(r)==n_Q) && (!r->is_field)); }
+
 static FORCE_INLINE BOOLEAN nCoeff_is_Q_or_BI(const coeffs r)
 { assume(r != NULL); return getCoeffType(r)==n_Q; }
 
