@@ -9,7 +9,7 @@
 #ifndef FLINTCF_Q_H
 #define FLINTCF_Q_H
 
-#include <misc/auxiliary.h>
+#include "misc/auxiliary.h"
 #ifdef HAVE_FLINT
 BOOLEAN flintQ_InitChar(coeffs cf, void * infoStruct);
 #endif
