@@ -9,10 +9,9 @@
 #ifndef FLINTCF_ZN_H
 #define FLINTCF_ZN_H
 
-#include <singularconfig.h>
-#include <misc/auxiliary.h>
+#include "singularconfig.h"
+#include "misc/auxiliary.h"
 
-#ifdef SINGULAR_4_1
 #ifdef HAVE_FLINT
 typedef struct
 {
@@ -21,7 +20,6 @@ typedef struct
 } flintZn_struct;
 BOOLEAN flintZn_InitChar(coeffs cf, void * infoStruct);
 #endif
-#endif
 
 #endif
 
