@@ -6,22 +6,22 @@
 *
 * ngc == number gnu complex
 */
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
 
-#include <misc/mylimits.h>
-#include <reporter/reporter.h>
+#include "misc/mylimits.h"
+#include "reporter/reporter.h"
 
-#include "coeffs.h"
-#include "numbers.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
 
-#include "mpr_complex.h"
+#include "coeffs/mpr_complex.h"
 
-#include "gnumpc.h"
-#include "longrat.h"
-#include "gnumpfl.h"
-#include "modulop.h"
-#include "shortfl.h"
+#include "coeffs/gnumpc.h"
+#include "coeffs/longrat.h"
+#include "coeffs/gnumpfl.h"
+#include "coeffs/modulop.h"
+#include "coeffs/shortfl.h"
 
 #ifdef LDEBUG
 BOOLEAN  ngcDBTest(number a, const char *f, const int l, const coeffs r);
@@ -382,8 +382,8 @@ static BOOLEAN ngcCoeffIsEqual (const coeffs r, n_coeffType n, void * parameter)
     LongComplexInfo* p = (LongComplexInfo *)(parameter);
 
     if ((p==NULL)
-      && (6==r->float_len)
-      && (6==r->float_len2)
+      && (SHORT_REAL_LENGTH==r->float_len)
+      && (SHORT_REAL_LENGTH==r->float_len2)
       && (strcmp("i",n_ParameterNames(r)[0]) == 0)
       )
         return TRUE;
@@ -418,9 +418,18 @@ static char* ngcCoeffString(const coeffs r)
   return s;
 }
 
+static char* ngcCoeffName(const coeffs r)
+{
+  static char ngcCoeffName_buf[40];
+  const char *p=n_ParameterNames(r)[0];
+  if (ngcCoeffName_buf!=NULL) omFree(ngcCoeffName_buf);
+  sprintf(ngcCoeffName_buf,"complex,%d,%d,%s",r->float_len,r->float_len2,p);
+  return ngcCoeffName_buf;
+}
+
 static void ngcCoeffWrite  (const coeffs r, BOOLEAN /*details*/)
 {
-  Print("float[%s](complex:%d digits, additional %d digits)/(%s^2+1)",n_ParameterNames(r)[0],
+  Print("real[%s](complex:%d digits, additional %d digits)/(%s^2+1)",n_ParameterNames(r)[0],
         r->float_len, r->float_len2, n_ParameterNames(r)[0]);  /* long C */
 }
 
@@ -480,7 +489,7 @@ static number ngcMapR(number from, const coeffs aRing, const coeffs r)
 
   if ( from != NULL )
   {
-    gmp_complex *res=new gmp_complex((double)nrFloat(from)); // FIXME? TODO? // extern float   nrFloat(number n);
+    gmp_complex *res=new gmp_complex((double)nrFloat(from));
     return (number)res;
   }
   else
@@ -553,6 +562,7 @@ BOOLEAN ngcInitChar(coeffs n, void* parameter)
   n->cfKillChar = ngcKillChar;
   n->ch = 0;
   n->cfCoeffString=ngcCoeffString;
+  n->cfCoeffName=ngcCoeffName;
 
   n->cfDelete  = ngcDelete;
   //n->cfNormalize=ndNormalize;
@@ -591,9 +601,6 @@ BOOLEAN ngcInitChar(coeffs n, void* parameter)
 
   n->cfSetChar=ngcSetChar;
 
-// we need to initialize n->nNULL at least for minpoly printing
-  n->nNULL  = n->cfInit(0,n);
-
 /*
   //r->cfInitChar=nlInitChar;
   r->cfKillChar=NULL;
@@ -646,7 +653,6 @@ BOOLEAN ngcInitChar(coeffs n, void* parameter)
 #endif
 
   // the variables:
-  r->nNULL = INT_TO_SR(0);
   r->type = n_Q;
   r->ch = 0;
   r->has_simple_Alloc=FALSE;
