@@ -7,30 +7,30 @@
 * ngf == number gnu floats
 */
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
 
-#include <reporter/reporter.h>
+#include "reporter/reporter.h"
 
-#include "coeffs.h"
-#include "numbers.h"
-#include "mpr_complex.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
+#include "coeffs/mpr_complex.h"
 
-#include "longrat.h"
-#include "shortfl.h"
-#include "gnumpfl.h"
-#include "gnumpc.h"
-#include "modulop.h"
+#include "coeffs/longrat.h"
+#include "coeffs/shortfl.h"
+#include "coeffs/gnumpfl.h"
+#include "coeffs/gnumpc.h"
+#include "coeffs/modulop.h"
 
 const char *   ngfRead (const char *s, number *a, const coeffs r);
 
 union nf
 {
-  float _f;
+  SI_FLOAT _f;
   number _n;
-  nf(float f) {_f = f;}
+  nf(SI_FLOAT f) {_f = f;}
   nf(number n) {_n = n;}
-  float F() const {return _f;}
+  SI_FLOAT F() const {return _f;}
   number N() const {return _n;}
 };
 
@@ -402,15 +402,15 @@ static void ngfSetChar(const coeffs r)
 
 static char* ngfCoeffString(const coeffs r)
 {
-  char *s=(char*)omAlloc(27);
-  snprintf(s,27,"real,%d,%d",r->float_len,r->float_len2);
+  char *s=(char*)omAlloc(30);
+  snprintf(s,30,"Float(%d,%d)",r->float_len,r->float_len2);
   return s;
 }
 
 static char* ngfCoeffName(const coeffs r)
 {
-  static char ngfCoeffName_buf[27];
-  snprintf(ngfCoeffName_buf,27,"RR(%d,%d)",r->float_len,r->float_len2);
+  static char ngfCoeffName_buf[30];
+  snprintf(ngfCoeffName_buf,30,"Float(%d,%d)",r->float_len,r->float_len2);
   return ngfCoeffName_buf;
 }
 
@@ -502,8 +502,7 @@ static nMapFunc ngfSetMap(const coeffs src, const coeffs dst)
 
 static void ngfCoeffWrite  (const coeffs r, BOOLEAN /*details*/)
 {
-  Print("float(real:%d digits, additional %d digits)",
-               r->float_len,r->float_len2);  /* long R */
+  Print("Float(%d,%d)", r->float_len,r->float_len2);  /* long R */
 }
 
 BOOLEAN ngfInitChar(coeffs n, void *parameter)
