@@ -5,19 +5,25 @@
 * ABSTRACT: computation with long rational numbers (Hubert Grassmann)
 */
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
 
-#include <factory/factory.h>
+#include "factory/factory.h"
 
-#include <misc/sirandom.h>
-#include <misc/prime.h>
-#include <reporter/reporter.h>
+#include "misc/sirandom.h"
+#include "misc/prime.h"
+#include "reporter/reporter.h"
 
-#include "rmodulon.h" // ZnmInfo
-#include "longrat.h"
-#include "shortfl.h"
-#include "modulop.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
+#include "coeffs/rmodulon.h" // ZnmInfo
+#include "coeffs/longrat.h"
+#include "coeffs/shortfl.h"
+#include "coeffs/modulop.h"
+#include "coeffs/mpr_complex.h"
+
+#include <string.h>
+#include <float.h>
 
 // allow inlining only from p_Numbers.h and if ! LDEBUG
 #if defined(DO_LINLINE) && defined(P_NUMBERS_H) && !defined(LDEBUG)
@@ -109,7 +115,7 @@ BOOLEAN nlDBTest(number a, const char *f,int l, const coeffs r);
 static inline number nlShort3(number x) // assume x->s==3
 {
   assume(x->s==3);
-  if (mpz_cmp_ui(x->z,0L)==0)
+  if (mpz_sgn1(x->z)==0)
   {
     mpz_clear(x->z);
     FREE_RNUMBER(x);
@@ -132,16 +138,6 @@ static inline number nlShort3(number x) // assume x->s==3
 #ifndef LONGRAT_CC
 #define LONGRAT_CC
 
-#include <string.h>
-#include <float.h>
-
-#include <coeffs/coeffs.h>
-#include <reporter/reporter.h>
-#include <omalloc/omalloc.h>
-
-#include <coeffs/numbers.h>
-#include <coeffs/mpr_complex.h>
-
 #ifndef BYTES_PER_MP_LIMB
 #define BYTES_PER_MP_LIMB sizeof(mp_limb_t)
 #endif
@@ -152,7 +148,7 @@ static inline number nlShort3(number x) // assume x->s==3
 // #define SR_TO_INT(SR)   (((long)SR) >> 2)
 
 #define MP_SMALL 1
-//#define mpz_isNeg(A) (mpz_cmp_si(A,0L)<0)
+//#define mpz_isNeg(A) (mpz_sgn1(A)<0)
 #define mpz_isNeg(A) ((A)->_mp_size<0)
 #define mpz_limb_size(A) ((A)->_mp_size)
 #define mpz_limb_d(A) ((A)->_mp_d)
@@ -1328,7 +1324,7 @@ static int int_extgcd(int a, int b, int * u, int* x, int * v, int* y)
 number nlShort1(number x) // assume x->s==0/1
 {
   assume(x->s<2);
-  if (mpz_cmp_ui(x->z,0L)==0)
+  if (mpz_sgn1(x->z)==0)
   {
     _nlDelete_NoImm(&x);
     return INT_TO_SR(0);
@@ -1706,7 +1702,7 @@ number _nlAdd_aNoImm_OR_bNoImm(number a, number b)
         mpz_mul_si(x,b->n,SR_TO_INT(a));
         mpz_add(u->z,b->z,x);
         mpz_clear(x);
-        if (mpz_cmp_ui(u->z,0L)==0)
+        if (mpz_sgn1(u->z)==0)
         {
           mpz_clear(u->z);
           FREE_RNUMBER(u);
@@ -1755,7 +1751,7 @@ number _nlAdd_aNoImm_OR_bNoImm(number a, number b)
             mpz_add(u->z,u->z,x);
             mpz_clear(x);
 
-            if (mpz_cmp_ui(u->z,0L)==0)
+            if (mpz_sgn1(u->z)==0)
             {
               mpz_clear(u->z);
               FREE_RNUMBER(u);
@@ -1778,7 +1774,7 @@ number _nlAdd_aNoImm_OR_bNoImm(number a, number b)
           {
             mpz_mul(u->z,b->z,a->n);
             mpz_add(u->z,u->z,a->z);
-            if (mpz_cmp_ui(u->z,0L)==0)
+            if (mpz_sgn1(u->z)==0)
             {
               mpz_clear(u->z);
               FREE_RNUMBER(u);
@@ -1807,7 +1803,7 @@ number _nlAdd_aNoImm_OR_bNoImm(number a, number b)
           {
             mpz_mul(u->z,a->z,b->n);
             mpz_add(u->z,u->z,b->z);
-            if (mpz_cmp_ui(u->z,0L)==0)
+            if (mpz_sgn1(u->z)==0)
             {
               mpz_clear(u->z);
               FREE_RNUMBER(u);
@@ -2001,7 +1997,7 @@ number _nlSub_aNoImm_OR_bNoImm(number a, number b)
         mpz_mul_si(x,b->n,SR_TO_INT(a));
         mpz_sub(u->z,x,b->z);
         mpz_clear(x);
-        if (mpz_cmp_ui(u->z,0L)==0)
+        if (mpz_sgn1(u->z)==0)
         {
           mpz_clear(u->z);
           FREE_RNUMBER(u);
@@ -2048,7 +2044,7 @@ number _nlSub_aNoImm_OR_bNoImm(number a, number b)
         mpz_mul_si(x,a->n,SR_TO_INT(b));
         mpz_sub(u->z,a->z,x);
         mpz_clear(x);
-        if (mpz_cmp_ui(u->z,0L)==0)
+        if (mpz_sgn1(u->z)==0)
         {
           mpz_clear(u->z);
           FREE_RNUMBER(u);
@@ -2102,7 +2098,7 @@ number _nlSub_aNoImm_OR_bNoImm(number a, number b)
             mpz_sub(u->z,y,x);
             mpz_clear(x);
             mpz_clear(y);
-            if (mpz_cmp_ui(u->z,0L)==0)
+            if (mpz_sgn1(u->z)==0)
             {
               mpz_clear(u->z);
               FREE_RNUMBER(u);
@@ -2128,7 +2124,7 @@ number _nlSub_aNoImm_OR_bNoImm(number a, number b)
             mpz_mul(x,b->z,a->n);
             mpz_sub(u->z,a->z,x);
             mpz_clear(x);
-            if (mpz_cmp_ui(u->z,0L)==0)
+            if (mpz_sgn1(u->z)==0)
             {
               mpz_clear(u->z);
               FREE_RNUMBER(u);
@@ -2160,7 +2156,7 @@ number _nlSub_aNoImm_OR_bNoImm(number a, number b)
             mpz_mul(x,a->z,b->n);
             mpz_sub(u->z,x,b->z);
             mpz_clear(x);
-            if (mpz_cmp_ui(u->z,0L)==0)
+            if (mpz_sgn1(u->z)==0)
             {
               mpz_clear(u->z);
               FREE_RNUMBER(u);
@@ -2810,21 +2806,23 @@ void nlInpIntDiv(number &a, number b, const coeffs r)
 
 number nlFarey(number nN, number nP, const coeffs r)
 {
-  mpz_t tmp; mpz_init(tmp);
-  mpz_t A,B,C,D,E,N,P;
-  if (SR_HDL(nN) & SR_INT) mpz_init_set_si(N,SR_TO_INT(nN));
-  else                     mpz_init_set(N,nN->z);
+  mpz_t A,B,C,D,E,N,P,tmp;
   if (SR_HDL(nP) & SR_INT) mpz_init_set_si(P,SR_TO_INT(nP));
   else                     mpz_init_set(P,nP->z);
+  const mp_bitcnt_t bits=2*(mpz_size1(P)+1)*GMP_LIMB_BITS;
+  mpz_init2(N,bits);
+  if (SR_HDL(nN) & SR_INT) mpz_set_si(N,SR_TO_INT(nN));
+  else                     mpz_set(N,nN->z);
   assume(!mpz_isNeg(P));
   if (mpz_isNeg(N))  mpz_add(N,N,P);
-  mpz_init_set_si(A,0L);
-  mpz_init_set_ui(B,(unsigned long)1);
-  mpz_init_set_si(C,0L);
-  mpz_init(D);
-  mpz_init_set(E,P);
+  mpz_init2(A,bits); mpz_set_ui(A,0L);
+  mpz_init2(B,bits); mpz_set_ui(B,1L);
+  mpz_init2(C,bits); mpz_set_ui(C,0L);
+  mpz_init2(D,bits);
+  mpz_init2(E,bits); mpz_set(E,P);
+  mpz_init2(tmp,bits);
   number z=INT_TO_SR(0);
-  while(mpz_cmp_si(N,0L)!=0)
+  while(mpz_sgn1(N)!=0)
   {
     mpz_mul(tmp,N,N);
     mpz_add(tmp,tmp,tmp);
@@ -3408,8 +3406,6 @@ BOOLEAN nlInitChar(coeffs r, void*p)
   r->cfWriteFd=nlWriteFd;
   r->cfReadFd=nlReadFd;
 
-  // the variables: general stuff (required)
-  r->nNULL = INT_TO_SR(0);
   //r->type = n_Q;
   r->ch = 0;
   r->has_simple_Alloc=FALSE;
