@@ -11,20 +11,19 @@
 // WARNING! ALWAYS use omAlloc and FreeL when alloc. memory for some char* !!
 
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
 
-#include <reporter/reporter.h>
+#include "reporter/reporter.h"
 
-//#ifdef HAVE_MPR
-#include <coeffs/coeffs.h>
-#include <coeffs/numbers.h>
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
 
-#include <coeffs/mpr_complex.h>
+#include "coeffs/mpr_complex.h"
 
-#include "longrat.h"
+#include "coeffs/longrat.h"
 
-#include <math.h>
+#include <cmath>
 
 
 //%s
@@ -806,8 +805,6 @@ void gmp_complex::SmallToZero()
 
 //%e
 
-//#endif // HAVE_MPR
-
 // local Variables: ***
 // folded-file: t ***
 // compile-command-1: "make installg" ***
