@@ -9,31 +9,32 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
-#include <factory/factory.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
+#include "factory/factory.h"
 
-#include <reporter/reporter.h>
+#include "reporter/reporter.h"
 
-#include <coeffs/coeffs.h>
-#include <coeffs/numbers.h>
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
 
-#include <coeffs/longrat.h>
-#include <coeffs/modulop.h>
-#include <coeffs/gnumpfl.h>
-#include <coeffs/gnumpc.h>
-#include <coeffs/ffields.h>
-#include <coeffs/shortfl.h>
+#include "coeffs/longrat.h"
+#include "coeffs/modulop.h"
+#include "coeffs/gnumpfl.h"
+#include "coeffs/gnumpc.h"
+#include "coeffs/ffields.h"
+#include "coeffs/shortfl.h"
+#include "coeffs/ntupel.h"
 
 #ifdef HAVE_RINGS
-# include <coeffs/rmodulo2m.h>
-# include <coeffs/rmodulon.h>
-# include <coeffs/rintegers.h>
+#include "coeffs/rmodulo2m.h"
+#include "coeffs/rmodulon.h"
+#include "coeffs/rintegers.h"
 #endif
 
 #ifdef HAVE_POLYEXTENSIONS
-#include <polys/ext_fields/algext.h>
-#include <polys/ext_fields/transext.h>
+#include "polys/ext_fields/algext.h"
+#include "polys/ext_fields/transext.h"
 #endif
 
 
@@ -105,6 +106,13 @@ static void ndPower(number a, int i, number * res, const coeffs r)
     }
   }
 }
+static number ndInvers(number a, const coeffs r)
+{
+  number one=r->cfInit(1,r);
+  number res=r->cfDiv(one,a,r);
+  r->cfDelete(&one,r);
+  return res;
+}
 
 static BOOLEAN ndIsUnit(number a, const coeffs r) { return !r->cfIsZero(a,r); }
 #ifdef LDEBUG
@@ -136,22 +144,21 @@ static number ndParameter(const int, const coeffs r)
 
 BOOLEAN n_IsZeroDivisor( number a, const coeffs r)
 {
-  int c = n_GetChar(r);
   BOOLEAN ret = n_IsZero(a, r);
-  if( (c != 0) && !ret )
-  {
-    number ch = n_Init( c, r );
-    number g = n_Gcd( ch, a, r );
-    ret = !n_IsOne (g, r);
-    n_Delete(&ch, r);
-    n_Delete(&g, r);
-  }
+  int c = n_GetChar(r);
+  if (ret || (c==0) || (r->is_field))
+    return ret; /*n_IsZero(a, r)*/
+  number ch = n_Init( c, r );
+  number g = n_Gcd( ch, a, r );
+  ret = !n_IsOne (g, r);
+  n_Delete(&ch, r);
+  n_Delete(&g, r);
   return ret;
 }
 
 static void   ndNormalize(number&, const coeffs) { }
 static number ndReturn0(number, const coeffs r)        { return r->cfInit(0,r); }
-static number ndGcd(number, number, const coeffs r)    { return r->cfInit(1,r); }
+number ndGcd(number, number, const coeffs r)    { return r->cfInit(1,r); }
 static number ndIntMod(number, number, const coeffs r) { return r->cfInit(0,r); }
 static number ndGetDenom(number &, const coeffs r)     { return r->cfInit(1,r); }
 static number ndGetNumerator(number &a,const coeffs r) { return r->cfCopy(a,r); }
@@ -262,7 +269,7 @@ static int ndDivComp(number, number, const coeffs) { return 2; }
 static number  ndExtGcd (number, number, number *, number *, const coeffs r) { return r->cfInit(1,r); }
 #endif
 
-static CanonicalForm ndConvSingNFactoryN( number, BOOLEAN /*setChar*/, const coeffs)
+CanonicalForm ndConvSingNFactoryN( number, BOOLEAN /*setChar*/, const coeffs)
 {
   CanonicalForm term(0);
   WerrorS("no conversion to factory");
@@ -321,6 +328,7 @@ cfInitCharProc nInitCharTableDefault[]=
  NULL,        /* n_transExt */
  #endif
  ngcInitChar,  /* n_long_C */
+ nnInitChar,   /* n_nTupel */
  #ifdef HAVE_RINGS
  nrzInitChar,  /* n_Z */
  nrnInitChar,  /* n_Zn */
@@ -375,6 +383,7 @@ coeffs nInitChar(n_coeffType t, void * parameter)
     n->cfMPZ = ndMPZ;
     n->cfPower = ndPower;
     n->cfQuotRem = ndQuotRem;
+    n->cfInvers = ndInvers;
 
     n->cfKillChar = ndKillChar; /* dummy */
     n->cfSetChar = ndSetChar; /* dummy */
@@ -491,9 +500,6 @@ coeffs nInitChar(n_coeffType t, void * parameter)
     if(n->cfWriteShort==NULL) Warn("cfWriteShort is NULL for coeff %d",t);
     if(n->cfCoeffString==ndCoeffString) Warn("cfCoeffString is undefined for coeff %d",t);
 #endif
-
-   if( n->nNULL == NULL )
-     n->nNULL = n->cfInit(0, n); // may still remain NULL
   }
   else
   {
@@ -518,7 +524,6 @@ void nKillChar(coeffs r)
       {
         n->next=n->next->next;
         if (cf_root==r) cf_root=n->next;
-        n_Delete(&(r->nNULL),r);
         assume (r->cfKillChar!=NULL); r->cfKillChar(r); // STATISTIC(nKillChar);
         omFreeSize((void *)r, sizeof(n_Procs_s));
         r=NULL;
