@@ -5,24 +5,24 @@
 * ABSTRACT: numbers (integers)
 */
 
-#include <misc/auxiliary.h>
-#include <omalloc/omalloc.h>
+#include "misc/auxiliary.h"
+#include "omalloc/omalloc.h"
 
-#include <factory/factory.h>
+#include "factory/factory.h"
 
-#include <misc/mylimits.h>
-#include <reporter/reporter.h>
+#include "misc/mylimits.h"
+#include "reporter/reporter.h"
 
-#include "coeffs.h"
-#include "longrat.h"
-#include "numbers.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/longrat.h"
+#include "coeffs/numbers.h"
 
-#include "si_gmp.h"
+#include "coeffs/si_gmp.h"
 
-#include "mpr_complex.h"
-#include "rintegers.h"
-#include "rmodulon.h"
-#include "longrat.h"
+#include "coeffs/mpr_complex.h"
+#include "coeffs/rintegers.h"
+#include "coeffs/rmodulon.h"
+#include "coeffs/longrat.h"
 
 #include <string.h>
 
@@ -202,7 +202,7 @@ static BOOLEAN nrzIsZero (number  a, const coeffs)
 
 static BOOLEAN nrzIsOne (number a, const coeffs)
 {
-  return (a!=NULL) && (0 == mpz_cmp_si((mpz_ptr) a, 1));
+  return (a!=NULL) && (0 == mpz_cmp_ui((mpz_ptr) a, 1));
 }
 
 static BOOLEAN nrzIsMOne (number a, const coeffs)
@@ -222,7 +222,7 @@ static BOOLEAN nrzGreater (number a,number b, const coeffs)
 
 static BOOLEAN nrzGreaterZero (number k, const coeffs)
 {
-  return 0 < mpz_cmp_si((mpz_ptr) k, 0);
+  return 0 < mpz_sgn1((mpz_ptr) k);
 }
 
 static BOOLEAN nrzDivBy (number a,number b, const coeffs)
@@ -409,7 +409,7 @@ static const char * nlEatLongC(char *s, mpz_ptr i)
 
   if (*s<'0' || *s>'9')
   {
-    mpz_set_si(i,1);
+    mpz_set_ui(i,1);
     return s;
   }
   while (*s >= '0' && *s <= '9') s++;
@@ -625,7 +625,6 @@ BOOLEAN nrzInitChar(coeffs r,  void *)
   r->cfDBTest=nrzDBTest;
 #endif
 
-  r->nNULL = 0;
   r->ch = 0;
   r->has_simple_Alloc=FALSE;
   r->has_simple_Inverse=FALSE;
@@ -653,7 +652,7 @@ static inline number nrz_short(number x)
   StringAppendS("short(");
   nrzWrite(x, NULL);
 #endif
-  if (mpz_cmp_ui((mpz_ptr) x,0L)==0)
+  if (mpz_sgn1((mpz_ptr) x)==0)
   {
     mpz_clear((mpz_ptr)x);
     omFreeBin(x, gmp_nrz_bin);
@@ -1423,7 +1422,7 @@ static number nrzDiv (number a,number b, const coeffs)
   omFree(s);
 #endif
 
-  if (mpz_cmp_si(r, 0)!=0)
+  if (mpz_sgn1(r)!=0)
   {
     //WerrorS("4:Division by non divisible element.");
     //WerrorS("Result is without remainder.");
@@ -1645,7 +1644,7 @@ void nrzInitExp(int, coeffs)
 BOOLEAN nrzDBTest (number x, const char *f, const int l, const coeffs)
 {
   if (SR_HDL(x) & SR_INT) return TRUE;
-  if (mpz_cmp_ui((mpz_ptr) x,0L)==0)
+  if (mpz_sgn1((mpz_ptr) x)==0)
   {
     Print("gmp-0 %s:%d\n",f,l);
     return FALSE;
@@ -1697,7 +1696,7 @@ static const char * nlEatLongC(char *s, mpz_ptr i)
 
   if (*s<'0' || *s>'9')
   {
-    mpz_set_si(i,1);
+    mpz_set_ui(i,1);
     return s;
   }
   while (*s >= '0' && *s <= '9') s++;
@@ -1864,7 +1863,6 @@ BOOLEAN nrzInitChar(coeffs r,  void *)
   r->cfDBTest=nrzDBTest;
 #endif
 
-  r->nNULL = 0;
   r->ch = 0;
   r->has_simple_Alloc=FALSE;
   r->has_simple_Inverse=FALSE;
