@@ -1,7 +1,7 @@
 // the following initialization is needed for linkage on Mac OS X,
 // since initialized variables will be "D" (uninit. go to "C") segments
 // also, initialization must not be 0, as that goes to "B" (ubuntu)
-#include <misc/options.h>
+#include "misc/options.h"
 unsigned si_opt_1 = Sy_bit(OPT_FASTHC);
 unsigned si_opt_2 = Sy_bit(V_QUIET)
                    //| Sy_bit(V_QRING) // not default, as speed drops by 10 %
@@ -11,3 +11,4 @@ unsigned si_opt_2 = Sy_bit(V_QUIET)
                    | Sy_bit(V_PROMPT)
                    ;
 
+BOOLEAN siCntrlc = FALSE;
