@@ -8,23 +8,15 @@
 
 //#define FACTORIZE2_DEBUG
 
-
-
-
-
-
-
-#include <misc/auxiliary.h>
+#include "misc/auxiliary.h"
 #include "clapsing.h"
 
-#include <factory/factory.h>
+#include "factory/factory.h"
 
-#include <omalloc/omalloc.h>
-#include <coeffs/numbers.h>
-#include <coeffs/coeffs.h>
-#include <coeffs/bigintmat.h>
-
-// #include <kernel/ffields.h>
+#include "omalloc/omalloc.h"
+#include "coeffs/numbers.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/bigintmat.h"
 
 #include "monomials/ring.h"
 #include "simpleideals.h"
@@ -37,14 +29,13 @@
 
 
 #include "clapconv.h"
-// #include <kernel/clapconv.h>
 
-#include <polys/monomials/p_polys.h>
-#include <polys/monomials/ring.h>
-#include <polys/simpleideals.h>
-#include <misc/intvec.h>
-#include <polys/matpol.h>
-#include <coeffs/bigintmat.h>
+#include "polys/monomials/p_polys.h"
+#include "polys/monomials/ring.h"
+#include "polys/simpleideals.h"
+#include "misc/intvec.h"
+#include "polys/matpol.h"
+#include "coeffs/bigintmat.h"
 
 
 void out_cf(const char *s1,const CanonicalForm &f,const char *s2);
@@ -355,7 +346,7 @@ poly singclap_resultant ( poly f, poly g , poly x, const ring r)
         number n=n_Invers(nf,r->cf);
         while(eg>0)
         {
-          res=p_Mult_nn(res,n,r);
+          res=__p_Mult_nn(res,n,r);
           eg--;
         }
         n_Delete(&n,r->cf);
@@ -366,7 +357,7 @@ poly singclap_resultant ( poly f, poly g , poly x, const ring r)
         number n=n_Invers(ng,r->cf);
         while(ef>0)
         {
-          res=p_Mult_nn(res,n,r);
+          res=__p_Mult_nn(res,n,r);
           ef--;
         }
         n_Delete(&n,r->cf);
@@ -531,6 +522,58 @@ BOOLEAN singclap_extgcd ( poly f, poly g, poly &res, poly &pa, poly &pb , const
   return FALSE;
 }
 
+poly singclap_pmult ( poly f, poly g, const ring r )
+{
+  poly res=NULL;
+  On(SW_RATIONAL);
+  if (rField_is_Zp(r) || rField_is_Q(r))
+  {
+    setCharacteristic( rChar(r) );
+    CanonicalForm F( convSingPFactoryP( f,r ) ), G( convSingPFactoryP( g,r ) );
+    res = convFactoryPSingP( F * G,r );
+  }
+  else if (rField_is_Ring_Z(r))
+  {
+    Off(SW_RATIONAL);
+    setCharacteristic( rChar(r) );
+    CanonicalForm F( convSingPFactoryP( f,r ) ), G( convSingPFactoryP( g,r ) );
+    res = convFactoryPSingP( F * G,r );
+  }
+  else if (r->cf->extRing!=NULL)
+  {
+    if (rField_is_Q_a(r)) setCharacteristic( 0 );
+    else               setCharacteristic( rChar(r) );
+    if (r->cf->extRing->qideal!=NULL)
+    {
+      CanonicalForm mipo=convSingPFactoryP(r->cf->extRing->qideal->m[0],
+                                                 r->cf->extRing);
+      Variable a=rootOf(mipo);
+      CanonicalForm F( convSingAPFactoryAP( f,a,r ) ),
+                    G( convSingAPFactoryAP( g,a,r ) );
+      res= convFactoryAPSingAP(  F * G, r  );
+      prune (a);
+    }
+    else
+    {
+      CanonicalForm F( convSingTrPFactoryP( f,r ) ), G( convSingTrPFactoryP( g,r ) );
+      res= convFactoryPSingTrP(  F * G,r  );
+    }
+  }
+#if 0 // not yet working
+  else if (rField_is_GF())
+  {
+    //Print("GF(%d^%d)\n",nfCharP,nfMinPoly[0]);
+    setCharacteristic( nfCharP,nfMinPoly[0], currRing->parameter[0][0] );
+    CanonicalForm F( convSingGFFactoryGF( f ) ), G( convSingGFFactoryGF( g ) );
+    res = convFactoryGFSingGF( F * G );
+  }
+#endif
+  else
+    WerrorS( feNotImplemented );
+  Off(SW_RATIONAL);
+  return res;
+}
+
 poly singclap_pdivide ( poly f, poly g, const ring r )
 {
   poly res=NULL;
@@ -541,13 +584,7 @@ poly singclap_pdivide ( poly f, poly g, const ring r )
     CanonicalForm F( convSingPFactoryP( f,r ) ), G( convSingPFactoryP( g,r ) );
     res = convFactoryPSingP( F / G,r );
   }
-  else if (rField_is_Ring_Z(r))
-  {
-    Off(SW_RATIONAL);
-    setCharacteristic( rChar(r) );
-    CanonicalForm F( convSingPFactoryP( f,r ) ), G( convSingPFactoryP( g,r ) );
-    res = convFactoryPSingP( F / G,r );
-  }
+  // div is not implemented for ZZ coeffs in factory
   else if (r->cf->extRing!=NULL)
   {
     if (rField_is_Q_a(r)) setCharacteristic( 0 );
@@ -583,6 +620,52 @@ poly singclap_pdivide ( poly f, poly g, const ring r )
   return res;
 }
 
+poly singclap_pmod ( poly f, poly g, const ring r )
+{
+  poly res=NULL;
+  On(SW_RATIONAL);
+  if (rField_is_Zp(r) || rField_is_Q(r))
+  {
+    setCharacteristic( rChar(r) );
+    CanonicalForm F( convSingPFactoryP( f,r ) ), G( convSingPFactoryP( g,r ) );
+    res = convFactoryPSingP( F % G,r );
+  }
+  // mod is not implemented for ZZ coeffs in factory
+  else if (r->cf->extRing!=NULL)
+  {
+    if (rField_is_Q_a(r)) setCharacteristic( 0 );
+    else               setCharacteristic( rChar(r) );
+    if (r->cf->extRing->qideal!=NULL)
+    {
+      CanonicalForm mipo=convSingPFactoryP(r->cf->extRing->qideal->m[0],
+                                                 r->cf->extRing);
+      Variable a=rootOf(mipo);
+      CanonicalForm F( convSingAPFactoryAP( f,a,r ) ),
+                    G( convSingAPFactoryAP( g,a,r ) );
+      res= convFactoryAPSingAP(  F % G, r  );
+      prune (a);
+    }
+    else
+    {
+      CanonicalForm F( convSingTrPFactoryP( f,r ) ), G( convSingTrPFactoryP( g,r ) );
+      res= convFactoryPSingTrP(  F % G,r  );
+    }
+  }
+#if 0 // not yet working
+  else if (rField_is_GF())
+  {
+    //Print("GF(%d^%d)\n",nfCharP,nfMinPoly[0]);
+    setCharacteristic( nfCharP,nfMinPoly[0], currRing->parameter[0][0] );
+    CanonicalForm F( convSingGFFactoryGF( f ) ), G( convSingGFFactoryGF( g ) );
+    res = convFactoryGFSingGF( F / G );
+  }
+#endif
+  else
+    WerrorS( feNotImplemented );
+  Off(SW_RATIONAL);
+  return res;
+}
+
 void singclap_divide_content ( poly f, const ring r )
 {
   if ( f==NULL )
@@ -1047,7 +1130,7 @@ ideal singclap_factorize ( poly f, intvec ** v , int with_exps, const ring r)
     p_Delete(&ff,r);
     if (N!=NULL)
     {
-      p_Mult_nn(res->m[0],N,r);
+      __p_Mult_nn(res->m[0],N,r);
       n_Delete(&N,r->cf);
       N=NULL;
     }
@@ -1172,22 +1255,10 @@ ideal singclap_sqrfree ( poly f, intvec ** v , int with_exps, const ring r)
     for(i=rVar(r);i>0;i--) if(p_GetExp(f,i,r)!=0) n++;
     if (with_exps==0 || with_exps==3) n++; // with coeff
     res=idInit(si_max(n,1),1);
-    switch(with_exps)
+    if(with_exps!=1)
     {
-      case 0: // with coef & exp.
-        res->m[0]=p_NSet(n_Copy(pGetCoeff(f),r->cf),r);
-        // no break
-      case 3: // with coef & exp.
-        res->m[0]=p_NSet(n_Copy(pGetCoeff(f),r->cf),r);
-        // no break
-      case 2: // with exp.
         (*v)=new intvec(si_max(1,n));
         (**v)[0]=1;
-        // no break
-      case 1: ;
-      #ifdef TEST
-      default: ;
-      #endif
     }
     res->m[0]=p_NSet(n_Copy(pGetCoeff(f),r->cf),r);
     if (n==0)
@@ -1344,7 +1415,7 @@ ideal singclap_sqrfree ( poly f, intvec ** v , int with_exps, const ring r)
     }
     if (N!=NULL)
     {
-      p_Mult_nn(res->m[0],N,r);
+      __p_Mult_nn(res->m[0],N,r);
       n_Delete(&N,r->cf);
       N=NULL;
     }
