@@ -28,34 +28,29 @@
   *               computing in K[a_1, ..., a_s] / I.
   **/
 
+#include "misc/auxiliary.h"
 
+#include "omalloc/omalloc.h"
 
+#include "reporter/reporter.h"
 
-#include <misc/auxiliary.h>
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
+#include "coeffs/longrat.h"
 
-#include <omalloc/omalloc.h>
+#include "polys/monomials/ring.h"
+#include "polys/monomials/p_polys.h"
+#include "polys/simpleideals.h"
+#include "polys/PolyEnumerator.h"
 
-#include <reporter/reporter.h>
+#include "factory/factory.h"
+#include "polys/clapconv.h"
+#include "polys/clapsing.h"
+#include "polys/prCopy.h"
 
-#include <coeffs/coeffs.h>
-#include <coeffs/numbers.h>
-
-#include <coeffs/longrat.h>
-
-#include <polys/monomials/ring.h>
-#include <polys/monomials/p_polys.h>
-#include <polys/simpleideals.h>
-
-#include <polys/PolyEnumerator.h>
-
-#include <factory/factory.h>
-#include <polys/clapconv.h>
-#include <polys/clapsing.h>
-#include <polys/prCopy.h>
-
-#include <polys/ext_fields/algext.h>
+#include "polys/ext_fields/algext.h"
 #define TRANSEXT_PRIVATES 1
-#include <polys/ext_fields/transext.h>
+#include "polys/ext_fields/transext.h"
 
 #ifdef LDEBUG
 #define naTest(a) naDBTest(a,__FILE__,__LINE__,cf)
@@ -368,11 +363,11 @@ BOOLEAN naGreater(number a, number b, const coeffs cf)
   if (naIsZero(a, cf))
   {
     if (naIsZero(b, cf)) return FALSE;
-    return !n_GreaterZero(pGetCoeff((poly)b),cf);
+    return !n_GreaterZero(pGetCoeff((poly)b),naCoeffs);
   }
   if (naIsZero(b, cf))
   {
-    return n_GreaterZero(pGetCoeff((poly)a),cf);
+    return n_GreaterZero(pGetCoeff((poly)a),naCoeffs);
   }
   int aDeg = p_Totaldegree((poly)a, naRing);
   int bDeg = p_Totaldegree((poly)b, naRing);
@@ -467,8 +462,7 @@ number naMult(number a, number b, const coeffs cf)
 {
   naTest(a); naTest(b);
   if ((a == NULL)||(b == NULL)) return NULL;
-  poly aTimesB = p_Mult_q(p_Copy((poly)a, naRing),
-                          p_Copy((poly)b, naRing), naRing);
+  poly aTimesB = pp_Mult_qq((poly)a, (poly)b, naRing);
   definiteReduce(aTimesB, naMinpoly, cf);
   p_Normalize(aTimesB,naRing);
   return (number)aTimesB;
@@ -627,8 +621,7 @@ number naLcm(number a, number b, const coeffs cf)
   naTest(a); naTest(b);
   if (a == NULL) return NULL;
   if (b == NULL) return NULL;
-  number theProduct = (number)p_Mult_q(p_Copy((poly)a, naRing),
-                                       p_Copy((poly)b, naRing), naRing);
+  number theProduct = (number)pp_Mult_qq((poly)a, (poly)b, naRing);
   /* note that theProduct needs not be reduced w.r.t. naMinpoly;
      but the final division will take care of the necessary reduction */
   number theGcd = naGcd(a, b, cf);
@@ -720,11 +713,7 @@ static BOOLEAN naCoeffIsEqual(const coeffs cf, n_coeffType n, void * param)
 
 int naSize(number a, const coeffs cf)
 {
-  if (a == NULL) return -1;
-  /* this has been taken from the old implementation of field extensions,
-     where we computed the sum of the degree and the number of terms in
-     (poly)a; so we leave it at that, for the time being;
-     maybe, the number of terms alone is a better measure? */
+  if (a == NULL) return 0;
   poly aAsPoly = (poly)a;
   int theDegree = 0; int noOfTerms = 0;
   while (aAsPoly != NULL)
@@ -734,7 +723,7 @@ int naSize(number a, const coeffs cf)
     if (d > theDegree) theDegree = d;
     pIter(aAsPoly);
   }
-  return theDegree + noOfTerms;
+  return (theDegree +1) * noOfTerms;
 }
 
 /* performs polynomial division and overrides p by the remainder
@@ -1256,7 +1245,7 @@ void naClearContent(ICoeffsEnumerator& numberCollectionEnumerator, number& c, co
   n_ClearContent(itr, cc, Q); // TODO: get rid of (-LC) normalization!?
 
   // over alg. ext. of Q // takes over the input number
-  c = (number) p_Mult_nn( (poly)c, cc, R);
+  c = (number) __p_Mult_nn( (poly)c, cc, R);
 //      p_Mult_q(p_NSet(cc, R), , R);
 
   n_Delete(&cc, Q);
@@ -1554,8 +1543,7 @@ number n2pMult(number a, number b, const coeffs cf)
 {
   n2pTest(a); n2pTest(b);
   if ((a == NULL)||(b == NULL)) return NULL;
-  poly aTimesB = p_Mult_q(p_Copy((poly)a, n2pRing),
-                          p_Copy((poly)b, n2pRing), n2pRing);
+  poly aTimesB = pp_Mult_qq((poly)a, (poly)b, n2pRing);
   return (number)aTimesB;
 }
 
