@@ -2,18 +2,15 @@
 *  Computer Algebra System SINGULAR     *
 ****************************************/
 
-#include <omalloc/omalloc.h>
-#include <misc/auxiliary.h>
-
-#include <polys/monomials/p_polys.h>
-//#include <kernel/pShallowCopyDelete.h>
-#include <coeffs/coeffs.h>
-#include <polys/monomials/ring.h>
-//#include <kernel/GBEngine/kutil.h>
-#include <polys/kbuckets.h>
-
-// #include <polys/operations/pShallowCopyDelete.h>
+#include "omalloc/omalloc.h"
+#include "misc/auxiliary.h"
+#include "misc/options.h"
 
+#include "polys/monomials/p_polys.h"
+#include "coeffs/coeffs.h"
+#include "coeffs/numbers.h"
+#include "polys/monomials/ring.h"
+#include "polys/kbuckets.h"
 
 #ifdef HAVE_COEF_BUCKETS
 #define USE_COEF_BUCKETS
@@ -51,23 +48,39 @@ static int coef_start=1;
 /// Some internal stuff
 ///
 
+// https://graphics.stanford.edu/~seander/bithacks.html#IntegerLog
+#ifndef BUCKET_TWO_BASE
+static inline int LOG4(int v)
+{
+  const unsigned int b[] = {0x2, 0xC, 0xF0, 0xFF00, 0xFFFF0000};
+  const unsigned int S[] = {1, 2, 4, 8, 16};
+
+  unsigned int r = 0; // result of log4(v) will go here
+  if (v & b[4]) { v >>= S[4]; r |= S[3]; }
+  if (v & b[3]) { v >>= S[3]; r |= S[2]; }
+  if (v & b[2]) { v >>= S[2]; r |= S[1]; }
+  if (v & b[1]) { v >>= S[1]; r |= S[0]; }
+  return (int)r;
+}
+#endif
+
 // returns ceil(log_4(l))
-inline unsigned int pLogLength(unsigned int l)
+static inline unsigned int pLogLength(unsigned int l)
 {
   unsigned int i = 0;
 
   if (l == 0) return 0;
   l--;
 #ifdef BUCKET_TWO_BASE
-  while ((l = (l >> 1))) i++;
+  i=SI_LOG2(l);
 #else
-  while ((l = (l >> 2))) i++;
+  i=LOG4(l);
 #endif
   return i+1;
 }
 
 // returns ceil(log_4(pLength(p)))
-inline unsigned int pLogLength(poly p)
+static inline unsigned int pLogLength(poly p)
 {
   return pLogLength((unsigned int) pLength(p));
 }
@@ -90,7 +103,7 @@ BOOLEAN kbTest_i(kBucket_pt bucket, int i)
   }
   #endif
   pFalseReturn(p_Test(bucket->buckets[i], bucket->bucket_ring));
-  if (bucket->buckets_length[i] != pLength(bucket->buckets[i]))
+  if ((unsigned)bucket->buckets_length[i] != pLength(bucket->buckets[i]))
   {
     dReportError("Bucket %d lengths difference should:%d has:%d",
                  i, bucket->buckets_length[i], pLength(bucket->buckets[i]));
@@ -211,15 +224,10 @@ void kBucketDeleteAndDestroy(kBucket_pt *bucket_pt)
   int i;
   for (i=0; i<= bucket->buckets_used; i++)
   {
-
-    if (bucket->buckets[i] != NULL)
-    {
-      p_Delete(&(bucket->buckets[i]), bucket->bucket_ring);
+    p_Delete(&(bucket->buckets[i]), bucket->bucket_ring);
 #ifdef USE_COEF_BUCKETS
-      if (bucket->coef[i]!=NULL)
-        p_Delete(&(bucket->coef[i]), bucket->bucket_ring);
+    p_Delete(&(bucket->coef[i]), bucket->bucket_ring);
 #endif
-    }
   }
   omFreeBin(bucket, kBucket_bin);
   *bucket_pt = NULL;
@@ -325,7 +333,7 @@ void kBucketInit(kBucket_pt bucket, poly lm, int length)
 {
   //assume(false);
   assume(bucket != NULL);
-  assume(length <= 0 || length == pLength(lm));
+  assume(length <= 0 || (unsigned)length == pLength(lm));
   assume(kBucketIsCleared(bucket));
 
   if (lm == NULL) return;
@@ -425,7 +433,7 @@ int kBucketCanonicalize(kBucket_pt bucket)
     assume(bucket->coef[0]==NULL);
     assume(bucket->coef[i]==NULL);
   #endif
-  assume(pLength(p) == (int) pl);
+  assume(pLength(p) == (unsigned)pl);
   //if (TEST_OPT_PROT) { Print("C(%d)",pl); }
   kbTest(bucket);
   return i;
@@ -582,7 +590,7 @@ void kBucket_Mult_n(kBucket_pt bucket, number n)
     {
 #ifdef USE_COEF_BUCKETS
       if (i<coef_start)
-        bucket->buckets[i] = p_Mult_nn(bucket->buckets[i], n, r);
+        bucket->buckets[i] = __p_Mult_nn(bucket->buckets[i], n, r);
         /* Frank Seelisch on March 11, 2010:
            This looks a bit strange: The following "if" is indented
            like the previous line of code. But coded as it is,
@@ -598,14 +606,14 @@ void kBucket_Mult_n(kBucket_pt bucket, number n)
       else
       if (bucket->coef[i]!=NULL)
       {
-        bucket->coef[i] = p_Mult_nn(bucket->coef[i],n,r);
+        bucket->coef[i] = __p_Mult_nn(bucket->coef[i],n,r);
       }
       else
       {
         bucket->coef[i] = p_NSet(n_Copy(n,r),r);
       }
 #else
-      bucket->buckets[i] = p_Mult_nn(bucket->buckets[i], n, r);
+      bucket->buckets[i] = __p_Mult_nn(bucket->buckets[i], n, r);
       if (rField_is_Ring(r) && !(rField_is_Domain(r)))
       {
         bucket->buckets_length[i] = pLength(bucket->buckets[i]);
@@ -616,7 +624,7 @@ void kBucket_Mult_n(kBucket_pt bucket, number n)
   }
   kbTest(bucket);
 #else
-  bucket->p = p_Mult_nn(bucket->p, n, bucket->bucket_ring);
+  bucket->p = __p_Mult_nn(bucket->p, n, bucket->bucket_ring);
 #endif
 }
 
@@ -725,7 +733,7 @@ void kBucket_Minus_m_Mult_p(kBucket_pt bucket, poly m, poly p, int *l,
   {
     if ((i <= bucket->buckets_used) && (bucket->buckets[i] != NULL))
     {
-      assume(pLength(bucket->buckets[i])==bucket->buckets_length[i]);
+      assume(pLength(bucket->buckets[i])==(unsigned)bucket->buckets_length[i]);
 //#ifdef USE_COEF_BUCKETS
 //     if(bucket->coef[i]!=NULL)
 //     {
@@ -795,7 +803,7 @@ void kBucket_Minus_m_Mult_p(kBucket_pt bucket, poly m, poly p, int *l,
 void kBucket_Plus_mm_Mult_pp(kBucket_pt bucket, poly m, poly p, int l)
 {
     assume((!rIsPluralRing(bucket->bucket_ring))||p_IsConstant(m, bucket->bucket_ring));
-  assume(l <= 0 || pLength(p) == l);
+  assume(l <= 0 || pLength(p) == (unsigned)l);
   int i, l1;
   poly p1 = p;
   ring r = bucket->bucket_ring;
@@ -846,7 +854,7 @@ void kBucket_Plus_mm_Mult_pp(kBucket_pt bucket, poly m, poly p, int l)
       number backup=p_GetCoeff(m,r);
 
       p_SetCoeff0(m,add_coef,r);
-      bucket->buckets[i]=p_Mult_nn(bucket->buckets[i],orig_coef,r);
+      bucket->buckets[i]=__p_Mult_nn(bucket->buckets[i],orig_coef,r);
 
       n_Delete(&orig_coef,r);
       p_Delete(&bucket->coef[i],r);
@@ -916,8 +924,8 @@ void kBucket_Plus_mm_Mult_pp(kBucket_pt bucket, poly m, poly p, int l)
         n=gcd;
       }
       //assume(n_IsOne(n,r));
-      bucket->buckets[i]=p_Mult_nn(bucket->buckets[i],orig_coef,r);
-      p1=p_Mult_nn(p1,add_coef,r);
+      bucket->buckets[i]=__p_Mult_nn(bucket->buckets[i],orig_coef,r);
+      p1=__p_Mult_nn(p1,add_coef,r);
 
       p1 = p_Add_q(p1, bucket->buckets[i],r);
       l1=pLength(p1);
@@ -935,7 +943,7 @@ void kBucket_Plus_mm_Mult_pp(kBucket_pt bucket, poly m, poly p, int l)
       #ifdef USE_COEF_BUCKETS
       if(!(n_IsOne(n,r)))
       {
-        p1=p_Mult_nn(p1, n, r);
+        p1=__p_Mult_nn(p1, n, r);
         n_Delete(&n,r);
         n=n_Init(1,r);
       }
@@ -963,7 +971,7 @@ void kBucket_Plus_mm_Mult_pp(kBucket_pt bucket, poly m, poly p, int l)
     n_Delete(&n,r);
   }
 
-  if ((p1==NULL) && (bucket->coef[i]!=NULL))
+  if (p1==NULL)
     p_Delete(&bucket->coef[i],r);
 #endif
   bucket->buckets_length[i]=l1;
@@ -1026,9 +1034,9 @@ void kBucketTakeOutComp(kBucket_pt bucket,
       p_TakeOutComp(&(bucket->buckets[i]), comp, &q, &lq, bucket->bucket_ring);
       if (q != NULL)
       {
-        assume(pLength(q) == lq);
+        assume(pLength(q) == (unsigned)lq);
         bucket->buckets_length[i] -= lq;
-        assume(pLength(bucket->buckets[i]) == bucket->buckets_length[i]);
+        assume(pLength(bucket->buckets[i]) == (unsigned)bucket->buckets_length[i]);
         p = p_Add_q(p, q, lp, lq, bucket->bucket_ring);
       }
     }
@@ -1058,7 +1066,7 @@ number kBucketPolyRed(kBucket_pt bucket,
   assume((!rIsPluralRing(r))||p_LmEqual(p1,kBucketGetLm(bucket), r));
   assume(p1 != NULL &&
          p_DivisibleBy(p1,  kBucketGetLm(bucket), r));
-  assume(pLength(p1) == (int) l1);
+  assume(pLength(p1) == (unsigned) l1);
 
   poly a1 = pNext(p1), lm = kBucketExtractLm(bucket);
   BOOLEAN reset_vec=FALSE;
@@ -1094,7 +1102,7 @@ number kBucketPolyRed(kBucket_pt bucket,
 
       /* correct factor for cancelation by changing sign if an=-1 */
       if (rField_is_Ring(r))
-        lm = p_Mult_nn(lm, an, r);
+        lm = __p_Mult_nn(lm, an, r);
       else
         kBucket_Mult_n(bucket, an);
     }
@@ -1116,7 +1124,7 @@ number kBucketPolyRed(kBucket_pt bucket,
   p_ExpVectorSub(lm, p1, r);
   l1--;
 
-  assume(l1==pLength(a1));
+  assume((unsigned)l1==pLength(a1));
 #if 0
   BOOLEAN backuped=FALSE;
   number coef;
@@ -1151,7 +1159,84 @@ number kBucketPolyRed(kBucket_pt bucket,
 }
 
 #ifndef USE_COEF_BUCKETS
-void kBucketSimpleContent(kBucket_pt) {}
+void kBucketSimpleContent(kBucket_pt bucket)
+{
+  if (bucket->buckets[0]==NULL) return;
+
+  ring r=bucket->bucket_ring;
+  if (rField_is_Ring(r)) return;
+
+  coeffs cf=r->cf;
+  if (cf->cfSubringGcd==ndGcd) /* trivial gcd*/ return;
+
+  number nn=pGetCoeff(bucket->buckets[0]);
+  //if ((bucket->buckets_used==0)
+  //&&(!n_IsOne(nn,cf)))
+  //{
+  //  if (TEST_OPT_PROT) PrintS("@");
+  //  p_SetCoeff(bucket->buckets[0],n_Init(1,cf),r);
+  //  return;
+  //}
+
+  if (n_Size(nn,cf)<2) return;
+
+  //kBucketAdjustBucketsUsed(bucket);
+  number coef=n_Copy(nn,cf);
+  // find an initial guess of a gcd
+  for (int i=1; i<=bucket->buckets_used;i++)
+  {
+    if (bucket->buckets[i]!=NULL)
+    {
+      number t=p_InitContent(bucket->buckets[i],r);
+      if (n_Size(t,cf)<2)
+      {
+        n_Delete(&t,cf);
+        n_Delete(&coef,cf);
+        return;
+      }
+      number t2=n_SubringGcd(coef,t,cf);
+      n_Delete(&t,cf);
+      n_Delete(&coef,cf);
+      coef=t2;
+      if (n_Size(coef,cf)<2) { n_Delete(&coef,cf);return;}
+    }
+  }
+  // find the gcd
+  for (int i=0; i<=bucket->buckets_used;i++)
+  {
+    if (bucket->buckets[i]!=NULL)
+    {
+      poly p=bucket->buckets[i];
+      while(p!=NULL)
+      {
+        number t=n_SubringGcd(coef,pGetCoeff(p),cf);
+        if (n_Size(t,cf)<2)
+        {
+          n_Delete(&t,cf);
+          n_Delete(&coef,cf);
+          return;
+        }
+        pIter(p);
+      }
+    }
+  }
+  // divided by the gcd
+  if (TEST_OPT_PROT) PrintS("@");
+  for (int i=bucket->buckets_used;i>=0;i--)
+  {
+    if (bucket->buckets[i]!=NULL)
+    {
+      poly p=bucket->buckets[i];
+      while(p!=NULL)
+      {
+        number d = n_ExactDiv(pGetCoeff(p),coef,cf);
+        p_SetCoeff(p,d,r);
+        pIter(p);
+      }
+    }
+  }
+  n_Delete(&coef,cf);
+}
 #else
 static BOOLEAN nIsPseudoUnit(number n, ring r)
 {
@@ -1269,7 +1354,7 @@ poly kBucketExtractLmOfBucket(kBucket_pt bucket, int i)
       bucket->buckets[i]=next;
       number c=p_GetCoeff(bucket->coef[i],r);
       pNext(p)=NULL;
-      p=p_Mult_nn(p,c,r);
+      p=__p_Mult_nn(p,c,r);
       assume(p!=NULL);
       return p;
     }
