@@ -16,23 +16,23 @@
 #ifndef P_POLYS_H
 #define P_POLYS_H
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/mylimits.h>
-#include <misc/intvec.h>
-#include <coeffs/coeffs.h>
+#include "misc/mylimits.h"
+#include "misc/intvec.h"
+#include "coeffs/coeffs.h"
 
-#include <polys/monomials/monomials.h>
-#include <polys/monomials/ring.h>
+#include "polys/monomials/monomials.h"
+#include "polys/monomials/ring.h"
 
-#include <polys/templates/p_MemAdd.h>
-#include <polys/templates/p_MemCmp.h>
-#include <polys/templates/p_Procs.h>
+#include "polys/templates/p_MemAdd.h"
+#include "polys/templates/p_MemCmp.h"
+#include "polys/templates/p_Procs.h"
 
-#include <polys/sbuckets.h>
+#include "polys/sbuckets.h"
 
 #ifdef HAVE_PLURAL
-#include <polys/nc/nc.h>
+#include "polys/nc/nc.h"
 #endif
 
 poly p_Farey(poly p, number N, const ring r);
@@ -97,6 +97,9 @@ poly      p_NSet(number n, const ring r);
 
 void  p_Vec2Polys(poly v, poly**p, int *len, const ring r);
 
+/// julia: vector to already allocated array (len=p_MaxComp(v,r))
+void  p_Vec2Array(poly v, poly *p, int len, const ring r);
+
 /***************************************************************
  *
  * Copying/Deletion of polys: args may be NULL
@@ -186,9 +189,9 @@ BOOLEAN _pp_Test(poly p, ring lmRing, ring tailRing, int level);
 /*2
 * returns the length of a polynomial (numbers of monomials)
 */
-static inline int pLength(poly a)
+static inline unsigned pLength(poly a)
 {
-  int l = 0;
+  unsigned l = 0;
   while (a!=NULL)
   {
     pIter(a);
@@ -207,10 +210,12 @@ void      p_Norm(poly p1, const ring r);
 void      p_Normalize(poly p,const ring r);
 void      p_ProjectiveUnique(poly p,const ring r);
 
+void      p_ContentForGB(poly p, const ring r);
 void      p_Content(poly p, const ring r);
 #if 1
 // currently only used by Singular/janet
 void      p_SimpleContent(poly p, int s, const ring r);
+number    p_InitContent(poly ph, const ring r);
 #endif
 
 poly      p_Cleardenom(poly p, const ring r);
@@ -487,10 +492,10 @@ static inline unsigned long p_SetExp(poly p, const unsigned long e, const unsign
   pAssume2((VarOffset >> (24 + 6)) == 0);
 
   // shift e to the left:
-  register int shift = VarOffset >> 24;
+  REGISTER int shift = VarOffset >> 24;
   unsigned long ee = e << shift /*(VarOffset >> 24)*/;
   // find the bits in the exponent vector
-  register int offset = (VarOffset & 0xffffff);
+  REGISTER int offset = (VarOffset & 0xffffff);
   // clear the bits in the exponent vector:
   p->exp[offset]  &= ~( iBitmask << shift );
   // insert e with |
@@ -531,12 +536,12 @@ static inline long p_SetExp(poly p, const long e, const unsigned long iBitmask,
   pAssume2(e <= BitMask(iBitmask, VarOffset >> 30));
 
   // shift e to the left:
-  register int hbyte = VarOffset >> 24;
+  REGISTER int hbyte = VarOffset >> 24;
   int bitmask = BitMask(iBitmask, hbyte >> 6);
-  register int shift = hbyte & 0x3f;
+  REGISTER int shift = hbyte & 0x3f;
   long ee = e << shift;
   // find the bits in the exponent vector
-  register int offset = (VarOffset & 0xffffff);
+  REGISTER int offset = (VarOffset & 0xffffff);
   // clear the bits in the exponent vector:
   p->exp[offset]  &= ~( bitmask << shift );
   // insert e with |
@@ -796,17 +801,25 @@ p_GetTotalDegree(const unsigned long l, const ring r, const int number_of_exps)
 /// returns a copy of p (without any additional testing)
 static inline poly p_Copy_noCheck(poly p, const ring r)
 {
-  assume(r != NULL); assume(r->p_Procs != NULL); assume(r->p_Procs->p_Copy != NULL);
+  /*assume(p!=NULL);*/
+  assume(r != NULL);
+  assume(r->p_Procs != NULL);
+  assume(r->p_Procs->p_Copy != NULL);
   return r->p_Procs->p_Copy(p, r);
 }
 
 /// returns a copy of p
 static inline poly p_Copy(poly p, const ring r)
 {
-  p_Test(p,r);
-  const poly pp = p_Copy_noCheck(p, r);
-  p_Test(pp,r);
-  return pp;
+  if (p!=NULL)
+  {
+    p_Test(p,r);
+    const poly pp = p_Copy_noCheck(p, r);
+    p_Test(pp,r);
+    return pp;
+  }
+  else
+    return NULL;
 }
 
 static inline poly p_Head(poly p, const ring r)
@@ -832,7 +845,8 @@ static inline poly p_Copy(poly p, const ring lmRing, const ring tailRing)
       return p_Copy_noCheck(p, tailRing);
 #endif
     poly pres = p_Head(p, lmRing);
-    pNext(pres) = p_Copy_noCheck(pNext(p), tailRing);
+    if (pNext(p)!=NULL)
+      pNext(pres) = p_Copy_noCheck(pNext(p), tailRing);
     return pres;
   }
   else
@@ -843,7 +857,8 @@ static inline poly p_Copy(poly p, const ring lmRing, const ring tailRing)
 static inline void p_Delete(poly *p, const ring r)
 {
   assume( p!= NULL );
-  r->p_Procs->p_Delete(p, r);
+  assume( r!= NULL );
+  if ((*p)!=NULL) r->p_Procs->p_Delete(p, r);
 }
 
 static inline void p_Delete(poly *p,  const ring lmRing, const ring tailRing)
@@ -877,6 +892,8 @@ static inline poly p_ShallowCopyDelete(poly p, const ring r, omBin bin)
 static inline poly p_Add_q(poly p, poly q, const ring r)
 {
   assume( (p != q) || (p == NULL && q == NULL) );
+  if (q==NULL) return p;
+  if (p==NULL) return q;
   int shorter;
   return r->p_Procs->p_Add_q(p, q, shorter, r);
 }
@@ -885,28 +902,34 @@ static inline poly p_Add_q(poly p, poly q, const ring r)
 static inline poly p_Add_q(poly p, poly q, int &lp, int lq, const ring r)
 {
   assume( (p != q) || (p == NULL && q == NULL) );
+  if (q==NULL) return p;
+  if (p==NULL) { lp=lq; return q; }
   int shorter;
   poly res = r->p_Procs->p_Add_q(p, q, shorter, r);
-  lp = (lp + lq) - shorter;
+  lp += lq - shorter;
   return res;
 }
 
 // returns p*n, destroys p
 static inline poly p_Mult_nn(poly p, number n, const ring r)
 {
+  if (p==NULL) return NULL;
   if (n_IsOne(n, r->cf))
     return p;
   else if (n_IsZero(n, r->cf))
   {
-    r->p_Procs->p_Delete(&p, r); // NOTE: without p_Delete - memory leak!
+    p_Delete(&p, r); // NOTE: without p_Delete - memory leak!
     return NULL;
-  } else
+  }
+  else
     return r->p_Procs->p_Mult_nn(p, n, r);
 }
+#define __p_Mult_nn(p,n,r) r->p_Procs->p_Mult_nn(p, n, r)
 
 static inline poly p_Mult_nn(poly p, number n, const ring lmRing,
                         const ring tailRing)
 {
+  assume(p!=NULL);
 #ifndef PDEBUG
   if (lmRing == tailRing)
     return p_Mult_nn(p, n, tailRing);
@@ -914,18 +937,25 @@ static inline poly p_Mult_nn(poly p, number n, const ring lmRing,
   poly pnext = pNext(p);
   pNext(p) = NULL;
   p = lmRing->p_Procs->p_Mult_nn(p, n, lmRing);
-  pNext(p) = tailRing->p_Procs->p_Mult_nn(pnext, n, tailRing);
+  if (pnext!=NULL)
+  {
+    pNext(p) = tailRing->p_Procs->p_Mult_nn(pnext, n, tailRing);
+  }
   return p;
 }
 
 // returns p*n, does not destroy p
 static inline poly pp_Mult_nn(poly p, number n, const ring r)
 {
+  if (p==NULL) return NULL;
   if (n_IsOne(n, r->cf))
     return p_Copy(p, r);
+  else if (n_IsZero(n, r->cf))
+    return NULL;
   else
     return r->p_Procs->pp_Mult_nn(p, n, r);
 }
+#define __pp_Mult_nn(p,n,r) r->p_Procs->pp_Mult_nn(p, n, r)
 
 // test if the monomial is a constant as a vector component
 // i.e., test if all exponents are zero
@@ -956,19 +986,19 @@ static inline BOOLEAN p_LmIsConstant(const poly p, const ring r)
 // returns Copy(p)*m, does neither destroy p nor m
 static inline poly pp_Mult_mm(poly p, poly m, const ring r)
 {
+  if (p==NULL) return NULL;
   if (p_LmIsConstant(m, r))
-    return pp_Mult_nn(p, pGetCoeff(m), r);
+    return __pp_Mult_nn(p, pGetCoeff(m), r);
   else
-  {
     return r->p_Procs->pp_Mult_mm(p, m, r);
-  }
 }
 
 // returns p*m, destroys p, const: m
 static inline poly p_Mult_mm(poly p, poly m, const ring r)
 {
+  if (p==NULL) return NULL;
   if (p_LmIsConstant(m, r))
-    return p_Mult_nn(p, pGetCoeff(m), r);
+    return __p_Mult_nn(p, pGetCoeff(m), r);
   else
     return r->p_Procs->p_Mult_mm(p, m, r);
 }
@@ -1023,12 +1053,12 @@ static inline poly p_Mult_q(poly p, poly q, const ring r)
 
   if (p == NULL)
   {
-    r->p_Procs->p_Delete(&q, r);
+    p_Delete(&q, r);
     return NULL;
   }
   if (q == NULL)
   {
-    r->p_Procs->p_Delete(&p, r);
+    p_Delete(&p, r);
     return NULL;
   }
 
@@ -1041,21 +1071,14 @@ static inline poly p_Mult_q(poly p, poly q, const ring r)
 #endif /* HAVE_PLURAL */
       q = r->p_Procs->p_Mult_mm(q, p, r);
 
-    r->p_Procs->p_Delete(&p, r);
+    p_LmDelete(&p, r);
     return q;
   }
 
   if (pNext(q) == NULL)
   {
-  // NEEDED
-#ifdef HAVE_PLURAL
-/*    if (rIsPluralRing(r))
-      p = gnc_p_Mult_mm(p, q, r); // ???
-    else*/
-#endif /* HAVE_PLURAL */
-      p = r->p_Procs->p_Mult_mm(p, q, r);
-
-    r->p_Procs->p_Delete(&q, r);
+    p = r->p_Procs->p_Mult_mm(p, q, r);
+    p_LmDelete(&q, r);
     return p;
   }
 #ifdef HAVE_PLURAL
@@ -1272,7 +1295,7 @@ static inline poly p_LmInit(poly s_p, const ring s_r, const ring d_r, omBin d_bi
   p_CheckRing(d_r);
   pAssume1(d_r->N <= s_r->N);
   poly d_p = p_Init(d_r, d_bin);
-  for (int i=d_r->N; i>0; i--)
+  for (unsigned i=d_r->N; i!=0; i--)
   {
     p_SetExp(d_p, i, p_GetExp(s_p, i,s_r), d_r);
   }
@@ -1373,8 +1396,8 @@ static inline void p_ExpVectorSub(poly p1, poly p2, const ring r)
 
   p_MemSub_LengthGeneral(p1->exp, p2->exp, r->ExpL_Size);
   p_MemSub_NegWeightAdjust(p1, r);
-
 }
+
 // ExpVector(p1) += ExpVector(p2) - ExpVector(p3)
 static inline void p_ExpVectorAddSub(poly p1, poly p2, poly p3, const ring r)
 {
@@ -1414,7 +1437,7 @@ static inline BOOLEAN p_ExpVectorEqual(poly p1, poly p2, const ring r)
   p_LmCheckPolyRing1(p1, r);
   p_LmCheckPolyRing1(p2, r);
 
-  int i = r->ExpL_Size;
+  unsigned i = r->ExpL_Size;
   unsigned long *ep = p1->exp;
   unsigned long *eq = p2->exp;
 
@@ -1423,7 +1446,7 @@ static inline BOOLEAN p_ExpVectorEqual(poly p1, poly p2, const ring r)
     i--;
     if (ep[i] != eq[i]) return FALSE;
   }
-  while (i);
+  while (i!=0);
   return TRUE;
 }
 
@@ -1433,7 +1456,7 @@ static inline long p_Totaldegree(poly p, const ring r)
   unsigned long s = p_GetTotalDegree(p->exp[r->VarL_Offset[0]],
                                      r,
                                      r->ExpPerLong);
-  for (int i=r->VarL_Size-1; i>0; i--)
+  for (unsigned i=r->VarL_Size-1; i!=0; i--)
   {
     s += p_GetTotalDegree(p->exp[r->VarL_Offset[i]], r,r->ExpPerLong);
   }
@@ -1443,18 +1466,35 @@ static inline long p_Totaldegree(poly p, const ring r)
 static inline void p_GetExpV(poly p, int *ev, const ring r)
 {
   p_LmCheckPolyRing1(p, r);
-  for (int j = r->N; j; j--)
+  for (unsigned j = r->N; j!=0; j--)
       ev[j] = p_GetExp(p, j, r);
 
   ev[0] = p_GetComp(p, r);
 }
+// p_GetExpVL is used in Singular,jl
+static inline void p_GetExpVL(poly p, int64 *ev, const ring r)
+{
+  p_LmCheckPolyRing1(p, r);
+  for (unsigned j = r->N; j!=0; j--)
+      ev[j-1] = p_GetExp(p, j, r);
+}
 static inline void p_SetExpV(poly p, int *ev, const ring r)
 {
   p_LmCheckPolyRing1(p, r);
-  for (int j = r->N; j; j--)
+  for (unsigned j = r->N; j!=0; j--)
       p_SetExp(p, j, ev[j], r);
 
-  p_SetComp(p, ev[0],r);
+  if(ev[0]!=0) p_SetComp(p, ev[0],r);
+  p_Setm(p, r);
+}
+// p_SetExpVL is used in Singular,jl
+static inline void p_SetExpVL(poly p, int64 *ev, const ring r)
+{
+  p_LmCheckPolyRing1(p, r);
+  for (unsigned j = r->N; j!=0; j--)
+      p_SetExp(p, j, ev[j], r);
+
+  if(ev[0]!=0) p_SetComp(p, ev[0],r);
   p_Setm(p, r);
 }
 
@@ -1471,11 +1511,11 @@ static inline int p_LmCmp(poly p, poly q, const ring r)
 
   const unsigned long* _s1 = ((unsigned long*) p->exp);
   const unsigned long* _s2 = ((unsigned long*) q->exp);
-  register unsigned long _v1;
-  register unsigned long _v2;
+  REGISTER unsigned long _v1;
+  REGISTER unsigned long _v2;
   const unsigned long _l = r->CmpL_Size;
 
-  register unsigned long _i=0;
+  REGISTER unsigned long _i=0;
 
   LengthGeneral_OrdGeneral_LoopTop:
   _v1 = _s1[_i];
@@ -1487,14 +1527,21 @@ static inline int p_LmCmp(poly p, poly q, const ring r)
     goto LengthGeneral_OrdGeneral_LoopTop;
   }
   const long* _ordsgn = (long*) r->ordsgn;
+#if 1 /* two variants*/ 
   if (_v1 > _v2)
   {
-    if (_ordsgn[_i] == 1) return 1;
-    return -1;
+    return _ordsgn[_i];
   }
-  if (_ordsgn[_i] == 1) return -1;
-  return 1;
-
+  return -(_ordsgn[_i]);
+#else
+   if (_v1 > _v2)
+   {
+     if (_ordsgn[_i] == 1) return 1;
+     return -1;
+   }
+   if (_ordsgn[_i] == 1) return -1;
+   return 1;
+#endif
 }
 
 // The coefficient will be compared in absolute value
@@ -1513,9 +1560,9 @@ static inline int p_LtCmp(poly p, poly q, const ring r)
       qc = n_InpNeg(qc,r->cf);
     if(n_Greater(pc,qc,r->cf))
       res = 1;
-    if(n_Greater(qc,pc,r->cf))
+    else if(n_Greater(qc,pc,r->cf))
       res = -1;
-    if(n_Equal(pc,qc,r->cf))
+    else if(n_Equal(pc,qc,r->cf))
       res = 0;
     n_Delete(&pc,r->cf);
     n_Delete(&qc,r->cf);
@@ -1550,7 +1597,7 @@ static inline int p_LtCmpOrdSgnDiffM(poly p, poly q, const ring r)
 {
   if(r->OrdSgn == 1)
   {
-    return(p_LtCmp(p,q,r) != -1);
+    return(p_LtCmp(p,q,r) == 1);
   }
   else
   {
@@ -1931,12 +1978,14 @@ void      p_Split(poly p, poly * r);   /*p => IN(p), r => REST(p) */
 BOOLEAN p_HasNotCF(poly p1, poly p2, const ring r);
 poly      p_mInit(const char *s, BOOLEAN &ok, const ring r); /* monom s -> poly, interpreter */
 const char *    p_Read(const char *s, poly &p,const ring r); /* monom -> poly */
-poly      p_Divide(poly a, poly b, const ring r);
+poly      p_MDivide(poly a, poly b, const ring r);
 poly      p_DivideM(poly a, poly b, const ring r);
 poly      p_Div_nn(poly p, const number n, const ring r);
 
-// returns the LCM of the head terms of a and b in *m
+// returns the LCM of the head terms of a and b in *m, does not p_Setm
 void p_Lcm(const poly a, const poly b, poly m, const ring r);
+// returns the LCM of the head terms of a and b, does p_Setm
+poly p_Lcm(const poly a, const poly b, const ring r);
 
 #ifdef HAVE_RATGRING
 poly p_LcmRat(const poly a, const poly b, const long lCompM, const ring r);
@@ -2008,9 +2057,6 @@ poly p_PermPoly (poly p, const int * perm,const ring OldRing, const ring dst,
 
 /*----------------------------------------------------*/
 poly p_Series(int n,poly p,poly u, intvec *w, const ring R);
-poly p_Invers(int n,poly u,intvec *w, const ring R);
-
-
 
 /*----------------------------------------------------*/
 int   p_Var(poly mi, const ring r);
@@ -2020,5 +2066,14 @@ int   p_LowVar (poly p, const ring r);
 /*----------------------------------------------------*/
 /// shifts components of the vector p by i
 void p_Shift (poly * p,int i, const ring r);
+/*----------------------------------------------------*/
+
+int p_Compare(const poly a, const poly b, const ring R);
+
+/// polynomial gcd for f=mon
+poly p_GcdMon(poly f, poly g, const ring r);
+
+/// divide polynomial by monomial
+poly p_Div_mm(poly p, const poly m, const ring r);
 #endif // P_POLYS_H
 
