@@ -8,15 +8,14 @@
  *  Author:  obachman (Olaf Bachmann)
  *  Created: 9/00
  *******************************************************************/
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/auxiliary.h>
+#include "misc/auxiliary.h"
 
-#include <polys/sbuckets.h>
+#include "polys/sbuckets.h"
 
-#include <polys/monomials/ring.h>
-//#include <kernel/p_Procs.h>
-#include <polys/monomials/p_polys.h>
+#include "polys/monomials/ring.h"
+#include "polys/monomials/p_polys.h"
 
 
 
@@ -94,26 +93,6 @@ sBucket_pt    sBucketCopy(const sBucket_pt bucket)
   return newbucket;
 }
 
-/////////////////////////////////////////////////////////////////////////////
-// internal routines
-//
-// returns floor(log_2(i))
-static inline int LOG2(int i)
-{
-  assume (i > 0);
-  int j = 0;
-
-  do
-  {
-    i = i >> 1;
-    if (i == 0) return j;
-    j++;
-  }
-  while (1);
-
-  return j;
-}
-
 //////////////////////////////////////////////////////////////////////////
 // Creation/Destruction of buckets
 //
@@ -137,11 +116,7 @@ void sBucketDeleteAndDestroy(sBucket_pt *bucket_pt)
   int i;
   for (i=0; i<= bucket->max_bucket; i++)
   {
-
-    if (bucket->buckets[i].p != NULL)
-    {
-      p_Delete(&(bucket->buckets[i].p), bucket->bucket_ring);
-    }
+    p_Delete(&(bucket->buckets[i].p), bucket->bucket_ring);
   }
   omFreeBin(bucket, sBucket_bin);
   *bucket_pt = NULL;
@@ -152,7 +127,7 @@ void sBucketDeleteAndDestroy(sBucket_pt *bucket_pt)
 // Convertion from/to SBpolys
 //
 
-static void sBucket_Merge_m(sBucket_pt bucket, poly p)
+void sBucket_Merge_m(sBucket_pt bucket, poly p)
 {
   assume(p != NULL && pNext(p) == NULL);
   int length = 1;
@@ -165,7 +140,7 @@ static void sBucket_Merge_m(sBucket_pt bucket, poly p)
     bucket->buckets[i].p = NULL;
     bucket->buckets[i].length = 0;
     i++;
-    assume(LOG2(length) == i);
+    assume(SI_LOG2(length) == i);
   }
 
   bucket->buckets[i].p = p;
@@ -181,7 +156,7 @@ void sBucket_Merge_p(sBucket_pt bucket, poly p, int length)
   if (p == NULL) return;
   if (length <= 0) length = pLength(p);
 
-  int i = LOG2(length);
+  int i = SI_LOG2(length);
 
   while (bucket->buckets[i].p != NULL)
   {
@@ -190,7 +165,37 @@ void sBucket_Merge_p(sBucket_pt bucket, poly p, int length)
     bucket->buckets[i].p = NULL;
     bucket->buckets[i].length = 0;
     i++;
-    assume(LOG2(length) == i);
+    assume(SI_LOG2(length) == i);
+  }
+
+  bucket->buckets[i].p = p;
+  bucket->buckets[i].length = length;
+  if (i > bucket->max_bucket) bucket->max_bucket = i;
+}
+
+void sBucket_Add_m(sBucket_pt bucket, poly p)
+{
+  assume(bucket != NULL);
+  assume(1 == pLength(p));
+
+  int length = 1;
+
+  int i = 0; //SI_LOG2(length);
+
+  while (bucket->buckets[i].p != NULL)
+  {
+    int shorter;
+    p = bucket->bucket_ring->p_Procs->p_Add_q(p, bucket->buckets[i].p,
+                shorter, bucket->bucket_ring);
+    length+=bucket->buckets[i].length-shorter;
+    bucket->buckets[i].p = NULL;
+    bucket->buckets[i].length = 0;
+    if (p==NULL)
+    {
+      if (i > bucket->max_bucket) bucket->max_bucket = i;
+      return;
+    }
+    i = SI_LOG2(length);
   }
 
   bucket->buckets[i].p = p;
@@ -206,12 +211,14 @@ void sBucket_Add_p(sBucket_pt bucket, poly p, int length)
   if (p == NULL) return;
   if (length <= 0) length = pLength(p);
 
-  int i = LOG2(length);
+  int i = SI_LOG2(length);
 
   while (bucket->buckets[i].p != NULL)
   {
-    p = p_Add_q(p, bucket->buckets[i].p, length, bucket->buckets[i].length,
+    int shorter;
+    p = bucket->bucket_ring->p_Procs->p_Add_q(p, bucket->buckets[i].p, shorter,
                 bucket->bucket_ring);
+    length+= bucket->buckets[i].length-shorter;
     bucket->buckets[i].p = NULL;
     bucket->buckets[i].length = 0;
     if (p==NULL)
@@ -219,7 +226,7 @@ void sBucket_Add_p(sBucket_pt bucket, poly p, int length)
       if (i > bucket->max_bucket) bucket->max_bucket = i;
       return;
     }
-    i = LOG2(length);
+    i = SI_LOG2(length);
   }
 
   bucket->buckets[i].p = p;
@@ -326,12 +333,11 @@ done:
 
 poly sBucketSortMerge(poly p, const ring r)
 {
-#ifdef HAVE_ASSUME
-  int l_in = pLength(p);
-#endif
-
   if (p == NULL || pNext(p) == NULL) return p;
 
+#ifndef SING_NDEBUG
+  int l_in = pLength(p);
+#endif  
   sBucket_pt bucket = sBucketCreate(r);
   poly pn = pNext(p);
 
@@ -350,10 +356,8 @@ poly sBucketSortMerge(poly p, const ring r)
   sBucketDestroy(&bucket);
 
   p_Test(pn, r);
-#ifdef HAVE_ASSUME
   assume(l_dummy == pLength(pn));
   assume(l_in == l_dummy);
-#endif
   return pn;
 }
 
@@ -363,7 +367,7 @@ poly sBucketSortMerge(poly p, const ring r)
 
 poly sBucketSortAdd(poly p, const ring r)
 {
-#ifdef HAVE_ASSUME
+#ifndef SING_NDEBUG
   int l_in = pLength(p);
 #endif
 
@@ -375,7 +379,7 @@ poly sBucketSortAdd(poly p, const ring r)
   do
   {
     pNext(p) = NULL;
-    sBucket_Add_p(bucket, p, 1);
+    sBucket_Add_m(bucket, p);
     p = pn;
     if (p == NULL) break;
     pn = pNext(pn);
@@ -387,7 +391,7 @@ poly sBucketSortAdd(poly p, const ring r)
   sBucketDestroy(&bucket);
 
   p_Test(pn, r);
-#ifdef HAVE_ASSUME
+#ifndef SING_NDEBUG
   assume(l_dummy == pLength(pn));
   assume(l_in >= l_dummy);
 #endif
