@@ -10,14 +10,13 @@
 
 
 
-#include <misc/auxiliary.h>
+#include "misc/auxiliary.h"
 
-#include <omalloc/omalloc.h>
+#include "omalloc/omalloc.h"
 
-#include <misc/options.h>
-#include <misc/intvec.h>
+#include "misc/options.h"
+#include "misc/intvec.h"
 
-// #include <coeffs/longrat.h>
 #include "matpol.h"
 
 #include "monomials/p_polys.h"
@@ -125,14 +124,17 @@ void id_Delete (ideal * h, ring r)
   {
     assume( (*h)->m != NULL );
 
-    int j = elems;
-    do
+    if (r!=NULL)
     {
-      j--;
-      poly pp=((*h)->m[j]);
-      if (pp!=NULL) p_Delete(&pp, r);
+      int j = elems;
+      do
+      {
+        j--;
+        poly pp=((*h)->m[j]);
+        if (pp!=NULL) p_Delete(&pp, r);
+      }
+      while (j>0);
     }
-    while (j>0);
 
     omFreeSize((ADDRESS)((*h)->m),sizeof(poly)*elems);
   }
@@ -1134,13 +1136,34 @@ ideal id_Vec2Ideal(poly vec, const ring R)
 {
    ideal result=idInit(1,1);
    omFree((ADDRESS)result->m);
-   result->m=NULL; // remove later
    p_Vec2Polys(vec, &(result->m), &(IDELEMS(result)),R);
    return result;
 }
 
+/// for julia: convert an array of poly to vector
+poly id_Array2Vector(poly *m, unsigned n, const ring R)
+{
+  poly h;
+  int l;
+  sBucket_pt bucket = sBucketCreate(R);
 
-// converts mat to module, destroys mat
+  for(unsigned j=0;j<n ;j++)
+  {
+    h = m[j];
+    if (h!=NULL)
+    {
+      h=p_Copy(h, R);
+      l=pLength(h);
+      p_SetCompP(h,j+1, R);
+      sBucket_Merge_p(bucket, h, l);
+    }
+  }
+  sBucketClearMerge(bucket, &h, &l);
+  sBucketDestroy(&bucket);
+  return h;
+}
+
+/// converts mat to module, destroys mat
 ideal id_Matrix2Module(matrix mat, const ring R)
 {
   int mc=MATCOLS(mat);
@@ -1309,7 +1332,7 @@ BOOLEAN id_HomModule(ideal m, ideal Q, intvec **w, const ring R)
     if (i<length)
     {
       p=F[i];
-      while ((p!=NULL) && (iscom[p_GetComp(p,R)]==0)) pIter(p);
+      while ((p!=NULL) && (iscom[__p_GetComp(p,R)]==0)) pIter(p);
     }
     if ((p==NULL) && (i<length))
     {
@@ -1329,7 +1352,7 @@ BOOLEAN id_HomModule(ideal m, ideal Q, intvec **w, const ring R)
       //else
       //  order = p->order;
       //  order = pFDeg(p,currRing);
-      order = d(p,R) +diff[p_GetComp(p,R)];
+      order = d(p,R) +diff[__p_GetComp(p,R)];
       //order += diff[pGetComp(p)];
       p = F[i];
 //Print("Actual p=F[%d]: ",i);pWrite(p);
@@ -1343,10 +1366,10 @@ BOOLEAN id_HomModule(ideal m, ideal Q, intvec **w, const ring R)
       else
       //  ord = p->order;
         ord = R->pFDeg(p,R);
-      if (iscom[p_GetComp(p,R)]==0)
+      if (iscom[__p_GetComp(p,R)]==0)
       {
-        diff[p_GetComp(p,R)] = order-ord;
-        iscom[p_GetComp(p,R)] = 1;
+        diff[__p_GetComp(p,R)] = order-ord;
+        iscom[__p_GetComp(p,R)] = 1;
 /*
 *PrintS("new diff: ");
 *for (j=0;j<cmax;j++) Print("%d ",diff[j]);
@@ -1365,7 +1388,7 @@ BOOLEAN id_HomModule(ideal m, ideal Q, intvec **w, const ring R)
 *PrintLn();
 *Print("order %d, ord %d, diff %d\n",order,ord,diff[pGetComp(p)]);
 */
-        if (order != (ord+diff[p_GetComp(p,R)]))
+        if (order != (ord+diff[__p_GetComp(p,R)]))
         {
           omFreeSize((ADDRESS) iscom,cmax*sizeof(int));
           omFreeSize((ADDRESS) diff,cmax*sizeof(long));
@@ -1395,7 +1418,7 @@ BOOLEAN id_HomModule(ideal m, ideal Q, intvec **w, const ring R)
   return TRUE;
 }
 
-ideal id_Jet(ideal i,int d, const ring R)
+ideal id_Jet(const ideal i,int d, const ring R)
 {
   ideal r=idInit((i->nrows)*(i->ncols),i->rank);
   r->nrows = i-> nrows;
@@ -1408,7 +1431,7 @@ ideal id_Jet(ideal i,int d, const ring R)
   return r;
 }
 
-ideal id_JetW(ideal i,int d, intvec * iv, const ring R)
+ideal id_JetW(const ideal i,int d, intvec * iv, const ring R)
 {
   ideal r=idInit(IDELEMS(i),i->rank);
   if (ecartWeights!=NULL)
@@ -1446,7 +1469,7 @@ int id_ReadOutPivot(ideal arg,int* comp, const ring r)
     p = arg->m[i];
     while (p!=NULL)
     {
-      j = p_GetComp(p,r);
+      j = __p_GetComp(p,r);
       if (componentIsUsed[j]==0)
       {
         if (p_LmIsConstantComp(p,r) &&
@@ -1600,7 +1623,7 @@ int id_MinDegW(ideal M,intvec *w, const ring r)
   return d;
 }
 
-// #include <kernel/clapsing.h>
+// #include "kernel/clapsing.h"
 
 /*2
 * transpose a module
@@ -1617,7 +1640,7 @@ ideal id_Transp(ideal a, const ring rRing)
     while(p!=NULL)
     {
       poly h=p_Head(p, rRing);
-      int co=p_GetComp(h, rRing)-1;
+      int co=__p_GetComp(h, rRing)-1;
       p_SetComp(h, i, rRing);
       p_Setm(h, rRing);
       h->next=b->m[co];
@@ -1684,7 +1707,7 @@ ideal id_TensorModuleMult(const int m, const ideal M, const ring rRing)
     {
       poly h = p_Head(w, rRing);
 
-      const int  gen = p_GetComp(h, rRing); // 1 ...
+      const int  gen = __p_GetComp(h, rRing); // 1 ...
 
       assume(gen > 0);
       assume(gen <= n*m);
@@ -1761,6 +1784,9 @@ ideal id_ChineseRemainder(ideal *xx, number *q, int rl, const ring r)
   number *x=(number *)omAlloc(rl*sizeof(number));
   poly *p=(poly *)omAlloc(rl*sizeof(poly));
   CFArray inv_cache(rl);
+  extern int n_SwitchChinRem; //TEST
+  int save_n_SwitchChinRem=n_SwitchChinRem;
+  n_SwitchChinRem=1;
   for(i=cnt-1;i>=0;i--)
   {
     for(j=rl-1;j>=0;j--)
@@ -1776,6 +1802,7 @@ ideal id_ChineseRemainder(ideal *xx, number *q, int rl, const ring r)
       if(i<IDELEMS(xx[j])*xx[j]->nrows) xx[j]->m[i]=p[j];
     }
   }
+  n_SwitchChinRem=save_n_SwitchChinRem;
   omFreeSize(p,rl*sizeof(poly));
   omFreeSize(x,rl*sizeof(number));
   for(i=rl-1;i>=0;i--) id_Delete(&(xx[i]),r);
@@ -1796,3 +1823,12 @@ void id_Shift(ideal M, int s, const ring r)
 
 //  id_Test( M, r );
 }
+
+ideal id_Delete_Pos(const ideal I, const int p, const ring r)
+{
+  if ((p<0)||(p>=IDELEMS(I))) return NULL;
+  ideal ret=idInit(IDELEMS(I)-1,I->rank);
+  for(int i=0;i<p;i++) ret->m[i]=p_Copy(I->m[i],r);
+  for(int i=p+1;i<IDELEMS(I);i++) ret->m[i-1]=p_Copy(I->m[i],r);
+  return ret;
+}
