@@ -5,7 +5,7 @@
 * ABSTRACT: management of resources
 */
 
-#include "resourcesconfig.h"
+#include "singular_resourcesconfig.h"
 #include "feResource.h"
 #include "omFindExec.h"
 
@@ -174,7 +174,7 @@ void feInitResources(const char* argv0)
     //WarnS("illegal argv[0]==NULL");
     feArgv0 = (char*)malloc(MAXPATHLEN+strlen("/Singular"));
     getcwd(feArgv0, MAXPATHLEN);
-    strcpy(feArgv0+strlen(feArgv0),"/Singular");
+    strcat(feArgv0,"/Singular");
   }
   else
     feArgv0 = strdup(argv0);
